@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,8 +21,10 @@
 
 #include "wb_overview_diagram.h"
 #include "workbench/wb_context.h"
+#include "model/wb_context_model.h"
+#include "grtpp_undo_manager.h"
 #include "grt/icon_manager.h"
-#include "string_utilities.h"
+#include "base/string_utilities.h"
 
 using namespace bec;
 using namespace wb;
@@ -35,7 +37,7 @@ public:
 
   virtual bool activate(WBContext *wb)
   {
-    wb->add_new_diagram(model);
+    wb->get_model_context()->add_new_diagram(model);
     return true;
   }
 };
@@ -48,7 +50,7 @@ public:
 
   virtual bool activate(WBContext *wb)
   {
-    wb->switch_diagram(model_DiagramRef::cast_from(object));
+    wb->get_model_context()->switch_diagram(model_DiagramRef::cast_from(object));
     return true;
   }
 
@@ -59,7 +61,7 @@ public:
 
   virtual void delete_object(WBContext *wb)
   {
-    wb->delete_diagram(model_DiagramRef::cast_from(object));
+    wb->get_model_context()->delete_diagram(model_DiagramRef::cast_from(object));
   }
 
 
