@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2013, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -693,24 +693,29 @@ void SqlEditorForm::create_connection(sql::Dbc_connection_handler::Ref &dbc_conn
 
   // Activate the schema that was last active when this connection was open.
   // If there's no active schema use the default schema.
-  std::string last_default = temp_connection->parameterValues().get_string("DbSqlEditor:LastDefaultSchema");
-  if (last_default.empty())
-    last_default = temp_connection->parameterValues().get_string("schema");
-  if (!last_default.empty())
+  if (dbc_conn->active_schema.empty())
   {
-    try
+    std::string last_default = temp_connection->parameterValues().get_string("DbSqlEditor:LastDefaultSchema");
+    if (last_default.empty())
+      last_default = temp_connection->parameterValues().get_string("schema");
+    if (!last_default.empty())
     {
-      dbc_conn->ref->setSchema(last_default);
-      dbc_conn->active_schema = last_default;
-      
-      _grtm->run_once_when_idle(this, boost::bind(&set_active_schema, shared_from_this(), last_default));
-    }
-    catch (std::exception &exc)
-    {
-      log_error("Can't restore LastDefaultSchema (%s): %s", last_default.c_str(), exc.what());
-      temp_connection->parameterValues().gset("DbSqlEditor:LastDefaultSchema", "");
+      try
+      {
+        dbc_conn->ref->setSchema(last_default);
+        dbc_conn->active_schema = last_default;
+
+        _grtm->run_once_when_idle(this, boost::bind(&set_active_schema, shared_from_this(), last_default));
+      }
+      catch (std::exception &exc)
+      {
+        log_error("Can't restore LastDefaultSchema (%s): %s", last_default.c_str(), exc.what());
+        temp_connection->parameterValues().gset("DbSqlEditor:LastDefaultSchema", "");
+      }
     }
   }
+  else
+    dbc_conn->ref->setSchema((dbc_conn->active_schema));
 
   dbc_conn->ref->setAutoCommit(autocommit_mode);
   dbc_conn->autocommit_mode= dbc_conn->ref->getAutoCommit();
@@ -1487,7 +1492,7 @@ grt::StringRef SqlEditorForm::do_exec_sql(grt::GRT *grt, Ptr self_ptr, boost::sh
                 err_msg= strfmt(_("Error Code: %i. %s\nSelect the default DB to be used by double-clicking its name in the SCHEMAS list in the sidebar."), e.getErrorCode(), e.what());
                 break;
               case 1175: // safe mode
-                err_msg= strfmt(_("Error Code: %i. %s\nTo disable safe mode, toggle the option in Preferences -> SQL Editor -> Query Editor and reconnect."), e.getErrorCode(), e.what());
+                err_msg= strfmt(_("Error Code: %i. %s\nTo disable safe mode, toggle the option in Preferences -> SQL Queries and reconnect."), e.getErrorCode(), e.what());
                 break;
               default:
                 err_msg= strfmt(_("Error Code: %i. %s"), e.getErrorCode(), e.what());
@@ -1881,7 +1886,9 @@ bool SqlEditorForm::run_data_changes_commit_wizard(Recordset::Ptr rs_ptr)
   const Sql_script &sql_script= sql_storage->sql_script_substitute();;
   std::string sql_script_text= Recordset_sql_storage::statements_as_sql_script(sql_script.statements);
 
-  SqlScriptRunWizard wizard(_grtm);
+  // No need for online DDL settings or callback as we are dealing with data here, not metadata.
+  SqlScriptRunWizard wizard(_grtm, rdbms()->version(), "", "");
+
   scoped_connection c1(on_sql_script_run_error.connect(boost::bind(&SqlScriptApplyPage::on_error, wizard.apply_page, _1, _2, _3)));
   scoped_connection c2(on_sql_script_run_progress.connect(boost::bind(&SqlScriptApplyPage::on_exec_progress, wizard.apply_page, _1)));
   scoped_connection c3(on_sql_script_run_statistics.connect(boost::bind(&SqlScriptApplyPage::on_exec_stat, wizard.apply_page, _1, _2)));
