@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2013, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -45,8 +45,8 @@
 
 #define APP_MAJOR_NUMBER 5
 #define APP_MINOR_NUMBER 2
-#define APP_RELEASE_NUMBER 45
-#define APP_REVISION_NUMBER 10251
+#define APP_RELEASE_NUMBER 46
+#define APP_REVISION_NUMBER 10385
 #define APP_RELEASE_TYPE ""
 
 
@@ -265,8 +265,8 @@ namespace wb {
     // Admin
     void add_new_admin_window(const db_mgmt_ServerInstanceRef &target);
 
-    // Migration
-    void add_new_migration_window();
+    // Generic plugin tabs
+    void add_new_plugin_window(const std::string &plugin_id, const std::string &caption);
 
     // GUI Plugin
     void register_builtin_plugins(grt::ListRef<app_Plugin> plugins);
@@ -418,7 +418,7 @@ namespace wb {
     
     TunnelManager *_tunnel_manager;
 
-    ModelFile* _model_file;
+    ModelFile* _model_import_file;
     
     bool _force_sw_rendering;     // Command line switch.
     bool _force_opengl_rendering; // Command line switch.
@@ -446,6 +446,8 @@ namespace wb {
     
     bool auto_save_document();
     std::string get_auto_save_dir();
+
+    void cleanup_options();
   public:
     void save_app_options();
     void save_connections();
