@@ -101,7 +101,6 @@ GRTManager::GRTManager(bool threaded, bool verbose)
 
   _plugin_manager= _grt->get_native_module<PluginManagerImpl>();
 
-  _value_tree= 0;
   _messages_list= new MessageListStorage(this);
 }
 
@@ -220,8 +219,6 @@ GRTManager::~GRTManager()
 
   delete _shell;
   _shell = 0;
-  delete _value_tree;
-  _value_tree = 0;
   delete _messages_list;
   _messages_list = 0;
 
@@ -271,39 +268,6 @@ MessageListStorage *GRTManager::get_messages_list()
   return _messages_list;
 }
 
-
-ValueTreeBE *GRTManager::get_shared_value_tree(const std::string &valuespec)
-{
-  if (!_value_tree)
-    _value_tree= new ValueTreeBE(_grt);
-
-  if (!valuespec.empty() && valuespec[0] == '/')
-  {
-    if (*valuespec.rbegin() == '/' && valuespec != "/")
-      _value_tree->set_displayed_global_value(valuespec.substr(0, valuespec.size()-1), false);
-    else
-      _value_tree->set_displayed_global_value(valuespec, true);
-  }
-  else
-    _value_tree->set_displayed_value(_shell->get_shell_variable(valuespec),
-                                     valuespec);
-
-  return _value_tree;
-}
-
-
-ValueInspectorBE *GRTManager::get_new_value_inspector(const grt::ValueRef &value, bool process_editas_flag)
-{
-  return ValueInspectorBE::create(_grt, value, false, process_editas_flag);
-}
-
-
-ValueInspectorBE *GRTManager::get_new_grouped_object_inspector(const grt::ValueRef &object, bool process_editas_flag)
-{
-  return ValueInspectorBE::create(_grt, object, true, process_editas_flag);
-}
-
-
 void GRTManager::task_error_cb(const std::exception &error, const std::string &title)
 {
   mforms::Utilities::show_error(title, error.what(), _("Close"));
