@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -171,10 +171,12 @@ void GrtThreadedTask::process_msg(const grt::Message &msg, bec::GRTTask *task)
   case grt::WarningMsg:
   case grt::ErrorMsg:
   case grt::InfoMsg:
-    _msg_cb(msg.type, msg.text, msg.detail);
+    if(_msg_cb)
+      _msg_cb(msg.type, msg.text, msg.detail);
     break;
   case grt::ProgressMsg:
-    _progress_cb(msg.progress, msg.text);
+    if(_progress_cb)
+      _progress_cb(msg.progress, msg.text);
     break;
    default:
       break;
@@ -233,7 +235,7 @@ void GrtThreadedTask::send_msg(int msg_type, const std::string &msg, const std::
 
 void GrtThreadedTask::send_progress(float percentage, const std::string &msg, const std::string &detail)
 {
-  if (!_grtm)
+  if (!_grtm || _grtm->terminated())
     return;
 
   if (_grtm->in_main_thread())
