@@ -2160,7 +2160,6 @@ bool FKConstraintColumnsListBE::set_field(const NodeId &node, int column, const
 bool FKConstraintColumnsListBE::set_field(const NodeId &node, int column, int value)
 {
   db_ForeignKeyRef fk(_owner->get_selected_fk());
-  db_ColumnRef tcolumn;
 
   switch (column)
   {
@@ -2176,7 +2175,33 @@ bool FKConstraintColumnsListBE::set_field(const NodeId &node, int column, int va
                  strfmt(_("Remove Column from FK '%s.%s'"), _owner->get_owner()->get_name().c_str(), fk->name().c_str()));
       }
       else
+      {
         undo.cancel();
+
+        db_ColumnRef tcolumn;
+        if (node[0] < (int)_owner->get_owner()->get_table()->columns().count())
+          tcolumn = fk->owner()->columns()[node[0]];
+        db_TableRef reftable = fk->referencedTable();
+
+        if (reftable.is_valid() && tcolumn.is_valid() && get_ref_columns_list(node).empty())
+        {
+          std::string hint;
+          if (reftable->primaryKey().is_valid() && reftable->primaryKey()->columns().count() > 0)
+            hint = base::strfmt("\nHint: source column has type %s%s,\nPK of referenced table is %s%s.",
+                                tcolumn->flags().get_index("UNSIGNED") != grt::BaseListRef::npos ? "UNSIGNED " : "",
+                                tcolumn->formattedType().c_str(),
+                                reftable->primaryKey()->columns()[0]->referencedColumn()->flags().get_index("UNSIGNED") != grt::BaseListRef::npos ? "UNSIGNED " : "",
+                                reftable->primaryKey()->columns()[0]->referencedColumn()->formattedType().c_str());
+
+          // show a warning
+          mforms::Utilities::show_message("Create Foreign Key",
+                                          base::strfmt("Referenced table has no candidate columns with a compatible type for %s.%s.%s",
+                                                       tcolumn->owner()->name().c_str(),
+                                                       tcolumn->name().c_str(),
+                                                       hint.c_str()),
+                                          "OK");
+        }
+      }
       return true;
     }
     return false;
