@@ -351,6 +351,7 @@ namespace bec {
     virtual NodeId add_column(const std::string &name);
     virtual void remove_column(const NodeId &column);
     void rename_column(const db_ColumnRef &column, const std::string &name);
+    NodeId duplicate_column(const db_ColumnRef &col);
 
     db_ColumnRef get_column_with_name(const std::string &name);
 
@@ -376,6 +377,8 @@ namespace bec {
     grt::ValueRef parse_triggers_sql(grt::GRT*, grt::StringRef sql);
 
     void show_export_wizard(mforms::Form *owner);
+    void show_import_wizard();
+    
     virtual Sql_editor::Ref get_sql_editor();
 
     protected:
