@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -110,3 +110,7 @@ std::string UserEditorBE::get_title()
   return base::strfmt("%s - User", get_name().c_str()); 
 }
 
+bool UserEditorBE::can_close()
+{
+  return true; // There's nothing that can prevent closing the editor.
+}
\ No newline at end of file
