@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -46,6 +46,7 @@ class WBPUBLICBACKEND_PUBLIC_FUNC SqlFacade
 {
 public:
   typedef SqlFacade * Ref;
+  typedef std::list<std::pair<std::string, std::string> > Column_name_list;
   
 public:
   static SqlFacade::Ref instance_for_db_obj(db_DatabaseObjectRef db_obj);
@@ -53,6 +54,8 @@ public:
   static SqlFacade::Ref instance_for_rdbms_name(grt::GRT *grt, const std::string &name);
 
   virtual int splitSqlScript(const std::string &sql, std::list<std::string> &statements)= 0;
+  virtual int splitSqlScript(const char *sql, size_t length, const std::string &intial_delimiter,
+    std::vector<std::pair<size_t, size_t> > &borders)= 0;
 
   virtual Sql_parser::Ref sqlParser()= 0;
   virtual int parseSqlScriptString(grt::Ref<db_Catalog> catalog, const std::string sql)= 0;
@@ -79,7 +82,7 @@ public:
 
   virtual Sql_normalizer::Ref sqlNormalizer()= 0;
   virtual std::string normalizeSqlStatement(const std::string sql, const std::string schema_name)= 0;
-  virtual std::string remove_inter_token_spaces(const std::string sql) = 0;
+  virtual std::string removeInterTokenSpaces(const std::string sql) = 0;
 
   virtual Sql_inserts_loader::Ref sqlInsertsLoader()= 0;
 
@@ -87,6 +90,10 @@ public:
   virtual int renameSchemaReferences(grt::Ref<db_Catalog> catalog, const std::string old_schema_name, const std::string new_schema_name)= 0;
 
   virtual Sql_statement_decomposer::Ref sqlStatementDecomposer()= 0;
+
+  virtual bool parseSelectStatementForEdit(const std::string &sql, std::string &schema_name, std::string &table_name, Column_name_list &column_names)= 0;
+  
+  virtual void stop_processing() = 0;
 };
 
 
