@@ -123,9 +123,10 @@ public:
         _offset = 0;
         break;
       case -1:
-        _offset -= _block_size;
-        if (_offset < 0)
+        if (_block_size > _offset)
           _offset = 0;
+        else
+          _offset -= _block_size;
         break;
       case 1:
         _offset += _block_size;
