@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -31,14 +31,10 @@
 db_query_Resultset::ImplData::ImplData(db_query_ResultsetRef aself, boost::shared_ptr<Recordset> rset)
 : self(dynamic_cast<db_query_Resultset*>(aself.valueptr())), recordset(rset), cursor(0)
 { 
-  const std::vector<std::string> *column_names(recordset->column_names());
-  int i= 0;
-  const int last_column= column_names->size()-1;
-  for (std::vector<std::string>::const_iterator iter= column_names->begin(); iter != column_names->end(); ++iter, ++i)
+  const int last_column= recordset->get_column_count();
+  for (int i = 0; i < last_column; i++)
   {
-    if (i == last_column) // last column is internally added
-      break;
-    column_by_name[*iter]= i;
+    column_by_name[recordset->get_column_caption(i)]= i;
     
     std::string type;
     switch (recordset->get_column_type(i))
@@ -54,7 +50,7 @@ db_query_Resultset::ImplData::ImplData(db_query_ResultsetRef aself, boost::share
     db_query_ResultsetColumnRef column(aself->get_grt());
     
     column->owner(aself);
-    column->name(*iter);
+    column->name(recordset->get_column_caption(i));
     column->columnType(type);
     
     self->columns().insert(column);
@@ -62,7 +58,7 @@ db_query_Resultset::ImplData::ImplData(db_query_ResultsetRef aself, boost::share
 }
 
 
-db_query_ResultsetRef grtwrap_recordset(db_query_EditorRef owner, Recordset::Ref rset)
+db_query_ResultsetRef grtwrap_recordset(GrtObjectRef owner, Recordset::Ref rset)
 {
   db_query_ResultsetRef object(owner.get_grt());
 
@@ -95,33 +91,25 @@ void db_query_Resultset::set_data(ImplData *data)
 
 grt::IntegerRef db_query_Resultset::currentRow() const
 {
-  return grt::IntegerRef((grt::IntegerRef::storage_type)_data->cursor);
-}
-
-grt::IntegerRef db_query_Resultset::pinned() const
-{
-  return grt::IntegerRef(_data->recordset->pinned());
-}
-
-void db_query_Resultset::pinned(const grt::IntegerRef &value)
-{
-  _data->recordset->pinned(*value != 0);
+  if (_data)
+    return grt::IntegerRef((grt::IntegerRef::storage_type)_data->cursor);
+  return grt::IntegerRef();
 }
 
 grt::StringRef db_query_Resultset::sql() const
 {
-  return _data->recordset->generator_query();
+  return _data ? grt::StringRef(_data->recordset->generator_query()) : grt::StringRef();
 }
 
 grt::IntegerRef db_query_Resultset::rowCount() const
 {
-  return _data->recordset->count();
+  return _data ? grt::IntegerRef(_data->recordset->count()) : grt::IntegerRef();
 }
 
 grt::DoubleRef db_query_Resultset::floatFieldValue(long column)
 {
   double value;
-  if (column >= 0 && column < _data->recordset->get_column_count() &&
+  if (_data && column >= 0 && column < _data->recordset->get_column_count() &&
       _data->recordset->get_field(_data->cursor, column, value))
     return grt::DoubleRef(value);
   return grt::DoubleRef(); // NULL
@@ -131,7 +119,7 @@ grt::DoubleRef db_query_Resultset::floatFieldValue(long column)
 grt::DoubleRef db_query_Resultset::floatFieldValueByName(const std::string &column)
 {
   double value;
-  if (_data->column_by_name.find(column) != _data->column_by_name.end())
+  if (_data && _data->column_by_name.find(column) != _data->column_by_name.end())
   {
     if (_data->recordset->get_field(_data->cursor, _data->column_by_name[column], value))
       return grt::DoubleRef(value);
@@ -142,14 +130,18 @@ grt::DoubleRef db_query_Resultset::floatFieldValueByName(const std::string &colu
 
 grt::IntegerRef db_query_Resultset::goToFirstRow()
 {
-  _data->cursor= 0;
-  return grt::IntegerRef((int) _data->cursor < _data->recordset->count());
+  if (_data)
+  {
+    _data->cursor= 0;
+    return grt::IntegerRef((int) _data->cursor < _data->recordset->count());
+  }
+  return grt::IntegerRef(0);
 }
 
 
 grt::IntegerRef db_query_Resultset::goToLastRow()
 {
-  if (_data->recordset->count() > 0)
+  if (_data && _data->recordset->count() > 0)
   {
     _data->cursor= _data->recordset->count()-1;
     return grt::IntegerRef(1);
@@ -160,7 +152,7 @@ grt::IntegerRef db_query_Resultset::goToLastRow()
 
 grt::IntegerRef db_query_Resultset::goToRow(long row)
 {
-  if (row >= 0 && row < _data->recordset->count())
+  if (_data && row >= 0 && row < _data->recordset->count())
   {
     _data->cursor= row;
     return grt::IntegerRef(1);
@@ -172,7 +164,7 @@ grt::IntegerRef db_query_Resultset::goToRow(long row)
 grt::IntegerRef db_query_Resultset::intFieldValue(long column)
 {
   long long value;
-  if (column >= 0 && column < _data->recordset->get_column_count() &&
+  if (_data && column >= 0 && column < _data->recordset->get_column_count() &&
       _data->recordset->get_field(bec::NodeId(_data->cursor), (int)column, value))
     return grt::IntegerRef((grt::IntegerRef::storage_type)value);
   return grt::IntegerRef(); // NULL  
@@ -182,7 +174,7 @@ grt::IntegerRef db_query_Resultset::intFieldValue(long column)
 grt::IntegerRef db_query_Resultset::intFieldValueByName(const std::string &column)
 {
   long long value;
-  if (_data->column_by_name.find(column) != _data->column_by_name.end())
+  if (_data && _data->column_by_name.find(column) != _data->column_by_name.end())
   {
     if (_data->recordset->get_field(bec::NodeId(_data->cursor), _data->column_by_name[column], value))
       return grt::IntegerRef((grt::IntegerRef::storage_type)value);
@@ -193,7 +185,7 @@ grt::IntegerRef db_query_Resultset::intFieldValueByName(const std::string &colum
 
 grt::IntegerRef db_query_Resultset::nextRow()
 {
-  if ((int) _data->cursor < _data->recordset->count() - 1)
+  if (_data && (int) _data->cursor < _data->recordset->count() - 1)
   {
     ++_data->cursor;
     return grt::IntegerRef(1);
@@ -204,7 +196,7 @@ grt::IntegerRef db_query_Resultset::nextRow()
 
 grt::IntegerRef db_query_Resultset::previousRow()
 {
-  if (_data->cursor > 0)
+  if (_data && _data->cursor > 0)
   {
     --_data->cursor;
     return grt::IntegerRef(1);
@@ -215,7 +207,8 @@ grt::IntegerRef db_query_Resultset::previousRow()
 
 grt::IntegerRef db_query_Resultset::refresh()
 {
-  _data->recordset->refresh();
+  if (_data)
+    _data->recordset->refresh();
 
   return grt::IntegerRef(0);
 }
@@ -224,8 +217,8 @@ grt::IntegerRef db_query_Resultset::refresh()
 grt::StringRef db_query_Resultset::stringFieldValue(long column)
 {
   std::string value;
-  if (column >= 0 && column < _data->recordset->get_column_count() &&
-      _data->recordset->get_field_repr(bec::NodeId(_data->cursor), (int)column, value))
+  if (_data && column >= 0 && column < _data->recordset->get_column_count() &&
+      _data->recordset->get_field_repr_no_truncate(bec::NodeId(_data->cursor), (int)column, value))
     return grt::StringRef(value);
   return grt::StringRef(); // NULL    
 }
@@ -234,9 +227,9 @@ grt::StringRef db_query_Resultset::stringFieldValue(long column)
 grt::StringRef db_query_Resultset::stringFieldValueByName(const std::string &column)
 {
   std::string value;
-  if (_data->column_by_name.find(column) != _data->column_by_name.end())
+  if (_data && _data->column_by_name.find(column) != _data->column_by_name.end())
   {
-    if (_data->recordset->get_field_repr(bec::NodeId(_data->cursor), _data->column_by_name[column], value))
+    if (_data->recordset->get_field_repr_no_truncate(bec::NodeId(_data->cursor), _data->column_by_name[column], value))
       return grt::StringRef(value);
   }
   return grt::StringRef(); // NULL    
@@ -244,7 +237,7 @@ grt::StringRef db_query_Resultset::stringFieldValueByName(const std::string &col
 
 grt::IntegerRef db_query_Resultset::saveFieldValueToFile(long column, const std::string &file)
 {
-  if (column >= 0 && column < _data->recordset->get_column_count())
+  if (_data && column >= 0 && column < _data->recordset->get_column_count())
   {
     _data->recordset->save_to_file(bec::NodeId(_data->cursor), (int)column, file);
     return grt::IntegerRef(1);
