@@ -160,8 +160,6 @@ public:
   void paste_rows_from_clipboard(int dest_row);
   
 public:
-  boost::function<void ()> export_wizard;
-  
   std::vector<Recordset_storage_info> data_storages_for_export();
   Recordset_data_storage_Ref data_storage_for_export(const std::string &format_name);
 protected:
@@ -170,6 +168,7 @@ protected:
   Data_storages_for_export _data_storages_for_export;
 
   void invoke_export();
+  void invoke_import();
   
   void load_from_file(const bec::NodeId &node, int column);
   void save_to_file(const bec::NodeId &node, int column);
