@@ -58,6 +58,8 @@ public:
   db_mgmt_RdbmsRef _rdbms;
   bec::GRTManager *_grtm;
 
+  long _server_version;
+
   mforms::Menu* _editor_context_menu;
   mforms::Menu* _editor_text_submenu;
 
@@ -199,6 +201,27 @@ Sql_editor::Sql_editor(db_mgmt_RdbmsRef rdbms, GrtVersionRef version)
   _auto_completion_cache = NULL;
   d->_last_typed_char = 0;
 
+  // Create a server version of the form "Mmmrr" as long int for quick comparisons.
+  if (version.is_valid())
+    _server_version = version->majorNumber() * 10000 + version->minorNumber() * 100 + version->releaseNumber();
+  else
+    _server_version = 50501; // Assume some reasonable default (5.5.1).
+
+  // Prepare the set of charset names for the parsers.
+  grt::ListRef<db_CharacterSet> list= rdbms->characterSets();
+  for (size_t i = 0; i < list->count(); i++)
+    _charsets.insert(base::tolower(*list[i]->name()));
+
+  // 3 character sets were added in version 5.5.3. Remove them from the list if the current version
+  // is lower than that.
+  if (_server_version < 50503)
+  {
+    _charsets.erase("utf8mb4");
+    _charsets.erase("utf16");
+    _charsets.erase("utf32");
+  }
+  _sql_mode = "";
+
   setup_editor_menu();
 }
 
@@ -381,10 +404,10 @@ boost::signals2::signal<void ()>* Sql_editor::text_change_signal()
 
 void Sql_editor::sql_mode(const std::string &value)
 {
+  _sql_mode = value; 
   d->_sql_checker->sql_mode(value);
 }
 
-
 bool Sql_editor::has_sql_errors() const
 {
   return d->_last_error_count > 0;
