@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -34,8 +34,6 @@
 #include "base/string_utilities.h"
 
 using namespace base;
-using namespace MySQL::Geometry;
-using namespace MySQL::Drawing;
 
 workbench_physical_TableFigure::ImplData::ImplData(workbench_physical_TableFigure *self)
   : super(self), _figure(0)
@@ -115,9 +113,9 @@ void workbench_physical_TableFigure::ImplData::set_table(const db_TableRef &tabl
     if (self()->_owner.is_valid())
       workbench_physical_DiagramRef::cast_from(self()->_owner)->get_data()->add_mapping(table, self());
     
-    _table_fk_conn= *scoped_connect(table->signal_foreignKeyChanged(),boost::bind(&ImplData::fk_changed, this, _1)).get();
-    _refresh_conn = *scoped_connect(table->signal_refreshDisplay(),boost::bind(&ImplData::content_changed, this, _1)).get();
-    _changed_conn = *scoped_connect(table->signal_changed(),boost::bind(&ImplData::table_member_changed, this, _1, _2)).get();
+    _table_fk_conn= table->signal_foreignKeyChanged()->connect(boost::bind(&ImplData::fk_changed, this, _1));
+    _refresh_conn = table->signal_refreshDisplay()->connect(boost::bind(&ImplData::content_changed, this, _1));
+    _changed_conn = table->signal_changed()->connect(boost::bind(&ImplData::table_member_changed, this, _1, _2));
 
     self()->_name= self()->_table->name();
 
