@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2010, 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2013, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -144,22 +144,20 @@ MySQL::Grt::GrtValueTree^ WbContext::get_catalog_tree()
 
 //--------------------------------------------------------------------------------------------------
 
-MySQL::Grt::TreeModel^ WbContext::get_history_tree()
+TreeViewAdv^ WbContext::get_history_tree()
 {
-  if (history_tree == nullptr)
-    history_tree= gcnew ::MySQL::Grt::TreeModel(inner->get_history_tree());
+  mforms::TreeNodeView *native_tree = inner->get_wb()->get_model_context()->create_history_tree();
 
-  return history_tree;
+  return (TreeViewAdv^)ObjectImpl::FromUnmanaged(native_tree)->get_control();
 }
 
 //--------------------------------------------------------------------------------------------------
 
-MySQL::Grt::ListModel^ WbContext::get_usertypes_tree()
+TreeViewAdv^ WbContext::get_usertypes_tree()
 {
-  if (usertypes_tree == nullptr)
-    usertypes_tree= gcnew ::MySQL::Grt::ListModel(inner->get_usertypes_tree());
+  mforms::TreeNodeView *native_tree = inner->get_wb()->get_model_context()->create_user_type_list();
 
-  return usertypes_tree;
+  return (TreeViewAdv^)ObjectImpl::FromUnmanaged(native_tree)->get_control();
 } 
 
 //--------------------------------------------------------------------------------------------------
