@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2010, 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2013, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -25,7 +25,7 @@
 #include "workbench/wb_context_ui.h"
 #include "model/wb_model_diagram_form.h"
 #include "model/wb_context_model.h"
-#include "workbench/wb_history_tree.h"
+#include "model/wb_history_tree.h"
 #include "model/wb_diagram_options.h"
 #include "model/wb_user_datatypes.h"
 #include "model/wb_overview_physical.h"
@@ -49,6 +49,8 @@ using namespace System;
 using namespace System::Collections::Generic;
 using namespace System::Runtime::InteropServices;
 
+using namespace Aga::Controls::Tree;
+
 using namespace MySQL::Grt;
 using namespace MySQL::GUI::Mdc;
 using namespace MySQL::Forms;
@@ -173,8 +175,6 @@ public ref class WbContext
   ::MySQL::Grt::GrtManager^ manager;
   ::MySQL::Workbench::Overview^ physical_overview;
   ::MySQL::Grt::GrtValueTree^ catalog_tree;
-  ::MySQL::Grt::TreeModel^ history_tree;
-  ::MySQL::Grt::ListModel^ usertypes_tree;
 
   ::System::Collections::ArrayList open_editor_slot_wrappers;
 
@@ -223,8 +223,6 @@ public:
     manager = nullptr;
     physical_overview = nullptr;
     catalog_tree = nullptr;
-    history_tree = nullptr;
-    usertypes_tree = nullptr;
 
     Logger::LogDebug(DOMAIN_WB_CONTEXT_WRAPPER, 1, "Creating WbContext\n");
   }
@@ -232,11 +230,9 @@ public:
   ~WbContext()
   {
     delete catalog_tree;
-    delete history_tree;
     delete physical_overview;
     delete inner;
     delete manager;
-    delete usertypes_tree;
 
     Logger::LogDebug(DOMAIN_WB_CONTEXT_WRAPPER, 1, "Destroying WbContext\n");
   }
@@ -504,8 +500,8 @@ public:
   // Overview.
   Overview^ get_physical_overview();
   ::MySQL::Grt::GrtValueTree^ get_catalog_tree();
-  ::MySQL::Grt::TreeModel^ get_history_tree();
-  ::MySQL::Grt::ListModel^ get_usertypes_tree();
+  TreeViewAdv^ get_history_tree();
+  TreeViewAdv^ get_usertypes_tree();
   ::MySQL::Grt::GrtValueInspector^ get_inspector_for_selection(UIForm^ form, [Out] List<String^>^ %items);
   bool are_lists_equal(GrtValue^ v1, GrtValue^ v2);
   String^ get_description_for_selection(UIForm^ form, [Out] GrtValue^ %activeObjList, [Out] List<String^>^ %items);
