@@ -1,19 +1,35 @@
+/* 
+ * Copyright (c) 2010, 2012 Oracle and/or its affiliates. All rights reserved.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; version 2 of the
+ * License.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301  USA
+ */
+
 #ifndef __DB_OBJECT_EDITOR_H__
 #define __DB_OBJECT_EDITOR_H__
 
 #include "grtdb/editor_dbobject.h"
-#include "sql_editor_wr.h"
 #include "Grt.h"
 #include "GrtTemplates.h"
 #include "BaseEditor.h"
-#include "SigCSlot.h"
+#include "DelegateWrapper.h"
 
 
 #ifdef _MSC_VER
-//#include  <vcclr.h> // .net interop helpers
 using namespace MySQL::Grt;
 using namespace System;
-using namespace System::Runtime::InteropServices;
 using namespace System::Collections::Generic;
 #endif
 
@@ -130,7 +146,7 @@ public:
       gcnew VoidStringVectorWrapperDelegate(this, &DBObjectEditorBE::on_parse_sql_log_wrapper);
     IntPtr ip = Marshal::GetFunctionPointerForDelegate(on_parse_sql_log_wrapper_delegate);
     VOID_STRINGVECTOR_CB cb = static_cast<VOID_STRINGVECTOR_CB>(ip.ToPointer());
-    get_unmanaged_object()->set_sql_parser_log_cb(boost::bind(cb, _1));
+    get_unmanaged_object()->set_sql_parser_log_cb(cb);
   }
 
   typedef DelegateSlot4<
