@@ -26,6 +26,8 @@
 #include "UIForm.h"
 #include "IconManager.h"
 
+using namespace Runtime::InteropServices; // Needed for the [Out] keyword.
+
 namespace MySQL {
   namespace Grt {
 
@@ -180,6 +182,7 @@ namespace MySQL {
       virtual String^ get_column_caption(int column);
       virtual ColumnType get_column_type(int column);
       virtual bool is_readonly();
+      virtual String^ readonly_reason();
       virtual bool is_field_null(NodeId^ node, int column);
       virtual bool set_field_null(NodeId^ node, int column);
       virtual bool get_field_repr(NodeId^ node, int column, [Out] String^ %value);
