@@ -1,6 +1,5 @@
-#!/usr/bin/env python
 #
-# Copyright (c) 2010, 2012 Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2010, 2013 Oracle and/or its affiliates. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -301,6 +300,12 @@ parser.add_option("--start-test", action="store", dest="start_test",
                   type = "string", help="start executing tests that begin "
                   "with this string", default=None)
 
+# Add start-test list option
+parser.add_option("--stop-test", action="store", dest="stop_test",
+                  type = "string", help="stop executing tests at first "
+                  "occurrence of test that begins with this string",
+                  default=None)
+
 # Add skip-long tests option
 parser.add_option("--skip-long", action="store_true", dest="skip_long",
                   default=False, help="exclude tests that require "
@@ -423,6 +428,9 @@ if opt.start_test:
 else:
     start_sequence = False
 
+if opt.stop_test:
+    print "  Stop test           = '%s%%'" % opt.stop_test
+
 server_list = Server_list([], opt.start_port, opt.utildir, verbose_mode)
 basedir = None
 
@@ -469,11 +477,11 @@ else:
         # Here we capture any exception and print the error message.
         # Since all util errors (exceptions) derive from Exception, this is
         # safe.
-        except Exception, e:
+        except Exception, err:
             print "%sFAILED%s" % (BOLD_ON, BOLD_OFF)
             if conn.connect_error is not None:
                 print conn.connect_error
-            print "ERROR:", e.errmsg
+            print "ERROR: %s" % str(err)
     if server_list.num_servers() == 0:
         print "ERROR: Failed to connect to any servers listed."
         exit(1)
@@ -515,6 +523,17 @@ if start_sequence:
               "suite(s)" % opt.start_test
         start_sequence = False
 
+# Check for validity of --stop-test
+if opt.stop_test:
+    found = False
+    for test_tuple in test_files:
+        if opt.stop_test == test_tuple[2][0:len(opt.stop_test)]:
+            found = True
+    if not found:
+        print "\nWARNING: --stop-test=%s%% was not found. Running full " \
+              "suite(s)" % opt.stop_test
+        opt.stop_test = None
+
 # Get list of disabled tests
 disable_list = _read_disabled_tests()
 
@@ -533,6 +552,7 @@ if os.name == "posix":
 # Run the tests selected
 num_tests_run = 0
 last_test = None
+stop_testing = False
 for test_tuple in test_files:
 
     # Skip tests for start-test sequence
@@ -542,6 +562,12 @@ for test_tuple in test_files:
         else:
             continue
 
+    # Skip tests for stop-test sequence
+    if opt.stop_test and not stop_testing:
+        stop_testing = (opt.stop_test == test_tuple[2][0:len(opt.stop_test)])
+    if stop_testing:
+        continue
+
     # Get test parts - directory not used
     test = test_tuple[2]
     
