@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 import os
 import check_rpl
 import mutlib
@@ -101,6 +99,17 @@ class test(check_rpl.test):
                             "Error ####: Can't connect to local MySQL server "
                             "####...\n")
 
+        self.replace_result("mysqlrplcheck.py: error: No login credentials",
+                            "mysqlrplcheck.py: error: Unable to get "
+                            "login-path\n")
+        self.replace_result("mysqlrplcheck.py: error: .mylogin.cnf",
+                            "mysqlrplcheck.py: error: Unable to get "
+                            "login-path\n")
+        self.replace_result("mysqlrplcheck.py: error: the used "
+                            "my_print_defaults",
+                            "mysqlrplcheck.py: error: Unable to get "
+                            "login-path\n")
+
         return True
 
     def get_result(self):
