@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+
 #
 # Copyright (c) 2010, Oracle and/or its affiliates. All rights reserved.
 #
@@ -13,7 +13,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 #
 
 """
@@ -23,10 +23,10 @@ all tables in each database), a list of tables in the for db.table,
 or all tables in all databases except internal databases.
 """
 
-from mysql.utilities.exception import MySQLUtilError
+from mysql.utilities.exception import UtilError
 
 def check_index(src_val, table_args, options):
-    """ Check for duplicate or redundant indexes for one or more tables
+    """Check for duplicate or redundant indexes for one or more tables
     
     This method will examine the indexes for one or more tables and identify
     any indexes that are potential duplicates or redundant. It prints the
@@ -41,11 +41,11 @@ def check_index(src_val, table_args, options):
                          skip         : skip non-existant tables
                          verbosity    : print extra information
                          show-indexes : show all indexes for each table
-                         index-format : index format = SQL, TABLE, TAB, CSV
+                         index-format : index format = sql, table, tab, csv
                          worst        : show worst performing indexes
                          best         : show best performing indexes
     
-    Returns bool True = success, raises MySQLUtilError if error
+    Returns bool True = success, raises UtilError if error
     """
     
     # Get options
@@ -63,7 +63,11 @@ def check_index(src_val, table_args, options):
     from mysql.utilities.common.table import Table
 
     # Try to connect to the MySQL database server.
-    servers = connect_servers(src_val, None, verbosity == 1, "5.0.0")
+    conn_options = {
+        'quiet'     : verbosity == 1,
+        'version'   : "5.0.0",
+    }
+    servers = connect_servers(src_val, None, conn_options)
 
     source = servers[0]
 
@@ -98,16 +102,21 @@ def check_index(src_val, table_args, options):
 
     # Fail if no tables to check
     if not table_list:
-        raise MySQLUtilError("No tables to check.")
+        raise UtilError("No tables to check.")
 
     if verbosity > 1:
         print "# Checking indexes..."
     # Check indexes for each table in the list
     for table_name in table_list:
-        tbl = Table(source, table_name, verbosity >= 1)
+        tbl_options = {
+            'verbose'  : verbosity >= 1,
+            'get_cols' : False,
+            'quiet'    : verbosity is None or verbosity < 1
+        }
+        tbl = Table(source, table_name, tbl_options)
         exists = tbl.exists()
         if not exists and not skip:
-            raise MySQLUtilError("Table %s does not exist. Use --skip "
+            raise UtilError("Table %s does not exist. Use --skip "
                                  "to skip missing tables." % table_name)
         if exists:
             if not tbl.get_indexes():
@@ -120,8 +129,7 @@ def check_index(src_val, table_args, options):
                 if not tbl.has_primary_key():
                     if verbosity > 1:
                         print "#   Table %s does not contain a PRIMARY key."
-                tbl.check_indexes(show_drops,
-                                  verbosity is None or verbosity < 1)
+                tbl.check_indexes(show_drops)
                 
             # Show best and/or worst indexes
             if stats:
