@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+
 #
 # Copyright (c) 2010, 2012 Oracle and/or its affiliates. All rights reserved.
 #
@@ -559,7 +559,7 @@ class RplCommands(object):
         
         failover_mode = self.options.get("failover_mode", "auto")
         pingtime = self.options.get("pingtime", 3)
-        timeout = self.options.get("timeout", 3)
+        timeout = int(self.options.get("timeout", 3))
         exec_fail = self.options.get("exec_fail", None)
         post_fail = self.options.get("post_fail", None)
                 
