@@ -108,10 +108,16 @@ def format_tabular_list(file, columns, rows, options={}):
 
         stop = len(columns)
         for row in rows:
-            for i in range(0, stop):
-                col_size = len("%s" % row[i]) + 1
-                if col_size > col_widths[i]:
-                    col_widths[i] = col_size
+            # if there is one column, just use row.
+            if stop == 1:
+                col_size = len(row[0]) + 1
+                if col_size > col_widths[0]:
+                    col_widths[0] = col_size
+            else:
+                for i in range(0, stop):
+                    col_size = len("%s" % row[i]) + 1
+                    if col_size > col_widths[i]:
+                        col_widths[i] = col_size
 
         # print header
         if print_header:
@@ -248,3 +254,30 @@ def print_dictionary_list(column_names, keys, dictionary_list,
                                              max_value)
 
 
+def convert_dictionary_list(dict_list):
+    """Convert a dictionary to separated lists of keys and values.
+
+    Convert the list of items of the given dictionary (i.e. pairs key, value)
+    to a set of columns containing the keys and a set of rows containing the
+    values.
+
+    dict_list[in]    Dictionary with a list of items to convert
+
+    Returns tuple - (columns, rows)
+    """
+    cols = []
+    rows = []
+    # First, get a list of the columns
+    for node in dict_list:
+        for key in node.keys():
+            if key not in cols:
+                cols.append(key)
+
+    # Now form the rows replacing missing columns with None
+    for node in dict_list:
+        row = []
+        for col in cols:
+            row.append(node.get(col, None))
+        rows.append(row)
+
+    return (cols, rows)
