@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2010, 2012 Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2010, 2013, Oracle and/or its affiliates. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,12 +21,17 @@ This module contains abstractions of MySQL replication functionality.
 
 import logging
 import time
+
 from mysql.utilities.common.lock import Lock
+from mysql.utilities.common.my_print_defaults import MyDefaultsReader
+from mysql.utilities.common.options import parse_connection
+from mysql.utilities.common.options import parse_user_password
 from mysql.utilities.common.replication import Master, Slave, Replication
-from mysql.utilities.common.server import Server, get_server_state
-from mysql.utilities.exception import UtilError, UtilDBError
-from mysql.utilities.exception import UtilRplError, UtilBinlogError
-        
+from mysql.utilities.common.server import get_server_state
+
+from mysql.utilities.exception import FormatError
+from mysql.utilities.exception import UtilError
+from mysql.utilities.exception import UtilRplError
 
 _HEALTH_COLS = ["host", "port", "role", "state", "gtid_mode", "health"]
 _HEALTH_DETAIL_COLS = ["version", "master_log_file", "master_log_pos",
@@ -54,14 +59,25 @@ def parse_failover_connections(options):
     
     Returns tuple - (master, slaves, candidates) dictionaries
     """
-    from mysql.utilities.common.options import parse_connection
-    from mysql.utilities.exception import FormatError
+    # Create a basic configuration reader, without looking for the tool
+    # my_print_defaults to avoid raising exceptions. This is used for
+    # optimization purposes, to reuse data and avoid repeating the execution of
+    # some methods in the parse_connection method (e.g. searching for
+    # my_print_defaults).
+    config_reader = MyDefaultsReader(options, False)
 
     if options.master:
         try:
-            master_val = parse_connection(options.master)
+            master_val = parse_connection(options.master, config_reader,
+                                          options)
         except FormatError, e:
-            msg = "Master connection values invalid or cannot be parsed."
+            msg = ("Master connection values invalid or cannot be parsed: %s "
+                   "(%s)." % (options.master, e))
+            raise UtilRplError(msg)
+        except UtilError, e:
+            msg = ("Master connection values invalid or cannot be parsed: %s "
+                   "(using login-path authentication: %s)" % (options.master,
+                                                              e.errmsg))
             raise UtilRplError(msg)
     else:
         master_val = None
@@ -71,11 +87,15 @@ def parse_failover_connections(options):
         slaves = options.slaves.split(",")
         for slave in slaves:
             try:
-                s_values = parse_connection(slave)
+                s_values = parse_connection(slave, config_reader, options)
                 slaves_val.append(s_values)
             except FormatError, e:
-                msg = "Slave connection values invalid or " + \
-                      "cannot be parsed: %s" % slave
+                msg = ("Slave connection values invalid or cannot be parsed: "
+                       "%s (%s)" % (slave, e))
+                raise UtilRplError(msg)
+            except UtilError, e:
+                msg = ("Slave connection values invalid or cannot be parsed: "
+                       "%s (%s)" % (slave, e.errmsg))
                 raise UtilRplError(msg)
     
     candidates_val = []
@@ -83,12 +103,16 @@ def parse_failover_connections(options):
         candidates = options.candidates.split(",")
         for slave in candidates:
             try:
-                s_values = parse_connection(slave)
+                s_values = parse_connection(slave, config_reader, options)
                 candidates_val.append(s_values)
             except FormatError, e:
                 msg = "Candidate connection values invalid or " + \
                       "cannot be parsed: %s" % slave
                 raise UtilRplError(msg)
+            except UtilError, e:
+                msg = ("Candidate connection values invalid or cannot be "
+                       "parsed: %s (%s)" % (slave, e.errmsg))
+                raise UtilRplError(msg)
                 
     return (master_val, slaves_val, candidates_val)
 
@@ -145,7 +169,7 @@ class Topology(Replication):
         self.force = self.options.get("force", False)
         self.before_script = self.options.get("before", None)
         self.after_script = self.options.get("after", None)
-        self.timeout = self.options.get("timeout", 3)
+        self.timeout = int(self.options.get("timeout", 300))
         self.logging = self.options.get("logging", False)
         self.rpl_user = self.options.get("rpl_user", None)
         
@@ -311,13 +335,9 @@ class Topology(Replication):
         if discover is None:
             return
         
-        # Get user and password
-        try:
-            user, password = discover.split(":")
-        except ValueError:
-            user = discover
-            password = None
-            
+        # Get user and password (support login-path)
+        user, password = parse_user_password(discover, options=self.options)
+
         # Find discovered slaves
         new_slaves_found = False
         self._report("# Discovering slaves for master at %s:%s" %
@@ -494,12 +514,8 @@ class Topology(Replication):
             user, passwd = slave.get_rpl_user()
             return (user, passwd)
 
-        # Get user and password
-        try:
-            user, passwd =  self.rpl_user.split(":")
-        except ValueError:
-            user = self.rpl_user.strip(":")
-            passwd = None
+        # Get user and password (support login-path)
+        user, passwd = parse_user_password(self.rpl_user, options=self.options)
         return (user, passwd)
     
     
@@ -1214,7 +1230,6 @@ class Topology(Replication):
         
         Return bool - True = success, raises exception on error
         """
-        from mysql.utilities.common.server import get_connection_dictionary
 
         # Need instance of Master class for operation
         m_candidate = self.connect_candidate(candidate)
@@ -1505,6 +1520,17 @@ class Topology(Replication):
                 self._report(msg, logging.CRITICAL)
                 raise UtilRplError(msg)
 
+        # We must also ensure the new master and all remaining slaves
+        # have the latest GTID support.
+        new_master.check_gtid_version()
+        for slave_dict in self.slaves:
+            # Ignore dead or offline slaves
+            slave = slave_dict['instance']
+            # skip dead or zombie slaves
+            if slave is None or not slave.is_alive():
+                continue
+            slave.check_gtid_version()
+
         host = new_master_dict['host']
         port = new_master_dict['port']
         self._report("# Candidate slave %s:%s will become the new master." % 
