@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #
-# Copyright (c) 2011, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2011, 2013, Oracle and/or its affiliates. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,14 +21,16 @@ This file contains the object diff utility which allows users to compare the
 definitions of two objects and return the difference (like diff).
 """
 
-import optparse
+
 import os
 import re
 import sys
-from mysql.utilities import VERSION_FRM
+
 from mysql.utilities.command.diff import object_diff, database_diff
 from mysql.utilities.common.options import parse_connection, add_difftype
 from mysql.utilities.common.options import add_verbosity, check_verbosity
+from mysql.utilities.common.options import add_changes_for, add_reverse
+from mysql.utilities.common.options import setup_common_options
 from mysql.utilities.exception import UtilError
 
 # Constants
@@ -40,24 +42,22 @@ USAGE = "%prog --server1=user:pass@host:port:socket " + \
 PRINT_WIDTH = 75
 
 # Setup the command parser
-parser = optparse.OptionParser(
-    version=VERSION_FRM.format(program=os.path.basename(sys.argv[0])),
-    description=DESCRIPTION,
-    usage=USAGE,
-    add_help_option=False)
-parser.add_option("--help", action="help")
+parser = setup_common_options(os.path.basename(sys.argv[0]),
+                              DESCRIPTION, USAGE, False, False)
 
 # Connection information for the source server
 parser.add_option("--server1", action="store", dest="server1",
                   type="string", default="root@localhost:3306",
-                  help="connection information for first server in " + \
-                  "the form: <user>:<password>@<host>:<port>:<socket>")
+                  help="connection information for first server in "
+                  "the form: <user>[:<password>]@<host>[:<port>][:<socket>]"
+                  " or <login-path>[:<port>][:<socket>].")
 
 # Connection information for the destination server
 parser.add_option("--server2", action="store", dest="server2",
                   type="string", default=None,
-                  help="connection information for second server in " + \
-                  "the form: <user>:<password>@<host>:<port>:<socket>")
+                  help="connection information for second server in "
+                  "the form: <user>[:<password>]@<host>[:<port>][:<socket>]"
+                  " or <login-path>[:<port>][:<socket>].")
 
 # Add display width option
 parser.add_option("--width", action="store", dest="width",
@@ -71,8 +71,14 @@ parser.add_option("--force", action="store_true", dest="force",
 # Add verbosity and quiet (silent) mode
 add_verbosity(parser, True)
 
-# Add difftype option
-add_difftype(parser)
+# Add difftype option with SQL option
+add_difftype(parser, True)
+
+# Add the direction (changes-for)
+add_changes_for(parser)
+
+# Add show reverse option
+add_reverse(parser)
 
 # Now we process the rest of the arguments.
 opt, args = parser.parse_args()
@@ -86,21 +92,27 @@ options = {
     "verbosity"        : opt.verbosity,
     "difftype"         : opt.difftype,
     "force"            : opt.force,
-    "width"            : opt.width
+    "width"            : opt.width,
+    "changes-for"      : opt.changes_for,
+    "reverse"          : opt.reverse,
 }
 
 # Parse server connection values
 try:
-    server1_values = parse_connection(opt.server1)
+    server1_values = parse_connection(opt.server1, None, options)
 except:
     parser.error("Server1 connection values invalid or cannot be parsed.")
 if opt.server2 is not None:
     try:
-        server2_values = parse_connection(opt.server2)
+        server2_values = parse_connection(opt.server2, None, options)
     except:
         parser.error("Server2 connection values invalid or cannot be parsed.")
 else:
     server2_values = None
+    
+# Check for arguments
+if len(args) == 0:
+    parser.error("No objects specified to compare.")
 
 # run the diff
 diff_failed = False
@@ -140,7 +152,7 @@ for argument in args:
 
 if diff_failed:
     if not opt.quiet:
-        print "Diff failed. One or more differences found."
+        print "Compare failed. One or more differences found."
     exit(1)            
 
 if not opt.quiet:
