@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #
-# Copyright (c) 2011, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2011, 2013, Oracle and/or its affiliates. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,7 +13,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 #
 
 """
@@ -21,17 +21,18 @@ This file contains the disk usage utility for showing the estimated disk
 storage of the databases and system files.
 """
 
-import optparse
+
 import os
-import re
 import sys
 import time
-from mysql.utilities import VERSION_FRM
+
 from mysql.utilities.command import diskusage
 from mysql.utilities.common.options import parse_connection
 from mysql.utilities.common.options import setup_common_options
 from mysql.utilities.common.options import add_verbosity
-from mysql.utilities.exception import MySQLUtilError
+from mysql.utilities.common.options import add_format_option
+from mysql.utilities.common.server import connect_servers
+from mysql.utilities.exception import UtilError
 
 # Constants
 NAME = "MySQL Utilities - mysqldiskusage "
@@ -39,7 +40,7 @@ DESCRIPTION = "mysqldiskusage - show disk usage for databases"
 USAGE = "%prog --server=user:pass@host:port:socket db1 --all"
 
 def print_elapsed_time(start_test):
-    """ Print the elapsed time to stdout (screen)
+    """Print the elapsed time to stdout (screen)
 
     start_test[in]      The starting time of the test
     """
@@ -49,16 +50,15 @@ def print_elapsed_time(start_test):
         display_time = 1
     print("Time: %6d\n" % display_time)
 
-# Setup the command parser and setup server, helpe
+# Setup the command parser and setup server, help
 parser = setup_common_options(os.path.basename(sys.argv[0]),
                               DESCRIPTION, USAGE)
 
 # Setup utility-specific options:
 
-# Input format
-parser.add_option("-f", "--format", action="store", dest="format",
-                  help="display the output in either GRID (default), "
-                       "TAB, CSV, or VERTICAL format", default="GRID")
+# Output format
+add_format_option(parser, "display the output in either grid (default), "
+                  "tab, csv, or vertical format", "grid")     
 
 # Header row
 parser.add_option("-h", "--no-headers", action="store_true", dest="no_headers",
@@ -96,38 +96,29 @@ add_verbosity(parser, True)
 # Now we process the rest of the arguments.
 opt, args = parser.parse_args()
 
-_PERMITTED_FORMATS = ("GRID", "TAB", "CSV", "VERTICAL")
-
-if opt.format.upper() not in _PERMITTED_FORMATS:
-    print "# WARNING : '%s' is not a valid output format. Using default." % \
-          opt.format
-    opt.format = "GRID"
-else:
-    opt.format = opt.format.upper()
-
-from mysql.utilities.common.server import connect_servers
-
 # Parse source connection values
 try:
-    source_values = parse_connection(opt.server)
+    source_values = parse_connection(opt.server, None, opt)
 except:
     parser.error("Source connection values invalid or cannot be parsed.")
 
 try:
-    servers = connect_servers(source_values, None, False, "5.1.30")
-    #print servers
-except MySQLUtilError, e:
+    conn_options = {
+        'version'   : "5.1.30",
+    }
+    servers = connect_servers(source_values, None)
+except UtilError, e:
     parser.error(e.errmsg)
 
 try:
     res = servers[0].show_server_variable("datadir")
     datadir = res[0][1]
-except MySQLUtilError, e:
+except UtilError, e:
     parser.error(e.errmsg)
 
 if not os.access(datadir, os.R_OK):
     print "\nNOTICE: Your user account does not have read access to the " + \
-          "datadir. Data sizes will be \ncalculated and actual file sizes " + \
+          "datadir. Data sizes will be calculated and actual file sizes " + \
           "may be omitted. Some features may be unavailable.\n"
 
 # Set options for database operations.
@@ -145,7 +136,7 @@ options = {
 # We do database disk usage by default.
 try:
     diskusage.show_database_usage(servers[0], datadir, args, options)
-except MySQLUtilError, e:
+except UtilError, e:
     print "ERROR:", e.errmsg
     exit(1)
 
@@ -153,7 +144,7 @@ except MySQLUtilError, e:
 if opt.do_logs or opt.do_all:
     try:
         diskusage.show_logfile_usage(servers[0], options)
-    except MySQLUtilError, e:
+    except UtilError, e:
         print "ERROR:", e.errmsg
         exit(1)
 
@@ -162,7 +153,7 @@ if opt.do_binlog or opt.do_all:
     try:
         options["log_type"] = 'binary log'
         diskusage.show_log_usage(servers[0], datadir, options)
-    except MySQLUtilError, e:
+    except UtilError, e:
         print "ERROR:", e.errmsg
         exit(1)
 
@@ -171,7 +162,7 @@ if opt.do_relaylog or opt.do_all:
     try:
         options["log_type"] = 'relay log'
         diskusage.show_log_usage(servers[0], datadir, options)
-    except MySQLUtilError, e:
+    except UtilError, e:
         print "ERROR:", e.errmsg
         exit(1)
 
@@ -179,7 +170,7 @@ if opt.do_relaylog or opt.do_all:
 if opt.do_innodb or opt.do_all:
     try:
         diskusage.show_innodb_usage(servers[0], datadir, options)
-    except MySQLUtilError, e:
+    except UtilError, e:
         print "ERROR:", e.errmsg
         exit(1)
 
