@@ -92,48 +92,6 @@ Scintilla::Point Scintilla::Point::FromLong(long lpoint)
                           );
 }
 
-//----------------- Palette ------------------------------------------------------------------------
-
-// The Palette implementation is only here because we would get linker errors if not.
-// We don't use indexed colors in ScintillaCocoa.
-
-Scintilla::Palette::Palette()
-{
-}
-
-//--------------------------------------------------------------------------------------------------
-
-Scintilla::Palette::~Palette()
-{
-}
-
-//--------------------------------------------------------------------------------------------------
-
-void Scintilla::Palette::Release()
-{
-}
-
-//--------------------------------------------------------------------------------------------------
-
-/**
- * Used to transform a given color, if needed. If the caller tries to find a color that matches the
- * desired color then we simply pass it on, as we support the full color space.
- */
-void Scintilla::Palette::WantFind(ColourPair &cp, bool want)
-{
-  if (!want)
-    cp.allocated.Set(cp.desired.AsLong());
-  
-  // Don't do anything if the caller wants the color it has already set.
-}
-
-//--------------------------------------------------------------------------------------------------
-
-void Scintilla::Palette::Allocate(Window&)
-{
-  // Nothing to allocate as we don't use palettes.
-}
-
 //----------------- Font ---------------------------------------------------------------------------
 
 Font::Font(): fid(0)
@@ -156,8 +114,7 @@ static int FontCharacterSet(Font &f) {
 /**
  * Creates a CTFontRef with the given properties.
  */
-void Font::Create(const char *faceName, int characterSet, int size, bool bold, bool italic, 
-                  int /* extraFontFlag */)
+void Font::Create(const FontParameters &fp)
 {
 	Release();
 
@@ -165,9 +122,9 @@ void Font::Create(const char *faceName, int characterSet, int size, bool bold, b
 	fid = style;
 
 	// Create the font with attributes
-	QuartzFont font(faceName, strlen(faceName), size, bold, italic);
+	QuartzFont font(fp.faceName, strlen(fp.faceName), fp.size, fp.weight, fp.italic);
 	CTFontRef fontRef = font.getFontID();
-	style->setFontRef(fontRef, characterSet);
+	style->setFontRef(fontRef, fp.characterSet);
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -314,7 +271,7 @@ void SurfaceImpl::InitPixMap(int width, int height, Surface* /* surface_ */, Win
 
 //--------------------------------------------------------------------------------------------------
 
-void SurfaceImpl::PenColour(ColourAllocated fore)
+void SurfaceImpl::PenColour(ColourDesired fore)
 {
   if (gc)
   {
@@ -328,7 +285,7 @@ void SurfaceImpl::PenColour(ColourAllocated fore)
 
 //--------------------------------------------------------------------------------------------------
 
-void SurfaceImpl::FillColour(const ColourAllocated& back)
+void SurfaceImpl::FillColour(const ColourDesired& back)
 {
   if (gc)
   {
@@ -400,27 +357,23 @@ CGImageRef SurfaceImpl::GetImage()
 
 /**
  * Returns the vertical logical device resolution of the main monitor.
+ * This is no longer called.
+ * For Cocoa, all screens are treated as 72 DPI, even retina displays.
  */
 int SurfaceImpl::LogPixelsY()
 {
-  if (verticalDeviceResolution == 0)
-  {
-    NSSize deviceResolution = [[[[NSScreen mainScreen] deviceDescription]
-    objectForKey: NSDeviceResolution] sizeValue];
-    verticalDeviceResolution = (int) deviceResolution.height;
-  }
-  return verticalDeviceResolution;
+  return 72;
 }
 
 //--------------------------------------------------------------------------------------------------
 
 /**
- * Converts the logical font height (in dpi) into a pixel height for the current main screen.
+ * Converts the logical font height in points into a device height.
+ * For Cocoa, points are always used for the result even on retina displays.
  */
 int SurfaceImpl::DeviceHeightFont(int points)
 {
-  int logPix = LogPixelsY();
-  return (points * logPix + logPix / 2) / 72;
+  return points;
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -451,8 +404,8 @@ void SurfaceImpl::LineTo(int x_, int y_)
 
 //--------------------------------------------------------------------------------------------------
 
-void SurfaceImpl::Polygon(Scintilla::Point *pts, int npts, ColourAllocated fore,
-                          ColourAllocated back)
+void SurfaceImpl::Polygon(Scintilla::Point *pts, int npts, ColourDesired fore,
+                          ColourDesired back)
 {
   // Allocate memory for the array of points.
   CGPoint *points = new CGPoint[npts];
@@ -484,7 +437,7 @@ void SurfaceImpl::Polygon(Scintilla::Point *pts, int npts, ColourAllocated fore,
 
 //--------------------------------------------------------------------------------------------------
 
-void SurfaceImpl::RectangleDraw(PRectangle rc, ColourAllocated fore, ColourAllocated back)
+void SurfaceImpl::RectangleDraw(PRectangle rc, ColourDesired fore, ColourDesired back)
 {
   if (gc)
   {
@@ -502,11 +455,14 @@ void SurfaceImpl::RectangleDraw(PRectangle rc, ColourAllocated fore, ColourAlloc
 
 //--------------------------------------------------------------------------------------------------
 
-void SurfaceImpl::FillRectangle(PRectangle rc, ColourAllocated back)
+void SurfaceImpl::FillRectangle(PRectangle rc, ColourDesired back)
 {
   if (gc)
   {
     FillColour(back);
+    // Snap rectangle boundaries to nearest int
+    rc.left = lround(rc.left);
+    rc.right = lround(rc.right);
     CGRect rect = PRectangleToCGRect(rc);
     CGContextFillRect(gc, rect);
   }
@@ -521,6 +477,13 @@ void drawImageRefCallback(CGImageRef pattern, CGContextRef gc)
 
 //--------------------------------------------------------------------------------------------------
 
+void releaseImageRefCallback(CGImageRef pattern)
+{
+  CGImageRelease(pattern);
+}
+
+//--------------------------------------------------------------------------------------------------
+
 void SurfaceImpl::FillRectangle(PRectangle rc, Surface &surfacePattern)
 {
   SurfaceImpl& patternSurface = static_cast<SurfaceImpl &>(surfacePattern);
@@ -529,12 +492,13 @@ void SurfaceImpl::FillRectangle(PRectangle rc, Surface &surfacePattern)
   CGImageRef image = patternSurface.GetImage();
   if (image == NULL)
   {
-    FillRectangle(rc, ColourAllocated(0));
+    FillRectangle(rc, ColourDesired(0));
     return;
   }
   
-  const CGPatternCallbacks drawImageCallbacks = { 0, 
-    reinterpret_cast<CGPatternDrawPatternCallback>(drawImageRefCallback), NULL };
+  const CGPatternCallbacks drawImageCallbacks = { 0,
+    reinterpret_cast<CGPatternDrawPatternCallback>(drawImageRefCallback),
+    reinterpret_cast<CGPatternReleaseInfoCallback>(releaseImageRefCallback) };
   
   CGPatternRef pattern = CGPatternCreate(image,
                                          CGRectMake(0, 0, patternSurface.bitmapWidth, patternSurface.bitmapHeight),
@@ -566,12 +530,10 @@ void SurfaceImpl::FillRectangle(PRectangle rc, Surface &surfacePattern)
     colorSpace = NULL;
     CGPatternRelease( pattern );
     pattern = NULL;
-    CGImageRelease( image );
-    image = NULL;
   } /* pattern != NULL */
 }
 
-void SurfaceImpl::RoundedRectangle(PRectangle rc, ColourAllocated fore, ColourAllocated back) {
+void SurfaceImpl::RoundedRectangle(PRectangle rc, ColourDesired fore, ColourDesired back) {
   // This is only called from the margin marker drawing code for SC_MARK_ROUNDRECT
   // The Win32 version does
   //  ::RoundRect(hdc, rc.left + 1, rc.top, rc.right - 1, rc.bottom, 8, 8 );
@@ -611,11 +573,13 @@ void SurfaceImpl::RoundedRectangle(PRectangle rc, ColourAllocated fore, ColourAl
   };
   
   // Align the points in the middle of the pixels
-  for( int i = 0; i < 4*3; ++ i )
+  for( int i = 0; i < 4; ++ i )
   {
-    CGPoint* c = (CGPoint*) corners;
-    c[i].x += 0.5;
-    c[i].y += 0.5;
+    for( int j = 0; j < 3; ++ j )
+    {
+      corners[i][j].x += 0.5;
+      corners[i][j].y += 0.5;
+    }
   }
   
   PenColour( fore );
@@ -636,12 +600,15 @@ void SurfaceImpl::RoundedRectangle(PRectangle rc, ColourAllocated fore, ColourAl
   CGContextDrawPath( gc, kCGPathFillStroke );
 }
 
-void Scintilla::SurfaceImpl::AlphaRectangle(PRectangle rc, int /*cornerSize*/, ColourAllocated fill, int alphaFill,
-                                            ColourAllocated /*outline*/, int /*alphaOutline*/, int /*flags*/)
+void Scintilla::SurfaceImpl::AlphaRectangle(PRectangle rc, int /*cornerSize*/, ColourDesired fill, int alphaFill,
+                                            ColourDesired /*outline*/, int /*alphaOutline*/, int /*flags*/)
 {
   if ( gc ) {
     ColourDesired colour( fill.AsLong() );
-    
+ 
+    // Snap rectangle boundaries to nearest int
+    rc.left = lround(rc.left);
+    rc.right = lround(rc.right);
     // Set the Fill color to match
     CGContextSetRGBFillColor( gc, colour.GetRed() / 255.0, colour.GetGreen() / 255.0, colour.GetBlue() / 255.0, alphaFill / 255.0 );
     CGRect rect = PRectangleToCGRect( rc );
@@ -649,7 +616,12 @@ void Scintilla::SurfaceImpl::AlphaRectangle(PRectangle rc, int /*cornerSize*/, C
   }
 }
 
-static CGImageRef ImageFromRGBA(int width, int height, const unsigned char *pixelsImage, bool invert) {
+static void ProviderReleaseData(void *, const void *data, size_t) {
+	const unsigned char *pixels = reinterpret_cast<const unsigned char *>(data);
+	delete []pixels;
+}
+
+static CGImageRef ImageCreateFromRGBA(int width, int height, const unsigned char *pixelsImage, bool invert) {
 	CGImageRef image = 0;
 
 	// Create an RGB color space.
@@ -660,9 +632,8 @@ static CGImageRef ImageFromRGBA(int width, int height, const unsigned char *pixe
 		
 		// Create a data provider.
 		CGDataProviderRef dataProvider = 0;
-		unsigned char *pixelsUpsideDown = 0;
 		if (invert) {
-			pixelsUpsideDown = new unsigned char[bitmapByteCount];
+			unsigned char *pixelsUpsideDown = new unsigned char[bitmapByteCount];
 		
 			for (int y=0; y<height; y++) {
 				int yInverse = height - y - 1;
@@ -672,7 +643,7 @@ static CGImageRef ImageFromRGBA(int width, int height, const unsigned char *pixe
 			}
 			
 			dataProvider = CGDataProviderCreateWithData(
-								NULL, pixelsUpsideDown, bitmapByteCount, NULL);
+								NULL, pixelsUpsideDown, bitmapByteCount, ProviderReleaseData);
 		} else {
 			dataProvider = CGDataProviderCreateWithData(
 								NULL, pixelsImage, bitmapByteCount, NULL);
@@ -694,7 +665,6 @@ static CGImageRef ImageFromRGBA(int width, int height, const unsigned char *pixe
 
 			CGDataProviderRelease(dataProvider);
 		}
-		delete []pixelsUpsideDown;
 		
 		// The image retains the color space, so we can release it.
 		CGColorSpaceRelease(colorSpace);
@@ -702,21 +672,16 @@ static CGImageRef ImageFromRGBA(int width, int height, const unsigned char *pixe
 	return image;
 }
 
-void SurfaceImpl::DrawRGBAImage(PRectangle /* rc */, int width, int height, const unsigned char *pixelsImage) {
-	CGImageRef image = ImageFromRGBA(width, height, pixelsImage, true);
+void SurfaceImpl::DrawRGBAImage(PRectangle rc, int width, int height, const unsigned char *pixelsImage) {
+	CGImageRef image = ImageCreateFromRGBA(width, height, pixelsImage, true);
 	if (image) {
-		//CGContextSaveGState(gc);
-		//CGRect dst = PRectangleToCGRect(rc);
-		//CGContextClipToRect(gc, dst);
-		CGRect drawRect = CGRectMake (0, 0, width, height);
+		CGRect drawRect = CGRectMake(rc.left, rc.top, rc.Width(), rc.Height());
 		CGContextDrawImage(gc, drawRect, image);
-		//CGContextRestoreGState (gc);
-		
 		CGImageRelease(image);
 	}
 }
 
-void SurfaceImpl::Ellipse(PRectangle rc, ColourAllocated fore, ColourAllocated back) {
+void SurfaceImpl::Ellipse(PRectangle rc, ColourDesired fore, ColourDesired back) {
   // Drawing an ellipse with bezier curves. Code modified from:
   // http://www.codeguru.com/gdi/ellipse.shtml
   // MAGICAL CONSTANT to map ellipse to beziers 2/3*(sqrt(2)-1)
@@ -813,7 +778,7 @@ void SurfaceImpl::Copy(PRectangle rc, Scintilla::Point from, Surface &surfaceSou
   // If we could not get an image reference, fill the rectangle black
   if ( image == NULL )
   {
-    FillRectangle( rc, ColourAllocated( 0 ) );
+    FillRectangle( rc, ColourDesired( 0 ) );
     return;
   }
   
@@ -836,8 +801,8 @@ void SurfaceImpl::Copy(PRectangle rc, Scintilla::Point from, Surface &surfaceSou
 
 //--------------------------------------------------------------------------------------------------
 
-void SurfaceImpl::DrawTextNoClip(PRectangle rc, Font &font_, int ybase, const char *s, int len,
-                                 ColourAllocated fore, ColourAllocated back)
+void SurfaceImpl::DrawTextNoClip(PRectangle rc, Font &font_, XYPOSITION ybase, const char *s, int len,
+                                 ColourDesired fore, ColourDesired back)
 {
   FillRectangle(rc, back);
   DrawTextTransparent(rc, font_, ybase, s, len, fore);
@@ -845,8 +810,8 @@ void SurfaceImpl::DrawTextNoClip(PRectangle rc, Font &font_, int ybase, const ch
 
 //--------------------------------------------------------------------------------------------------
 
-void SurfaceImpl::DrawTextClipped(PRectangle rc, Font &font_, int ybase, const char *s, int len,
-                                  ColourAllocated fore, ColourAllocated back)
+void SurfaceImpl::DrawTextClipped(PRectangle rc, Font &font_, XYPOSITION ybase, const char *s, int len,
+                                  ColourDesired fore, ColourDesired back)
 {
   CGContextSaveGState(gc);
   CGContextClipToRect(gc, PRectangleToCGRect(rc));
@@ -913,8 +878,8 @@ CFStringEncoding EncodingFromCharacterSet(bool unicode, int characterSet)
   }
 }
 
-void SurfaceImpl::DrawTextTransparent(PRectangle rc, Font &font_, int ybase, const char *s, int len, 
-                                      ColourAllocated fore)
+void SurfaceImpl::DrawTextTransparent(PRectangle rc, Font &font_, XYPOSITION ybase, const char *s, int len, 
+                                      ColourDesired fore)
 {
 	CFStringEncoding encoding = EncodingFromCharacterSet(unicodeMode, FontCharacterSet(font_));
 	ColourDesired colour(fore.AsLong());
@@ -943,7 +908,7 @@ static size_t utf8LengthFromLead(unsigned char uch) {
 
 //--------------------------------------------------------------------------------------------------
 
-void SurfaceImpl::MeasureWidths(Font &font_, const char *s, int len, int *positions)
+void SurfaceImpl::MeasureWidths(Font &font_, const char *s, int len, XYPOSITION *positions)
 {
 	CFStringEncoding encoding = EncodingFromCharacterSet(unicodeMode, FontCharacterSet(font_));
 	textLayout->setText (reinterpret_cast<const UInt8*>(s), len, encoding, *reinterpret_cast<QuartzTextStyle*>(font_.GetID()));
@@ -962,7 +927,7 @@ void SurfaceImpl::MeasureWidths(Font &font_, const char *s, int len, int *positi
 			size_t codeUnits = (lenChar < 4) ? 1 : 2;
 			CGFloat xPosition = CTLineGetOffsetForStringIndex(mLine, ui+1, NULL);
 			for (unsigned int bytePos=0; (bytePos<lenChar) && (i<len); bytePos++) {
-				positions[i++] = static_cast<int>(lround(xPosition));
+				positions[i++] = xPosition;
 			}
 			ui += codeUnits;
 		}
@@ -978,20 +943,20 @@ void SurfaceImpl::MeasureWidths(Font &font_, const char *s, int len, int *positi
 			size_t lenChar = Platform::IsDBCSLeadByte(codePage, s[i]) ? 2 : 1;
 			CGFloat xPosition = CTLineGetOffsetForStringIndex(mLine, ui+1, NULL);
 			for (unsigned int bytePos=0; (bytePos<lenChar) && (i<len); bytePos++) {
-				positions[i++] = static_cast<int>(lround(xPosition));
+				positions[i++] = xPosition;
 			}
 			ui++;
 		}
 	} else {	// Single byte encoding
 		for (int i=0;i<len;i++) {
 			CGFloat xPosition = CTLineGetOffsetForStringIndex(mLine, i+1, NULL);
-			positions[i] = static_cast<int>(lround(xPosition));
+			positions[i] = xPosition;
 		}
 	}
 
 }
 
-int SurfaceImpl::WidthText(Font &font_, const char *s, int len) {
+XYPOSITION SurfaceImpl::WidthText(Font &font_, const char *s, int len) {
   if (font_.GetID())
   {
     CFStringEncoding encoding = EncodingFromCharacterSet(unicodeMode, FontCharacterSet(font_));
@@ -1002,7 +967,7 @@ int SurfaceImpl::WidthText(Font &font_, const char *s, int len) {
   return 1;
 }
 
-int SurfaceImpl::WidthChar(Font &font_, char ch) {
+XYPOSITION SurfaceImpl::WidthChar(Font &font_, char ch) {
   char str[2] = { ch, '\0' };
   if (font_.GetID())
   {
@@ -1019,7 +984,7 @@ int SurfaceImpl::WidthChar(Font &font_, char ch) {
 const char sizeString[] = "`~!@#$%^&*()-_=+\\|[]{};:\"\'<,>.?/1234567890"
 "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ";
 
-int SurfaceImpl::Ascent(Font &font_) {
+XYPOSITION SurfaceImpl::Ascent(Font &font_) {
   if (!font_.GetID())
     return 1;
   
@@ -1028,7 +993,7 @@ int SurfaceImpl::Ascent(Font &font_) {
 
 }
 
-int SurfaceImpl::Descent(Font &font_) {
+XYPOSITION SurfaceImpl::Descent(Font &font_) {
   if (!font_.GetID())
     return 1;
   
@@ -1037,11 +1002,11 @@ int SurfaceImpl::Descent(Font &font_) {
 
 }
 
-int SurfaceImpl::InternalLeading(Font &) {
+XYPOSITION SurfaceImpl::InternalLeading(Font &) {
   return 0;
 }
 
-int SurfaceImpl::ExternalLeading(Font &font_) {
+XYPOSITION SurfaceImpl::ExternalLeading(Font &font_) {
   if (!font_.GetID())
     return 1;
   
@@ -1050,13 +1015,13 @@ int SurfaceImpl::ExternalLeading(Font &font_) {
 
 }
 
-int SurfaceImpl::Height(Font &font_) {
+XYPOSITION SurfaceImpl::Height(Font &font_) {
 
 	int ht = Ascent(font_) + Descent(font_);
 	return ht;
 }
 
-int SurfaceImpl::AverageCharWidth(Font &font_) {
+XYPOSITION SurfaceImpl::AverageCharWidth(Font &font_) {
   
   if (!font_.GetID())
     return 1;
@@ -1067,11 +1032,6 @@ int SurfaceImpl::AverageCharWidth(Font &font_) {
   return (int) ((width / (float) sizeStringLength) + 0.5);
 }
 
-int SurfaceImpl::SetPalette(Scintilla::Palette *, bool) {
-  // Mac OS X is always true colour (I think) so this doesn't matter
-  return 0;
-}
-
 void SurfaceImpl::SetClip(PRectangle rc) {
   CGContextClipToRect( gc, PRectangleToCGRect( rc ) );
 }
@@ -1089,7 +1049,7 @@ void SurfaceImpl::SetDBCSMode(int codePage_) {
     codePage = codePage_;
 }
 
-Surface *Surface::Allocate()
+Surface *Surface::Allocate(int)
 {
   return new SurfaceImpl();
 }
@@ -1149,9 +1109,8 @@ PRectangle Window::GetPosition()
       // NSView
       NSView* view = reinterpret_cast<NSView*>(idWin);
       win = [view window];
-      rect = [view bounds];
-      rect = [view convertRectToBase: rect];
-      rect.origin = [win convertBaseToScreen:rect.origin];
+      rect = [view convertRect: [view bounds] toView: nil];
+      rect.origin = [win convertBaseToScreen: rect.origin];
     }
     else
     {
@@ -1368,17 +1327,15 @@ static NSImage* ImageFromXPM(XPM* pxpm)
     const int width = pxpm->GetWidth();
     const int height = pxpm->GetHeight();
     PRectangle rcxpm(0, 0, width, height);
-    Surface* surfaceXPM = Surface::Allocate();
+    Surface* surfaceXPM = Surface::Allocate(SC_TECHNOLOGY_DEFAULT);
     if (surfaceXPM)
     {
       surfaceXPM->InitPixMap(width, height, NULL, NULL);
       SurfaceImpl* surfaceIXPM = static_cast<SurfaceImpl*>(surfaceXPM);
       CGContextClearRect(surfaceIXPM->GetContext(), CGRectMake(0, 0, width, height));
       pxpm->Draw(surfaceXPM, rcxpm);
-      img = [NSImage alloc];
-      [img autorelease];
+      img = [[[NSImage alloc] initWithSize:NSZeroSize] autorelease];
       CGImageRef imageRef = surfaceIXPM->GetImage();
-      [img initWithSize:NSZeroSize];
       NSBitmapImageRep *bitmapRep = [[NSBitmapImageRep alloc] initWithCGImage: imageRef];
       [img addRepresentation: bitmapRep];
       [bitmapRep release];
@@ -1389,19 +1346,85 @@ static NSImage* ImageFromXPM(XPM* pxpm)
   return img;
 }
 
-//----------------- ListBox ------------------------------------------------------------------------
+//----------------- ListBox and related classes ----------------------------------------------------
 
-ListBox::ListBox()
+namespace {
+
+// unnamed namespace hides IListBox interface
+
+class IListBox {
+public:
+  virtual int Rows() = 0;
+  virtual NSImage* ImageForRow(NSInteger row) = 0;
+  virtual NSString* TextForRow(NSInteger row) = 0;
+  virtual void DoubleClick() = 0;
+};
+
+} // unnamed namespace
+
+//----------------- AutoCompletionDataSource -------------------------------------------------------
+
+@interface AutoCompletionDataSource :
+NSObject
+#if MAC_OS_X_VERSION_MAX_ALLOWED > MAC_OS_X_VERSION_10_5
+<NSTableViewDataSource>
+#endif
 {
+  IListBox* box;
 }
 
-//--------------------------------------------------------------------------------------------------
+@property IListBox* box;
 
-ListBox::~ListBox()
+@end
+
+@implementation AutoCompletionDataSource
+
+@synthesize box;
+
+- (void) doubleClick: (id) sender
 {
+#pragma unused(sender)
+	if (box)
+	{
+		box->DoubleClick();
+	}
 }
 
-//--------------------------------------------------------------------------------------------------
+- (id)tableView: (NSTableView*)aTableView objectValueForTableColumn: (NSTableColumn*)aTableColumn row: (NSInteger)rowIndex
+{
+#pragma unused(aTableView)
+	if (!box)
+		return nil;
+	if ([(NSString*)[aTableColumn identifier] isEqualToString: @"icon"])
+	{
+		return box->ImageForRow(rowIndex);
+	}
+	else {
+		return box->TextForRow(rowIndex);
+	}
+}
+
+- (void)tableView: (NSTableView*)aTableView setObjectValue: anObject forTableColumn: (NSTableColumn*)aTableColumn row: (NSInteger)rowIndex
+{
+#pragma unused(aTableView)
+#pragma unused(anObject)
+#pragma unused(aTableColumn)
+#pragma unused(rowIndex)
+}
+
+- (NSInteger)numberOfRowsInTableView: (NSTableView*)aTableView
+{
+#pragma unused(aTableView)
+	if (!box)
+		return 0;
+	return box->Rows();
+}
+
+@end
+
+//----------------- ListBoxImpl --------------------------------------------------------------------
+
+namespace {	// unnamed namespace hides ListBoxImpl and associated classes
 
 struct RowData
 {
@@ -1459,25 +1482,10 @@ public:
   }
 };
 
-class ListBoxImpl;
-
-@interface AutoCompletionDataSource :
-NSObject
-#if MAC_OS_X_VERSION_MAX_ALLOWED > MAC_OS_X_VERSION_10_5
-<NSTableViewDataSource>
-#endif
-{
-  ListBoxImpl* box;
-}
-
-@end
-
-//----------------- ListBoxImpl --------------------------------------------------------------------
-
 // Map from icon type to an NSImage*
 typedef std::map<NSInteger, NSImage*> ImageMap;
 
-class ListBoxImpl : public ListBox
+class ListBoxImpl : public ListBox, IListBox
 {
 private:
   ControlRef lb;
@@ -1488,14 +1496,15 @@ private:
   unsigned int maxItemWidth;
   unsigned int aveCharWidth;
   unsigned int maxIconWidth;
-  FontAlias font;
+  Font font;
   int maxWidth;
 
   NSTableView* table;
   NSScrollView* scroller;
   NSTableColumn* colIcon;
   NSTableColumn* colText;
-
+  AutoCompletionDataSource* ds;
+	
   LinesData ld;
   CallBackAction doubleClickAction;
   void* doubleClickActionData;
@@ -1506,11 +1515,11 @@ public:
     doubleClickAction(NULL), doubleClickActionData(NULL)
   {
   }
-  ~ListBoxImpl() { ClearRegisteredImages(); }
+  ~ListBoxImpl() {}
 
   // ListBox methods
   void SetFont(Font& font);
-  void Create(Window& parent, int ctrlID, Scintilla::Point pt, int lineHeight_, bool unicodeMode_);
+  void Create(Window& parent, int ctrlID, Scintilla::Point pt, int lineHeight_, bool unicodeMode_, int technology_);
   void SetAverageCharWidth(int width);
   void SetVisibleRows(int rows);
   int GetVisibleRows() const;
@@ -1533,69 +1542,15 @@ public:
   }
   void SetList(const char* list, char separator, char typesep);
 
-  // For access from AutoCompletionDataSource
+  // For access from AutoCompletionDataSource implement IListBox
   int Rows();
   NSImage* ImageForRow(NSInteger row);
   NSString* TextForRow(NSInteger row);
   void DoubleClick();
 };
 
-@implementation AutoCompletionDataSource
-
-- (void)setBox: (ListBoxImpl*)box_
-{
-  box = box_;
-}
-
-- (void) doubleClick: (id) sender
-{
-#pragma unused(sender)
-  if (box)
-  {
-    box->DoubleClick();
-  }
-}
-
-- (id)tableView: (NSTableView*)aTableView objectValueForTableColumn: (NSTableColumn*)aTableColumn row: (NSInteger)rowIndex
-{
-#pragma unused(aTableView)
-  if (!box)
-    return nil;
-  if ([(NSString*)[aTableColumn identifier] isEqualToString: @"icon"])
-  {
-    return box->ImageForRow(rowIndex);
-  }
-  else {
-    return box->TextForRow(rowIndex);
-  }
-}
-
-- (void)tableView: (NSTableView*)aTableView setObjectValue: anObject forTableColumn: (NSTableColumn*)aTableColumn row: (NSInteger)rowIndex
-{
-#pragma unused(aTableView)
-#pragma unused(anObject)
-#pragma unused(aTableColumn)
-#pragma unused(rowIndex)
-}
-
-- (NSInteger)numberOfRowsInTableView: (NSTableView*)aTableView
-{
-#pragma unused(aTableView)
-  if (!box)
-    return 0;
-  return box->Rows();
-}
-
-@end
-
-ListBox* ListBox::Allocate()
-{
-  ListBoxImpl* lb = new ListBoxImpl();
-  return lb;
-}
-
 void ListBoxImpl::Create(Window& /*parent*/, int /*ctrlID*/, Scintilla::Point pt,
-    int lineHeight_, bool unicodeMode_)
+    int lineHeight_, bool unicodeMode_, int)
 {
   lineHeight = lineHeight_;
   unicodeMode = unicodeMode_;
@@ -1608,29 +1563,27 @@ void ListBoxImpl::Create(Window& /*parent*/, int /*ctrlID*/, Scintilla::Point pt
     defer: NO];
   [winLB setLevel:NSFloatingWindowLevel];
   [winLB setHasShadow:YES];
-  [winLB setAlphaValue: 0.9];
   scroller = [NSScrollView alloc];
   NSRect scRect = NSMakeRect(0, 0, lbRect.size.width, lbRect.size.height);
   [scroller initWithFrame: scRect];
   [scroller setHasVerticalScroller:YES];
-  table = [NSTableView alloc];
-  [table initWithFrame: scRect];
+  table = [[NSTableView alloc] initWithFrame: scRect];
   [table setHeaderView:nil];
   [scroller setDocumentView: table];
   colIcon = [[NSTableColumn alloc] initWithIdentifier:@"icon"];
   [colIcon setWidth: 20];
   [colIcon setEditable:NO];
   [colIcon setHidden:YES];
-  NSImageCell* imCell = [[NSImageCell alloc] init];
+  NSImageCell* imCell = [[[NSImageCell alloc] init] autorelease];
   [colIcon setDataCell:imCell];
   [table addTableColumn:colIcon];
   colText = [[NSTableColumn alloc] initWithIdentifier:@"name"];
   [colText setResizingMask:NSTableColumnAutoresizingMask];
   [colText setEditable:NO];
   [table addTableColumn:colText];
-  AutoCompletionDataSource* ds = [[AutoCompletionDataSource alloc] init];
+  ds = [[AutoCompletionDataSource alloc] init];
   [ds setBox:this];
-  [table setDataSource: ds];
+  [table setDataSource: ds];	// Weak reference
   [scroller setAutoresizingMask: NSViewWidthSizable | NSViewHeightSizable];
   [[winLB contentView] addSubview: scroller];
 
@@ -1641,15 +1594,15 @@ void ListBoxImpl::Create(Window& /*parent*/, int /*ctrlID*/, Scintilla::Point pt
 
 void ListBoxImpl::SetFont(Font& font_)
 {
-  font.MakeAlias(font_);
-  
   // NSCell setFont takes an NSFont* rather than a CTFontRef but they
   // are the same thing toll-free bridged.
   QuartzTextStyle* style = reinterpret_cast<QuartzTextStyle*>(font_.GetID());
+  font.Release();
+  font.SetID(new QuartzTextStyle(*style));
   NSFont *pfont = (NSFont *)style->getFontRef();
   [[colText dataCell] setFont: pfont];
   CGFloat itemHeight = ceil([pfont boundingRectForFont].size.height);
-  [table setRowHeight: itemHeight];
+  [table setRowHeight:itemHeight];
 }
 
 void ListBoxImpl::SetAverageCharWidth(int width)
@@ -1824,7 +1777,6 @@ void ListBoxImpl::GetValue(int n, char* value, int len)
 void ListBoxImpl::RegisterImage(int type, const char* xpm_data)
 {
   XPM xpm(xpm_data);
-  xpm.CopyDesiredColours();
   NSImage* img = ImageFromXPM(&xpm);
   [img retain];
   ImageMap::iterator it=images.find(type);
@@ -1840,14 +1792,12 @@ void ListBoxImpl::RegisterImage(int type, const char* xpm_data)
 }
 
 void ListBoxImpl::RegisterRGBAImage(int type, int width, int height, const unsigned char *pixelsImage) {
-	NSImage *img = [NSImage alloc];
-	[img autorelease];
-	CGImageRef imageRef = ImageFromRGBA(width, height, pixelsImage, false);
+	CGImageRef imageRef = ImageCreateFromRGBA(width, height, pixelsImage, false);
 	NSSize sz = {width, height};
-	[img initWithSize: sz];
-  NSBitmapImageRep *bitmapRep = [[NSBitmapImageRep alloc] initWithCGImage: imageRef];
-  [img addRepresentation: bitmapRep];
-  [bitmapRep release];
+	NSImage *img = [[[NSImage alloc] initWithSize: sz] autorelease];
+	NSBitmapImageRep *bitmapRep = [[NSBitmapImageRep alloc] initWithCGImage: imageRef];
+	[img addRepresentation: bitmapRep];
+	[bitmapRep release];
 	CGImageRelease(imageRef);
 	[img retain];
 	ImageMap::iterator it=images.find(type);
@@ -1911,6 +1861,24 @@ void ListBoxImpl::DoubleClick()
   }
 }
 
+} // unnamed namespace
+
+//----------------- ListBox ------------------------------------------------------------------------
+
+ListBox::ListBox()
+{
+}
+
+ListBox::~ListBox()
+{
+}
+
+ListBox* ListBox::Allocate()
+{
+	ListBoxImpl* lb = new ListBoxImpl();
+	return lb;
+}
+
 //----------------- ScintillaContextMenu -----------------------------------------------------------
 
 @implementation ScintillaContextMenu : NSMenu
@@ -1971,8 +1939,7 @@ void Menu::Show(Point, Window &)
 
 ElapsedTime::ElapsedTime() {
   struct timeval curTime;
-  int retVal;
-  retVal = gettimeofday( &curTime, NULL );
+  gettimeofday( &curTime, NULL );
   
   bigBit = curTime.tv_sec;
   littleBit = curTime.tv_usec;
@@ -1980,8 +1947,7 @@ ElapsedTime::ElapsedTime() {
 
 double ElapsedTime::Duration(bool reset) {
   struct timeval curTime;
-  int retVal;
-  retVal = gettimeofday( &curTime, NULL );
+  gettimeofday( &curTime, NULL );
   long endBigBit = curTime.tv_sec;
   long endLittleBit = curTime.tv_usec;
   double result = 1000000.0 * (endBigBit - bigBit);
@@ -2141,7 +2107,7 @@ int Platform::Maximum(int a, int b) {
 
 void Platform::DebugDisplay(const char *s)
 {
-  fprintf( stderr, s );
+  fprintf( stderr, "%s", s );
 }
 
 //--------------------------------------------------------------------------------------------------
