@@ -680,15 +680,15 @@ AdvancedSidebar::AdvancedSidebar()
     _filtered_schema_tree(TreeNoColumns | TreeNoBorder | TreeSidebar | TreeNoHeader),
     _schema_search_box(true),
     _schema_search_text(mforms::SmallSearchEntry),
+    _remote_search_enabled(false),
     _schema_search_warning(_("Showing loaded schemas only")),
     _schema_model(0),
     _base_model(0),
     _is_model_owner(false),
-    _schema_box(false),
-    _remote_search_enabled(false)
+    _schema_box(false)
 {
   _remote_search.set_text(_("Search on Server..."));
-
+  
   _schema_search_warning.set_style(mforms::SmallHelpTextStyle);
   _schema_search_warning.set_text_align(mforms::MiddleCenter);
 
@@ -798,7 +798,7 @@ void AdvancedSidebar::on_search_text_changed()
       _schema_box.remove(&_new_schema_tree);
       set_schema_model(_filtered_schema_model);
       _schema_box.add(&_filtered_schema_tree, true, true);
-      
+
       if (_remote_search_enabled)
         _schema_box.add(&_remote_search, false, true);
       else
@@ -851,7 +851,7 @@ void AdvancedSidebar::on_show_menu()
 {
   _tree_context_menu.clear();
 
-  std::list<mforms::TreeNodeRef> nodes = _new_schema_tree.get_selection();
+  std::list<mforms::TreeNodeRef> nodes = _schema_model == _base_model ? _new_schema_tree.get_selection() : _filtered_schema_tree.get_selection();
   //std::vector<bec::NodeId> nodes;
   //_schema_tree.get_selection(nodes);
   
@@ -872,7 +872,7 @@ void AdvancedSidebar::on_expand_changed(SidebarSection* section)
 
 void AdvancedSidebar::handle_menu_command(const std::string& command)
 {
-  std::list<mforms::TreeNodeRef> nodes = _new_schema_tree.get_selection();
+  std::list<mforms::TreeNodeRef> nodes = _schema_model == _base_model ? _new_schema_tree.get_selection() : _filtered_schema_tree.get_selection();
   
   _schema_model->activate_popup_item_for_nodes(command, nodes);
 }
