@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,31 +21,42 @@
 #define _OUTPUT_VIEW_H_
 
 #include "grt/grt_message_list.h"
-#include "mforms/mforms.h"
-#include "mforms/grttreeview.h"
+
+#include "mforms/treenodeview.h"
 #include "mforms/splitter.h"
 #include "mforms/menu.h"
+#include "mforms/appview.h"
+#include "mforms/textbox.h"
+
+namespace wb {
+  class WBContext;
+}
 
 class OutputView : public mforms::AppView
 {
 public:
-  OutputView(bec::MessageListStorage *storage);
+  OutputView(wb::WBContext* context);
   virtual ~OutputView();
   
   bec::MessageListBE *get_be() { return _messages; }
+  void setup_ui();
 private:
+  wb::WBContext* _wb;
   bec::MessageListStorage *_storage;
   bec::MessageListBE *_messages;
 
   mforms::Splitter _splitter;
-  mforms::GRTTreeView _message_list;
+  mforms::TreeNodeView _message_list;
   mforms::TextBox _output_text;
   mforms::Menu _context_menu;
+  bool _can_track_changes;
   
   void handle_command(const std::string& command);
 
+  void refresh();
   void row_added();
   bool will_close();
+  void splitter_moved();
 };
 
 #endif // _OUTPUT_VIEW_H_
