@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -26,6 +26,10 @@
 #include "workbench/wb_model_file.h"
 #include "workbench/wb_context_ui.h"
 
+#include "mforms/progressbar.h"
+#include "mforms/imagebox.h"
+#include "mforms/label.h"
+
 class AddOnDownloadWindow::DownloadItem : public mforms::Box
 {
 public:
