@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2013, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -131,7 +131,7 @@ public:
 #else
     int start_column = 1;
 #endif
-    _table.add(cb, start_column, 2, _rows - 1, _rows, mforms::HFillFlag);
+    _table.add(cb, start_column, 3, _rows - 1, _rows, mforms::HFillFlag);
     
     return cb;
   }
@@ -611,8 +611,8 @@ void PreferencesForm::create_sqlide_page()
   }
   
   {
-    mforms::Panel *frame= mforms::manage(new mforms::Panel(mforms::TitledBoxPanel));
-    frame->set_title(_("SQL Editor"));
+    mforms::Panel *frame = mforms::manage(new mforms::Panel(mforms::TitledBoxPanel));
+    frame->set_title(_("Productivity"));
     box->add(frame, false);
     
     mforms::Box *vbox= mforms::manage(new mforms::Box(false));
@@ -666,8 +666,7 @@ void PreferencesForm::create_sqlide_page()
       mforms::TextEntry *entry= new_entry_option("SqlEditor::SyntaxCheck::MaxErrCount", false);
       entry->set_max_length(5);
       entry->set_size(50, -1);
-      entry->set_tooltip(_(
-                           "Maximum number of errors to stop syntax check.\n"
+      entry->set_tooltip(_("Maximum number of errors for syntax checking.\n"
                            "Syntax errors aren't highlighted beyond this threshold.\n"
                            "Set to 0 to show all errors."));
       tbox->add(entry, false, false);
@@ -796,6 +795,50 @@ void PreferencesForm::create_query_page()
     }
   }
   
+  {
+    mforms::Panel *frame = mforms::manage(new mforms::Panel(mforms::TitledBoxPanel));
+    frame->set_title(_("Online DDL"));
+    box->add(frame, false);
+
+    mforms::Box *vbox = mforms::manage(new mforms::Box(false));
+    vbox->set_padding(8);
+    vbox->set_spacing(4);
+    frame->add(vbox);
+
+    {
+      mforms::Box *line_box = mforms::manage(new mforms::Box(true));
+      line_box->set_spacing(4);
+      vbox->add(line_box, false);
+
+      mforms::Label *label = new_label(_("Default algorithm for ALTER table:"), true);
+      label->set_size(180, -1);
+      line_box->add(label, false, false);
+
+      std::string algorithms = "Default:DEFAULT,In place:INPLACE,Copy:COPY";    
+      mforms::Selector *selector = new_selector_option("DbSqlEditor:OnlineDDLAlgorithm", algorithms, false);
+      selector->set_size(150, -1);
+      selector->set_tooltip(_("If the currently connected server supports online DDL then use the selected "
+        "algorithm as default. This setting can also be adjusted for each alter operation."));
+      line_box->add(selector, false, false);
+    }
+    {
+      mforms::Box *line_box = mforms::manage(new mforms::Box(true));
+      line_box->set_spacing(4);
+      vbox->add(line_box, false);
+
+      mforms::Label *label = new_label(_("Default lock for ALTER table:"), true);
+      label->set_size(180, -1);
+      line_box->add(label, false, false);
+
+      std::string locks = "Default:DEFAULT,None:NONE,Shared:SHARED,Exclusive:EXCLUSIVE";    
+      mforms::Selector *selector = new_selector_option("DbSqlEditor:OnlineDDLLock", locks, false);
+      selector->set_size(150, -1);
+      selector->set_tooltip(_("If the currently connected server supports online DDL then use the selected "
+        "lock as default. This setting can also be adjusted for each alter operation."));
+      line_box->add(selector, false, false);
+    }
+  }
+
   {
     mforms::Panel *frame= mforms::manage(new mforms::Panel(mforms::TitledBoxPanel));
     frame->set_title(_("Query Results"));
@@ -1002,26 +1045,6 @@ void PreferencesForm::create_model_page()
   box->set_padding(12);
   box->set_spacing(8);
 
-
-  {
-    mforms::Panel *frame= mforms::manage(new mforms::Panel(mforms::TitledBoxPanel));
-    frame->set_title(_("When Deleting Physical Model Figures in Diagram"));
-    
-    mforms::Box *rbox= mforms::manage(new mforms::Box(true));
-    
-    rbox->set_padding(8);
-    
-    frame->add(rbox);
-
-    rbox->add(new_label(""), false);
-
-    mforms::Selector* selector= new_selector_option("workbench.physical:DeleteObjectConfirmation");
-    selector->set_size(300, -1);
-    rbox->add(selector, true, false);
-
-    box->add(frame, false);
-  }
-
   {
     mforms::Panel *frame= mforms::manage(new mforms::Panel(mforms::TitledBoxPanel));
     frame->set_title(_("Column Defaults"));
