@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,13 +21,22 @@
 #define _SERVER_INSTANCE_EDITOR_H_
 
 
-#include <mforms/mforms.h>
-
 #include "workbench/wb_backend_public_interface.h"
 #include "grts/structs.db.mgmt.h"
 
 #include "grt/grt_manager.h"
 
+#include "mforms/form.h"
+#include "mforms/box.h"
+#include "mforms/textentry.h"
+#include "mforms/treenodeview.h"
+#include "mforms/selector.h"
+#include "mforms/button.h"
+#include "mforms/tabview.h"
+#include "mforms/radiobutton.h"
+#include "mforms/checkbox.h"
+#include "mforms/label.h"
+#include "mforms/textbox.h"
 
 class MYSQLWBBACKEND_PUBLIC_FUNC ServerInstanceEditor : public mforms::Form 
 { 
@@ -50,7 +59,7 @@ class MYSQLWBBACKEND_PUBLIC_FUNC ServerInstanceEditor : public mforms::Form
   mforms::Button _dup_inst_button;
   mforms::Button _move_up_button;
   mforms::Button _move_down_button;
-  mforms::TreeView _stored_instance_list;
+  mforms::TreeNodeView _stored_instance_list;
   
   mforms::TabView _tabview;
   mforms::Box _conn_box;
