@@ -173,9 +173,7 @@ bool MainForm::close_window(GdkEventAny *ev)
     get_mainwindow()->hide();
     _wbui_context->perform_quit();
   }*/
- // _wbui_context->get_wb()->quit_application();
-  if (_wbui_context->request_quit())
-      _wbui_context->perform_quit();
+  _wbui_context->get_wb()->quit_application();
   return true; // true means stop processing the event
 }
 
@@ -1107,7 +1105,8 @@ void MainForm::refresh_gui_becb(wb::RefreshType type, const std::string& arg_id,
     {
       ModelDiagramPanel *panel = dynamic_cast<ModelDiagramPanel*>(reinterpret_cast<FormViewBase*>(arg_ptr));
       if (panel)
-        panel->setup_navigator();
+      panel->setup_navigator();
+//         switch_to_diagram(panel);
       break;
     }
 
@@ -1242,13 +1241,8 @@ void MainForm::handle_model_created()
 void MainForm::handle_model_closed()
 {
   if (_model_panel)
-  {
-    _model_panel->dispose();
-    get_upper_note()->remove_page(*_model_panel->get_panel());//*_model_panel);
-//    _model_panel->unreference();
-  }
-
-//  delete _model_panel;
+    get_upper_note()->remove_page(*_model_panel);
+  delete _model_panel;
   _model_panel= 0;
 }
 
@@ -1452,25 +1446,42 @@ void MainForm::close_active_tab()
 }
 
 
+static bool note_contains_page(Gtk::Notebook *note, Gtk::Widget *page)
+{
+  for (int i = note->get_n_pages()-1; i >= 0; --i)
+    if (note->get_nth_page(i) == page)
+      return true;
+  return false;
+}
+
+
 bool MainForm::close_tab(Gtk::Notebook *note, Gtk::Widget *page)
 {
   // on_close should return true if the form should be closed/removed
   mforms::AppView *app_view = reinterpret_cast<mforms::AppView*>(page->get_data("AppView"));
   FormViewBase *form = reinterpret_cast<FormViewBase*>(page->get_data("FormViewBase"));
+
   if (app_view || form)
   {
     if ((app_view && app_view->on_close()) || (form && form->on_close()))
     {
-      if (note->page_num(*page) >= 0)
+       // can't use page_num, because it will dereference the pointer and it could be deleted (shouldn't be, but it is happening)
+      //if (note->page_num(*page) >= 0)
+      if (note_contains_page(note, page))
       {
         if (form)
           form->dispose();
         note->remove_page(*page);
         page->unreference();
+
+        if (form == _model_panel)
+          _model_panel = 0;
       }
     }
     else
+    {
       return false;
+    }
   }
   else
     page->hide();
