@@ -28,9 +28,6 @@ namespace wb
 };
 
 class CatalogTree;
-class LayerTree;
-class HistoryTree;
-class UserTypesBox;
 class PropertiesTree;
 class DocumentationBox;
 class NavigatorBox;
@@ -75,11 +72,11 @@ class ModelDiagramPanel : public Gtk::HPaned, public FormViewBase
 
   NavigatorBox                *_navigator_box;
   CatalogTree                 *_catalog_tree;
-  LayerTree                   *_layer_tree;
-  HistoryTree                 *_history_tree;
-  UserTypesBox                *_usertypes_box;
+  mforms::TreeNodeView        *_usertypes_list;
+  mforms::TreeNodeView        *_history_list;
   DocumentationBox            *_documentation_box;
   PropertiesTree              *_properties_tree;
+  Glib::RefPtr<Gtk::Builder>   _xml;
 
   bool drag_drop(const Glib::RefPtr<Gdk::DragContext> &context, int x, int y, guint time);
 
