@@ -142,6 +142,7 @@ static NSDictionary *EditorTabImages = nil;
     switch (mStyle)
     {
       case MPaletteTabSwitcher:
+      case MPaletteTabSwitcherSmallText:
       case MSectionTabSwitcher:
         size.height = 24;
         size.width = MAX(ceil([[item label] sizeWithAttributes: mLabelAttributes].width) + 20, mMinTabWidth);
@@ -185,6 +186,7 @@ static NSDictionary *EditorTabImages = nil;
     switch (mStyle)
     {
       case MPaletteTabSwitcher:
+      case MPaletteTabSwitcherSmallText:
         size.height = 24;
         size.width = 0;
         for (NSTabViewItem *item in [mTabView tabViewItems])
@@ -246,6 +248,21 @@ static NSDictionary *EditorTabImages = nil;
       mDefaultMinTabWidth = mMinTabWidth;
       break;
     }
+    case MPaletteTabSwitcherSmallText:
+    {
+      NSMutableParagraphStyle *style = [[NSMutableParagraphStyle defaultParagraphStyle] mutableCopy];
+      [style setAlignment: NSCenterTextAlignment];
+      [style setLineBreakMode: NSLineBreakByTruncatingTail];
+
+      mLabelAttributes = [[NSMutableDictionary alloc] initWithObjectsAndKeys:
+                          [NSFont boldSystemFontOfSize: [NSFont systemFontSizeForControlSize: NSMiniControlSize]], NSFontAttributeName,
+                          [NSColor blackColor], NSForegroundColorAttributeName,
+                          style, NSParagraphStyleAttributeName,
+                          nil];
+      mMinTabWidth = 70;
+      mDefaultMinTabWidth = mMinTabWidth;
+      break;
+    }
     case MEditorTabSwitcher:
     {
       NSMutableParagraphStyle *style = [[NSMutableParagraphStyle defaultParagraphStyle] mutableCopy];
@@ -566,7 +583,7 @@ static NSDictionary *EditorTabImages = nil;
   tabRect.origin = NSMakePoint(floor(NSMinX(rect)), floor(NSMinY(rect)));
   tabRect.size = [self _sizeOfTabViewItem: item];
     
-  if ([item tabState] != NSBackgroundTab && [mTabView numberOfTabViewItems] > 1)
+  if ([item tabState] != NSBackgroundTab/* && [mTabView numberOfTabViewItems] > 1*/)
   {
     [[[[NSGradient alloc] initWithColorsAndLocations:
        [NSColor colorWithDeviceWhite: 0xba/255.0 alpha:1.0], (CGFloat)0.0,
@@ -809,6 +826,7 @@ static NSDictionary *EditorTabImages = nil;
     }
       
     case MPaletteTabSwitcher:
+    case MPaletteTabSwitcherSmallText:
     {
       [[[[NSGradient alloc] initWithColorsAndLocations:
           [NSColor colorWithDeviceWhite: 0xbb/255.0 alpha:1.0], (CGFloat)0.0,
