@@ -1,5 +1,5 @@
 /* 
- * Copyright © 2008, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2012, Oracle and/or its affiliates. All rights reserved.
  * 
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -42,8 +42,7 @@ namespace wb
   IBOutlet NSView *sidebar;
   IBOutlet NSView *optionsToolbar;
   IBOutlet MCanvasScrollView *scrollView;
-  IBOutlet NSOutlineView *layerOutline;
-  IBOutlet GRTTreeDataSource *layerDS;
+  IBOutlet NSTabViewItem *layerTab;
   
   IBOutlet WBModelSidebarController *sidebarController;
   
@@ -96,7 +95,6 @@ sharedSidebarController:(WBModelSidebarController*)sidebar;
 - (IBAction)changeDiagramSize:(id)sender;
 
 - (IBAction)setZoom:(id)sender;
-- (IBAction)activateLayerItem:(id)sender;
 
 - (void) performCommand: (const std::string) command;
 
