@@ -17,6 +17,7 @@
 #include "model/wb_model_diagram_form.h"
 #include "model/wb_layer_tree.h"
 
+#import "mforms/../cocoa/MFView.h"
 #import "NSString_extras.h"
 #import "WBModelDiagramPanel.h"
 #import "MCanvasScrollView.h"
@@ -45,9 +46,6 @@ static int zoom_levels[]= {
 };
 
 
-static void refresh_layer_tree(const bec::NodeId &node, int old_count, WBModelDiagramPanel *panel);
-static void redisplay_catalog_tree(const bec::NodeId &node, int old_count, WBModelDiagramPanel *panel);
-
 @implementation WBModelDiagramPanel
 
 static void *backend_destroyed(void *ptr)
@@ -78,14 +76,11 @@ sharedSidebarController:(WBModelSidebarController*) controller
     [topView setDividerThickness: 1];
      
     // setup layer tree
-    [layerDS setTreeModel: _formBE->get_layer_tree()];
-    _formBE->get_layer_tree()->tree_changed_signal()->connect(boost::bind(refresh_layer_tree, _1, _2, self));
+    [layerTab setView: nsviewForView(_formBE->get_layer_tree())];
+    // _formBE->get_layer_tree()->refresh();
 
     // when the layer tree changes, we should redisplay the catalog tree in case a new object was dropped (redisplay only is relatively cheap)
-    _formBE->get_layer_tree()->tree_changed_signal()->connect(boost::bind(redisplay_catalog_tree, _1, _2, self));
-    [layerOutline setDoubleAction:@selector(activateLayerItem:)];
-    [layerOutline setTarget:self];
-    [layerDS setHidesRootNode:YES];
+//XXX    _formBE->get_layer_tree()->tree_changed_signal()->connect(boost::bind(redisplay_catalog_tree, _1, _2, self));
 
     // setup navigator
     for (int i= 0; i < (int)(sizeof(zoom_levels)/sizeof(int)); i++)
@@ -154,7 +149,6 @@ sharedSidebarController:(WBModelSidebarController*) controller
   [descriptionController release];
   [mPropertiesController release];
   [mainSplitViewDelegate release];
-  [layerDS release];
   
   [super dealloc];
 }
@@ -191,12 +185,6 @@ sharedSidebarController:(WBModelSidebarController*) controller
 }
 
 
-- (IBAction)activateLayerItem:(id)sender
-{
-  _formBE->get_layer_tree()->activate_node([layerDS nodeIdForItem:[layerOutline itemAtRow: [layerOutline clickedRow]]]);
-}
-
-
 - (MCanvasViewer*)canvasViewer
 {
   return _viewer;
@@ -311,44 +299,6 @@ static NSPoint loadCursorHotspot(const std::string &path)
   [sidebarController refreshCatalogTree];
 }
 
-- (void)refreshLayerTree
-{
-  if (_formBE->get_wb()->get_grt_manager()->try_soft_lock_globals_tree())
-  {
-    NSPoint pos = [[[layerOutline enclosingScrollView] contentView] documentVisibleRect].origin;
-    id state = [layerDS storeExpansionStateOfOutlineView:layerOutline usingValueOfColumn:@"0"];
-    NSIndexSet *selectedIndexes = [[layerOutline selectedRowIndexes] copy];
-
-    wb::LayerTreeBE *layerTree = _formBE->get_layer_tree();
-    layerTree->refresh();
-        
-    [layerOutline reloadData];
-    
-    [layerDS restoreExpansionStateOfOutlineView: layerOutline fromState:state usingValueOfColumn:@"0"];
-    
-    [[[layerOutline enclosingScrollView] contentView] scrollToPoint: pos];
-    [[layerOutline enclosingScrollView] reflectScrolledClipView: [[layerOutline enclosingScrollView] contentView]];
-
-    [layerOutline selectRowIndexes: selectedIndexes byExtendingSelection: NO];
-    
-    _formBE->get_wb()->get_grt_manager()->soft_unlock_globals_tree();
-    [selectedIndexes release];
-  }
-
-/*
-  for (size_t c= layerTree->count(), i= 0; i < c; i++)
-  {
-    bec::NodeId node= layerTree->get_node(i);
-    int islayer;
-    
-    layerTree->get_field(node, (int)wb::LayerTreeBE::IsLayer, islayer);
-    if (islayer)
-      [layerOutline expandItem:[layerDS outlineView:layerOutline
-                                              child:i
-                                             ofItem:nil]];
-  }*/
-}
-
 - (void)navigatorFrameChanged:(NSNotification*)notif
 {
   _formBE->update_mini_view_size(NSWidth([navigatorViewer frame]), NSHeight([navigatorViewer frame]));
@@ -396,8 +346,6 @@ static NSPoint loadCursorHotspot(const std::string &path)
     _formBE->setup_mini_view([navigatorViewer canvas]);
     _formBE->update_mini_view_size(NSWidth([navigatorViewer frame]), NSHeight([navigatorViewer frame]));
     _miniViewReady = YES;
-    
-    [self refreshLayerTree];
   }
 }
 
@@ -408,20 +356,6 @@ static NSPoint loadCursorHotspot(const std::string &path)
 }
 
 
-static void redisplay_catalog_tree(const bec::NodeId &node, int old_count, WBModelDiagramPanel *panel)
-{
-  NSAutoreleasePool *pool = [[NSAutoreleasePool alloc] init];
-  [[panel->sidebarController catalogOutline] setNeedsDisplay: YES];
-  [pool release];
-}
-
-static void refresh_layer_tree(const bec::NodeId &node, int old_count, WBModelDiagramPanel *panel)
-{
-  [panel performSelectorOnMainThread:@selector(refreshLayerTree)
-                          withObject:nil 
-                       waitUntilDone:NO];
-}
-
 - (void)refreshInfo
 {
   std::string info= _formBE->get_wb()->get_ui()->get_active_diagram_info();
