@@ -1,10 +1,21 @@
-//
-//  WBOverviewComponents.mm
-//  MySQLWorkbench
-//
-//  Created by Alfredo Kojima on 18/Nov/08.
-//  Copyright 2008 Sun Microsystems Inc. All rights reserved.
-//
+/* 
+ * Copyright (c) 2008, 2012, Oracle and/or its affiliates. All rights reserved.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; version 2 of the
+ * License.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301  USA
+ */
 
 #import "WBOverviewComponents.h"
 #import "WBOverviewListController.h"
@@ -44,8 +55,6 @@ static NSString *stringFromNodeId(const bec::NodeId &node)
 
 - (void)dealloc
 {
-  [[NSNotificationCenter defaultCenter] removeObserver:self];
-  
   delete _nodeId;
   [super dealloc];
 }
@@ -70,13 +79,6 @@ static NSString *stringFromNodeId(const bec::NodeId &node)
   
   [_owner registerContainer:group forItem:stringFromNodeId(child)];
   
-  [group setPostsFrameChangedNotifications:YES];
-  [[NSNotificationCenter defaultCenter] addObserver:self
-                                           selector:@selector(groupFrameChanged:)
-                                               name:NSViewFrameDidChangeNotification
-                                             object:group];
-  
-  
   [group buildChildren];
   
   [self addTabViewItem:[item autorelease]];
@@ -85,13 +87,28 @@ static NSString *stringFromNodeId(const bec::NodeId &node)
 }
 
 
-- (void)groupFrameChanged:(NSNotification*)notif
+- (void)tile
 {
-  float height= NSHeight([[notif object] frame]);
-  NSRect frame= [self frame]; 
+  if (!_resizing)
+    [self resizeWithOldSuperviewSize: NSZeroSize];
+}
+
+
+- (void)resizeWithOldSuperviewSize:(NSSize)oldBoundsSize
+{
+  float maxHeight = 0;
+
+  _resizing = YES;
   
-  if (NSHeight(frame) < height + _extraHeight)
-    [self setFrameSize:NSMakeSize(NSWidth(frame), height + _extraHeight)];
+  for (NSTabViewItem *tabItem in [self tabViewItems])
+  {
+    [[tabItem view] tile];
+    
+    maxHeight= MAX(maxHeight, [[tabItem view] minimumSize].height);
+  }
+  [self setFrameSize:NSMakeSize([self contentSize].width, maxHeight + _extraHeight)];
+  
+  _resizing = NO;
 }
 
 
@@ -165,8 +182,9 @@ static NSString *stringFromNodeId(const bec::NodeId &node)
       [[tabItem view] updateNodeId: child];
       
       [[tabItem view] refreshChildren]; // refresh
+      [[tabItem view] tile];
       
-      maxHeight= MAX(maxHeight, NSHeight([[tabItem view] frame]));
+      maxHeight= MAX(maxHeight, [[tabItem view] minimumSize].height);
             
       [self selectNextTabViewItem:nil];
       NSTabViewItem *nextItem= [self selectedTabViewItem]; 
@@ -182,7 +200,6 @@ static NSString *stringFromNodeId(const bec::NodeId &node)
 
   [self tabView:self willSelectTabViewItem:[self selectedTabViewItem]];
 
-    
   /// this raises an exception, check why
  // if (oldItem)
  //   [self selectTabViewItem:oldItem];
@@ -308,6 +325,12 @@ static NSString *stringFromNodeId(const bec::NodeId &node)
 }
 
 
+- (void)tabView:(NSTabView *)tabView didSelectTabViewItem:(NSTabViewItem *)tabViewItem
+{
+  [[tabViewItem view] tile];
+}
+
+
 @end
 
 
@@ -324,10 +347,11 @@ static NSString *stringFromNodeId(const bec::NodeId &node)
     _be= [owner backend];
     _nodeId= new bec::NodeId(node);
     _tabItem= tabItem;
-        
+    
+    [self setExpandSubviewsByDefault: NO];
     [self setBackgroundColor:[NSColor whiteColor]];
     [self setSpacing: 12];
-    [self setPadding: 12];
+    [self setPaddingLeft: 12 right: 12 top: 12 bottom: 12];
   }
   
   return self;
@@ -360,7 +384,6 @@ static NSString *stringFromNodeId(const bec::NodeId &node)
   return *_nodeId;
 }
 
-
 - (void)buildChildren
 {
   // build the child items
@@ -375,7 +398,7 @@ static NSString *stringFromNodeId(const bec::NodeId &node)
     
     WBOverviewSection *section= [[[WBOverviewSection alloc] initWithOverview:_owner
                                                                       nodeId:child] autorelease];
-    [section setFrameSize:NSMakeSize(100, 100)];
+    [section setFrameSize:NSMakeSize(100, 20)];
     [section setAutoresizingMask:NSViewWidthSizable|NSViewHeightSizable];
     [self addSubview:section];
     
@@ -441,6 +464,18 @@ static NSString *stringFromNodeId(const bec::NodeId &node)
   }
 }
 
+
+- (NSSize)minimumSize
+{
+  NSSize size = NSMakeSize(leftPadding + rightPadding, topPadding + bottomPadding);
+  NSArray *items = [self subviews];
+  for (NSView *subview in items)
+    size.height += NSHeight([subview frame]);
+  if ([items count] > 0)
+    size.height += ([items count] - 1) * spacing;
+  return size;
+}
+
 @end
      
      
@@ -453,7 +488,7 @@ static NSString *stringFromNodeId(const bec::NodeId &node)
 - (id)initWithOverview:(WBOverviewPanel*)owner
                 nodeId:(const bec::NodeId&)node
 {
-  self = [super initWithFrame:NSMakeRect(0, 0, 100, 200)];
+  self = [super initWithFrame:NSMakeRect(0, 0, 100, 20)];
   if (self != nil)
   {
     _owner= owner;
@@ -626,7 +661,7 @@ static NSString *stringFromNodeId(const bec::NodeId &node)
 
   [_iconController fillFromChildrenOf: *_nodeId
                              overview: _be
-                             iconSize: _displayMode == wb::OverviewBE::MLargeIcon ? bec::Icon32 : bec::Icon16];
+                             iconSize: _displayMode == wb::OverviewBE::MLargeIcon ? bec::Icon32 : bec::Icon16];  
 }
 
 
@@ -855,7 +890,7 @@ static NSString *stringFromNodeId(const bec::NodeId &node)
   if (count != 1)
     [self setSubTitle: [NSString stringWithFormat: NSLocalizedString(@"(%i items)", @"!=1 items"), count]];
   else
-    [self setSubTitle: [NSString stringWithFormat: NSLocalizedString(@"(%i item)", @"==1 item"), count]];  
+    [self setSubTitle: [NSString stringWithFormat: NSLocalizedString(@"(%i item)", @"==1 item"), count]];
 }
 
 @end
