@@ -1,13 +1,28 @@
-//
-//  WBPluginWindowController.mm
-//  MySQLWorkbench
-//
-//  Created by Alfredo Kojima on 11/Nov/09.
-//  Copyright 2009 Sun Microsystems Inc. All rights reserved.
-//
+/* 
+ * Copyright (c) 2009, 2012, Oracle and/or its affiliates. All rights reserved.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; version 2 of the
+ * License.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301  USA
+ */
+
+#include "base/geometry.h"
+#include "base/string_utilities.h"
 
 #import "WBPluginWindowController.h"
 
+#include "grt_manager.h"
 
 @implementation WBPluginWindowController
 
@@ -35,7 +50,7 @@
     size.height += yextra;
     [window setContentSize: size];
     
-    id view = [mPluginEditor dockableView];
+    id view = [mPluginEditor view];
     [contentView addSubview: view];
     [view setFrame: rect];
     
