@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2013, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -1631,13 +1631,18 @@ namespace MySQL.Controls
         OnTabClosing(args);
         if (args.canClose)
         {
-          SetBusy(TabPages.IndexOf(page), false);
+          // The page could be removed in the OnTabClosing event, so prepare for that.
+          int tabIndex = TabPages.IndexOf(page);
+          if (tabIndex > -1)
+          {
+            SetBusy(TabPages.IndexOf(page), false);
 
-          // Remove this tab and select its predecessor if possible.
-          if (SelectedIndex > 0)
-            SelectedIndex = SelectedIndex - 1;
-          lastTabHit = -1;
-          TabPages.Remove(page);
+            // Remove this tab and select its predecessor if possible.
+            if (SelectedIndex > 0)
+              SelectedIndex = SelectedIndex - 1;
+            lastTabHit = -1;
+            TabPages.Remove(page);
+          }
 
           AdjustLayoutInfo(null);
           Update();
@@ -1728,18 +1733,28 @@ namespace MySQL.Controls
 
       // The simple approach here would be to remove the page and insert it at the new location.
       // However this will produce heavy flickering, so we move the pages one by one instead.
+      // While moving the pages also move their corresponding tab info to keep current states.
+      TabInfo oldInfo = layoutInfo[oldIndex];
       if (oldIndex < newIndex)
       {
         for (int index = oldIndex; index < newIndex; index++)
+        {
           TabPages[index] = TabPages[index + 1];
+          layoutInfo[index] = layoutInfo[index + 1];
+        }
         TabPages[newIndex] = page;
+        layoutInfo[newIndex] = oldInfo;
         AdjustLayoutInfo(TabPages[oldIndex]);
       }
       else
       {
         for (int index = oldIndex; index > newIndex; index--)
+        {
           TabPages[index] = TabPages[index - 1];
+          layoutInfo[index] = layoutInfo[index - 1];
+        }
         TabPages[newIndex] = page;
+        layoutInfo[newIndex] = oldInfo;
         AdjustLayoutInfo(page);
       }
 
