@@ -1,5 +1,6 @@
 using System;
 using System.Windows.Forms;
+using MySQL.Workbench;
 
 namespace MySQL.GUI.Workbench
 {
@@ -9,21 +10,24 @@ namespace MySQL.GUI.Workbench
 
     private String errorInfo;
 
+    private WbContext wbContext;
+
     protected ExceptionDialog()
     {
       InitializeComponent();
     }
 
-    public static void Show(String message, String info)
+    public static void Show(String message, String info, WbContext wbcontext)
     {
       singleton.messageLabel.Text = message;
       singleton.errorInfo = info;
+      singleton.wbContext = wbcontext;
       singleton.ShowDialog();
     }
 
     private void reportBugButton_Click(object sender, EventArgs e)
     {
-      System.Diagnostics.Process.Start("http://bugs.mysql.com/report.php");
+      wbContext.report_bug(errorInfo);
     }
 
     private void copyInfoButton_Click(object sender, EventArgs e)
