@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008, 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2013, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -1215,6 +1215,11 @@ namespace MySQL.GUI.Workbench
       Control root = document.Content;
       Control content = (root.Controls.Count > 0) ? root.Controls[0] : null;
 
+      // If there's already a drawable panel then this document has already been set up
+      // and just needs to be shown. Happens for re-used views (like the Output view).
+      if (content is DrawablePanel)
+        return;
+
       root.Controls.Clear();
 
       // Content area.
