@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2013, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,7 +17,6 @@
  * 02110-1301  USA
  */
 
-
 using System;
 using System.Collections.Generic;
 using System.Drawing;
@@ -25,12 +24,12 @@ using System.IO;
 using System.Windows.Forms;
 
 using MySQL.Controls;
+using MySQL.Forms;
 using MySQL.Grt;
 using MySQL.GUI.Mdc;
 using MySQL.GUI.Workbench.Plugins;
-using MySQL.Forms;
-using MySQL.Workbench;
 using MySQL.Utilities.SysUtils;
+using MySQL.Workbench;
 
 namespace MySQL.GUI.Workbench
 {
@@ -77,7 +76,7 @@ namespace MySQL.GUI.Workbench
       // Sidebar windows.
       modelNavigator = new ModelNavigatorForm(this);
       userDatatypesForm = new UserDatatypesForm(wbContext);
-      modelLayerForm = new ModelLayerForm(this, wbContext.get_grt_manager());
+      modelLayerForm = new ModelLayerForm(this);
       modelCatalogForm = new ModelCatalogForm(wbContext);
       historyForm = new UndoHistoryForm(wbContext);
       modelPropertiesForm = new ModelPropertiesForm(wbContext);
@@ -155,7 +154,6 @@ namespace MySQL.GUI.Workbench
 
         case RefreshType.RefreshDocument:
           TabText = formBE.get_title();
-          userDatatypesForm.UpdateTree();
 
           break;
 
@@ -355,25 +353,25 @@ namespace MySQL.GUI.Workbench
     void CanvasPanel_MouseUp(object sender, MouseEventArgs e)
     {
       Point p = e.Location;
-      formBE.OnMouseUp(e, p.X, p.Y, ModifierKeys, MouseButtons);
+      formBE.OnMouseUp(e, p.X, p.Y, ModifierKeys, e.Button);
     }
 
     void CanvasPanel_MouseDown(object sender, MouseEventArgs e)
     {
       Point p = e.Location;
-      formBE.OnMouseDown(e, p.X, p.Y, ModifierKeys, MouseButtons);
+      formBE.OnMouseDown(e, p.X, p.Y, ModifierKeys, e.Button);
     }
 
     void CanvasPanel_MouseDoubleClick(object sender, MouseEventArgs e)
     {
       Point p = e.Location;
-      formBE.OnMouseDoubleClick(e, p.X, p.Y, ModifierKeys, MouseButtons);
+      formBE.OnMouseDoubleClick(e, p.X, p.Y, ModifierKeys, e.Button);
     }
 
     void CanvasPanel_MouseMove(object sender, MouseEventArgs e)
     {
       Point p = e.Location;
-      formBE.OnMouseMove(e, p.X, p.Y, ModifierKeys, MouseButtons);
+      formBE.OnMouseMove(e, p.X, p.Y, ModifierKeys, e.Button);
     }
 
     void CanvasPanel_MouseLeave(object sender, EventArgs e)
