@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -19,7 +19,7 @@
 
 #include "base/geometry.h"
 
-using namespace MySQL::Geometry;
+using namespace base;
 
 //----------------- Point --------------------------------------------------------------------------
 
@@ -129,6 +129,16 @@ ControlBounds::ControlBounds(int x, int y, int w, int h)
 
 //----------------- Padding ------------------------------------------------------------------------
 
+Padding::Padding()
+{
+  left = 0;
+  top = 0;
+  right = 0;
+  bottom = 0;
+}
+
+//--------------------------------------------------------------------------------------------------
+
 Padding::Padding(int padding)
 {
   left = padding;
@@ -148,3 +158,47 @@ Padding::Padding(int left, int top, int right, int bottom)
 }
 
 //--------------------------------------------------------------------------------------------------
+
+int Padding::horizontal()
+{
+  return left + right;
+}
+
+//--------------------------------------------------------------------------------------------------
+
+int Padding::vertical()
+{
+  return top + bottom;
+}
+
+//----------------- Range --------------------------------------------------------------------------
+
+Range::Range()
+{
+  position = 0;
+  size = 0;
+}
+
+//--------------------------------------------------------------------------------------------------
+
+Range::Range(int position, int size)
+{
+  this->position = position;
+  this->size = size;
+}
+
+//--------------------------------------------------------------------------------------------------
+
+int Range::end()
+{
+  return position + size;
+}
+
+//--------------------------------------------------------------------------------------------------
+
+bool Range::contains_point(int point)
+{
+  return (point >= position) && (point - position <= size);
+}
+
+//--------------------------------------------------------------------------------------------------
