@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -22,7 +22,7 @@
 #include "mdc_box.h"
 
 using namespace mdc;
-using namespace MySQL::Geometry;
+using namespace base;
 
 Box::Box(Layer *layer, Orientation orient, bool homogeneous)
   : Layouter(layer)
@@ -44,7 +44,7 @@ void Box::set_spacing(float sp)
 }
 
 
-void Box::foreach(const sigc::slot<void, CanvasItem*> &slot)
+void Box::foreach(const boost::function<void (CanvasItem*)> &slot)
 {
   for (ItemList::const_iterator iter= _children.begin(); iter != _children.end(); )
   {
