@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -37,7 +37,7 @@ class MYSQLCANVAS_PUBLIC_FUNC CanvasViewExtras {
 public:
   CanvasViewExtras(CanvasView *view);
 
-  void set_progress_callback(const sigc::slot<void, int, int> &progress);
+  void set_progress_callback(const boost::function<void (int, int)> &progress);
 
   void enable_custom_layout();
   void set_show_print_guides(bool flag);
@@ -57,7 +57,7 @@ public:
   void set_scale(double xscale, double yscale);
   void set_scale_to_fit();
 
-  void set_print_area(const MySQL::Geometry::Rect &area);
+  void set_print_area(const base::Rect &area);
 
   int print_to_pdf(const std::string &path);
   int print_to_ps(const std::string &path);
@@ -72,13 +72,13 @@ public:
   void render_page(CairoCtx *cr, int x, int y);
   
 protected:
-  MySQL::Geometry::Size get_adjusted_paper_size();
-  MySQL::Geometry::Rect get_adjusted_printable_area();
+  base::Size get_adjusted_paper_size();
+  base::Rect get_adjusted_printable_area();
 
 
   CanvasView *_view;
 
-  sigc::slot<void, int, int> _progress_cb;
+  boost::function<void (int, int)> _progress_cb;
 
   Count _xpages, _ypages;
 
