@@ -16,12 +16,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301  USA
  */
-//hack to workaround sigc++ using nil
-#ifdef nil
-#undef nil
-#endif 
-#include <sigc++/sigc++.h>
-#define nil __DARWIN_NULL
 
 #import <Cocoa/Cocoa.h>
 
