@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -92,24 +92,27 @@
 
 - (void)subviewMinimumSizeChanged
 {
-  NSSize minSize= [self minimumSize];
-  NSSize size= [self frame].size;
-  
-  // size of some subview has changed, we check if our current size is enough
-  // to fit it and if not, request forward the size change notification to superview
-  
-  if (minSize.width > size.width || minSize.height > size.height)
+  if (!mOwner->is_destroying())
   {
-    if ([self superview])
+    NSSize minSize= [self minimumSize];
+    NSSize size= [self frame].size;
+    
+    // size of some subview has changed, we check if our current size is enough
+    // to fit it and if not, request forward the size change notification to superview
+    
+    if (minSize.width > size.width || minSize.height > size.height)
     {
-      [[self superview] subviewMinimumSizeChanged];
-      return;
+      if ([self superview])
+      {
+        [[self superview] subviewMinimumSizeChanged];
+        return;
+      }
+      else
+        [self setFrameSize: minSize];
     }
-    else
-      [self setFrameSize: minSize];
+    [self resizeSubviewsWithOldSize:size];
+    [[self contentView] subviewMinimumSizeChanged];
   }
-  [self resizeSubviewsWithOldSize:size];
-  [[self contentView] subviewMinimumSizeChanged];
 }
 
 - (void)setTag:(NSInteger)tag
