@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -22,7 +22,11 @@
 #include "mforms/splitter.h"
 
 
-@interface MFSplitterImpl : NSSplitView {
+@interface MFSplitterImpl : NSSplitView
+#ifdef MAC_OS_X_VERSION_10_6
+    <NSSplitViewDelegate>
+#endif
+{
   mforms::Splitter *mOwner;
   NSInteger mTag;
   int mMinSizes[2];
