@@ -20,12 +20,10 @@
 #import <Cocoa/Cocoa.h>
 
 #include "mforms/treenodeview.h"
+#include <map>
 
 @class MFTreeNodeImpl;
-@interface MFTreeNodeViewImpl : NSScrollView
-#ifdef MAC_OS_X_VERSION_10_6
-    <NSOutlineViewDataSource, NSOutlineViewDelegate>
-#endif
+@interface MFTreeNodeViewImpl : NSScrollView <NSOutlineViewDataSource, NSOutlineViewDelegate>
 {
   NSOutlineView *mOutline;
   NSMutableDictionary *mIconCache;
@@ -33,11 +31,13 @@
   NSMutableArray *mColumnKeys;
   mforms::TreeNodeView *mOwner;
   NSMutableDictionary *mAttributedFonts;
+  std::map<std::string, MFTreeNodeImpl*> mTagMap;
   int mSortColumn;
   int mFreezeCount;
   BOOL mSortColumnEnabled;
   BOOL mReorderable;
   BOOL mPendingReload;
+  BOOL mTagIndexEnabled;
 @public
   BOOL mFlatTable;
   BOOL mSmallFont;
@@ -51,4 +51,6 @@
 - (NSImage*)iconForFile: (NSString*)path;
 
 - (void)setNeedsReload;
+
+- (void)setNode: (MFTreeNodeImpl*)node forTag: (const std::string&)tag;
 @end
