@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,7 +21,6 @@
 #include "mforms/mforms.h"
 
 using namespace mforms;
-
   
 GRTTreeView::GRTTreeView(TreeOptions options)
   : _context_menu(0)
@@ -111,3 +110,10 @@ void GRTTreeView::set_expanded(const bec::NodeId& node, bool expanded)
 }
 
 //--------------------------------------------------------------------------------------------------
+
+void GRTTreeView::enable_asynch_loading(bool enabled)
+{
+  if (_grttreeview_impl->enable_asynch_loading)
+    _grttreeview_impl->enable_asynch_loading(this, enabled);
+}
+//--------------------------------------------------------------------------------------------------
