@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -30,17 +30,17 @@ namespace gtk {
 class ImageBoxImpl : public ViewImpl
 {
 protected:
-  Gtk::Image *_image;
+  mutable Gtk::Image _image;
   bool _scale;
-  virtual Gtk::Widget *get_outer() const { return _image; }
+  virtual Gtk::Widget *get_outer() const { return &_image; }
 
   ImageBoxImpl(::mforms::ImageBox *self)
     : ViewImpl(self)
   {
-    _image = Gtk::manage(new Gtk::Image());
-    _image->set_alignment(0, 0.5);
+    //_image = Gtk::manage(new Gtk::Image());
+    _image.set_alignment(0, 0.5);
     _scale= false;
-    _image->signal_realize().connect(sigc::mem_fun(this, &ImageBoxImpl::on_realize));
+    _image.signal_realize().connect(sigc::mem_fun(this, &ImageBoxImpl::on_realize));
 
     setup();
   }
@@ -51,10 +51,10 @@ protected:
     {
       int w, h;
       int iw, ih;
-      _image->get_size_request(w, h);
-      if (w > 0 || h > 0)
+      Glib::RefPtr<Gdk::Pixbuf> pb= _image.get_pixbuf();
+      _image.get_size_request(w, h);
+      if ((w > 0 || h > 0) && pb)
       {
-        Glib::RefPtr<Gdk::Pixbuf> pb= _image->get_pixbuf();
         double ratio;
         iw= pb->get_width();
         ih= pb->get_height();
@@ -67,7 +67,7 @@ protected:
           pb= pb->scale_simple(h/ratio, h, Gdk::INTERP_BILINEAR);
         else
           pb= pb->scale_simple(w, w/ratio, Gdk::INTERP_BILINEAR);
-        _image->set(pb);
+        _image.set(pb);
       }
     }
   }
@@ -82,7 +82,13 @@ protected:
     ImageBoxImpl* image = self->get_data<ImageBoxImpl>();
 
     if (image)
-      image->_image->set(mforms::App::get()->get_resource_path(file));
+    {
+      std::string p = mforms::App::get()->get_resource_path(file);
+      if (p.empty())
+        g_warning("image %s not found", file.c_str());
+      else
+        image->_image.set(p);
+    }
   }
 
   static void set_scale_contents(::mforms::ImageBox *self, bool flag)
@@ -107,31 +113,31 @@ protected:
       switch (alignment)
       {
       case mforms::BottomLeft:
-        image->_image->set_alignment(0.0, 1.0);
+        image->_image.set_alignment(0.0, 1.0);
         break;
       case mforms::MiddleLeft:
-        image->_image->set_alignment(0.0, 0.5);
+        image->_image.set_alignment(0.0, 0.5);
         break;
       case mforms::TopLeft:
-        image->_image->set_alignment(0.0, 0.0);
+        image->_image.set_alignment(0.0, 0.0);
         break;
       case mforms::BottomCenter:
-        image->_image->set_alignment(0.5, 1.0);
+        image->_image.set_alignment(0.5, 1.0);
         break;
       case mforms::TopCenter:
-        image->_image->set_alignment(0.5, 0.0);
+        image->_image.set_alignment(0.5, 0.0);
         break;
       case mforms::MiddleCenter:
-        image->_image->set_alignment(0.5, 0.5);
+        image->_image.set_alignment(0.5, 0.5);
         break;
       case mforms::BottomRight:
-        image->_image->set_alignment(1.0, 1.0);
+        image->_image.set_alignment(1.0, 1.0);
         break;
       case mforms::MiddleRight:
-        image->_image->set_alignment(1.0, 0.5);
+        image->_image.set_alignment(1.0, 0.5);
         break;
       case mforms::TopRight:
-        image->_image->set_alignment(1.0, 0.0);
+        image->_image.set_alignment(1.0, 0.0);
         break;
       case mforms::WizardLabelAlignment:
         break;
