@@ -41,14 +41,13 @@ class ListBoxImpl : public ViewImpl
       Gtk::TreeModelColumn<Glib::ustring> _item;
   };
 
-  Gtk::TreeView                 *_lbox;
-  Gtk::ScrolledWindow           *_swin;
-
   ComboColumn                    _ccol;
   Glib::RefPtr<Gtk::ListStore>   _store;
+  Gtk::TreeView                  _lbox;
+  Gtk::ScrolledWindow            _swin;
 
-  virtual Gtk::Widget *get_outer() const { return _swin; }
-  virtual Gtk::Widget *get_inner() const { return _lbox; }
+  virtual Gtk::Widget *get_outer() const { return &(const_cast<Gtk::ScrolledWindow&>(_swin)); }
+  virtual Gtk::Widget *get_inner() const { return &(const_cast<Gtk::TreeView&>(_lbox)); }
 
 protected:
   ListBoxImpl(::mforms::ListBox *self, bool multi_select);
