@@ -30,17 +30,33 @@ namespace gtk {
 class TextEntryImpl : public ViewImpl
 {
   Gtk::Entry    *_entry;
+  std::string _placeholder;
+  Gdk::Color _text_color;
+  TextEntryType _type;
+  bool _has_real_text;
+  bool _changing_text;
   virtual Gtk::Widget *get_outer() const { return _entry; }
   
   TextEntryImpl(::mforms::TextEntry *self, TextEntryType type);
   static bool create(::mforms::TextEntry *self, TextEntryType type);
   static void set_text(::mforms::TextEntry *self, const std::string &text);
+  static void set_placeholder_text(::mforms::TextEntry *self, const std::string &text);
   static void set_max_length(::mforms::TextEntry *self, int len);
   static std::string get_text(::mforms::TextEntry *self);
   static void set_read_only(::mforms::TextEntry *self, bool flag);
   void activated(mforms::TextEntry *self);
   bool key_press(GdkEventKey *event, mforms::TextEntry *self);
-  
+ 
+#if GTK_VERSION_GT(2, 16)
+  void icon_pressed(Gtk::EntryIconPosition pos, const GdkEventButton *ev);
+#endif
+
+  void set_placeholder_text(const std::string &text);
+  void set_text(const std::string &text);
+  void focus_in(GdkEventFocus*);
+  void focus_out(GdkEventFocus*);
+  void changed(mforms::TextEntry *);
+
 public:
   static void init();
 };
