@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008, 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2013, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -104,7 +104,7 @@ public:
     Glib::RefPtr<Gtk::TreeStore> store(_treeview->tree_store());
     Gtk::TreeIter new_iter;
     
-    if (index < 0)
+    if (index < 0 || index >= store->children().size())
       new_iter = store->append();
     else
     {
@@ -428,6 +428,11 @@ public:
   {
   }
 
+  TreeNodeImpl(TreeNodeViewImpl *tree, const Gtk::TreeRowReference &ref)
+  : RootTreeNodeImpl(tree), _rowref(ref)
+  {
+  }
+
   virtual bool equals(const TreeNode &other)
   {
     const TreeNodeImpl *impl = dynamic_cast<const TreeNodeImpl*>(&other);
@@ -443,6 +448,13 @@ public:
 
   virtual void invalidate()
   {
+    if (_treeview)
+    {
+      std::map<std::string, Gtk::TreeRowReference>::iterator it = _treeview->_tagmap.find(get_tag());
+      if (it != _treeview->_tagmap.end())
+        _treeview->_tagmap.erase(it);
+    }
+
     _treeview = 0;
     _rowref = Gtk::TreeRowReference();
   }
@@ -667,7 +679,25 @@ public:
     if (is_valid() && !is_root())
     {
       Gtk::TreeRow row = *iter();
+      std::string old_tag = row[_treeview->_columns.tag_column()];
+
+      if (!old_tag.empty())
+      {
+        std::map<std::string, Gtk::TreeRowReference>::iterator it = _treeview->_tagmap.find(old_tag);
+        if (it != _treeview->_tagmap.end())
+          _treeview->_tagmap.erase(it);
+      }
+
       row[_treeview->_columns.tag_column()] = tag;
+
+      if (tag.empty())
+      {
+        std::map<std::string, Gtk::TreeRowReference>::iterator it = _treeview->_tagmap.find(tag);
+        if (it != _treeview->_tagmap.end())
+          _treeview->_tagmap.erase(it);
+      }
+      else
+        _treeview->_tagmap[tag] = _rowref;
     }
   }
 
@@ -858,6 +888,7 @@ TreeNodeViewImpl::TreeNodeViewImpl(TreeNodeView *self, mforms::TreeOptions opts)
   : ViewImpl(self), _row_height(-1)
 {
   _flat_list = (opts & mforms::TreeFlatList) != 0;
+  _tagmap_enabled = (opts & mforms::TreeIndexOnTag) != 0;
 
   _swin.set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
   if (opts & mforms::TreeNoBorder)
@@ -1380,6 +1411,21 @@ TreeNodeRef TreeNodeViewImpl::node_at_row(TreeNodeView *self, int row)
   return TreeNodeRef();
 }
 
+
+TreeNodeRef TreeNodeViewImpl::node_with_tag(TreeNodeView *self, const std::string &tag)
+{
+  TreeNodeViewImpl* impl = self->get_data<TreeNodeViewImpl>();
+  if (impl->_tagmap_enabled)
+  {
+    std::map<std::string, Gtk::TreeRowReference>::iterator it;
+    if ((it = impl->_tagmap.find(tag)) == impl->_tagmap.end())
+      return TreeNodeRef();
+    return TreeNodeRef(new TreeNodeImpl(impl, it->second));
+  }
+  throw std::logic_error("node_with_tag() requires tree to be created with TreeIndexOnTag");
+}
+
+
 void TreeNodeViewImpl::init()
 {
   ::mforms::ControlFactory *f = ::mforms::ControlFactory::get_instance();
@@ -1399,6 +1445,7 @@ void TreeNodeViewImpl::init()
   f->_treenodeview_impl.freeze_refresh= &TreeNodeViewImpl::freeze_refresh;
   f->_treenodeview_impl.set_row_height= &TreeNodeViewImpl::set_row_height;
   f->_treenodeview_impl.node_at_row= &TreeNodeViewImpl::node_at_row;
+  f->_treenodeview_impl.node_with_tag= &TreeNodeViewImpl::node_with_tag;
   f->_treenodeview_impl.row_for_node= &TreeNodeViewImpl::row_for_node;
 }
 
