@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -31,6 +31,7 @@ extern "C" {
 
 // this is broken
 //#undef USE_KEYRING
+#include "../lf_mforms.h"
 
 #include "base/file_functions.h"
 #include "../lf_utilities.h"
@@ -195,16 +196,19 @@ int UtilitiesImpl::show_message(const std::string &title, const std::string &tex
                         const std::string &ok, const std::string &cancel,
                         const std::string &other)
 {
-  Gtk::MessageDialog dlg("<b>"+title+"</b>\n"+text, true,
+  Gtk::MessageDialog dlg("<b>"+title+"</b>", true,
                          Gtk::MESSAGE_INFO, Gtk::BUTTONS_NONE, true);
-
+  dlg.set_secondary_text(text);
   dlg.add_button(ok, mforms::ResultOk);
   if (!cancel.empty())
     dlg.add_button(cancel, mforms::ResultCancel);
   if (!other.empty())
     dlg.add_button(other, mforms::ResultOther);
 
-  dlg.set_transient_for(*get_mainwindow());
+  //unnecessary.. apparently newer window managers set this automatically for dialogs
+  //and setting this to main_window explicitly will break that and cause the dialog
+  //to be assigned to the wrong window when a non-main window is the actual owner
+  //dlg.set_transient_for(*get_mainwindow());
   int r= dlg.run();
   if (r == Gtk::RESPONSE_DELETE_EVENT)
     return mforms::ResultCancel;
@@ -216,16 +220,16 @@ int UtilitiesImpl::show_error(const std::string &title, const std::string &text,
                       const std::string &ok, const std::string &cancel,
                       const std::string &other)
 {
-  Gtk::MessageDialog dlg("<b>"+title+"</b>\n"+text, true,
+  Gtk::MessageDialog dlg("<b>"+title+"</b>", true,
                          Gtk::MESSAGE_ERROR, Gtk::BUTTONS_NONE, true);
-
+  dlg.set_secondary_text(text);
   dlg.add_button(ok, mforms::ResultOk);
   if (!cancel.empty())
     dlg.add_button(cancel, mforms::ResultCancel);
   if (!other.empty())
     dlg.add_button(other, mforms::ResultOther);
 
-  dlg.set_transient_for(*get_mainwindow());
+//  dlg.set_transient_for(*get_mainwindow());
   int r= dlg.run();
   if (r == Gtk::RESPONSE_DELETE_EVENT)
     return mforms::ResultCancel;
@@ -236,16 +240,16 @@ int UtilitiesImpl::show_warning(const std::string &title, const std::string &tex
                       const std::string &ok, const std::string &cancel,
                       const std::string &other)
 {
-  Gtk::MessageDialog dlg("<b>"+title+"</b>\n"+text, true,
+  Gtk::MessageDialog dlg("<b>"+title+"</b>", true,
                          Gtk::MESSAGE_WARNING, Gtk::BUTTONS_NONE, true);
-  
+  dlg.set_secondary_text(text);
   dlg.add_button(ok, mforms::ResultOk);
   if (!cancel.empty())
     dlg.add_button(cancel, mforms::ResultCancel);
   if (!other.empty())
     dlg.add_button(other, mforms::ResultOther);
 
-  dlg.set_transient_for(*get_mainwindow());
+  //dlg.set_transient_for(*get_mainwindow());
   int r= dlg.run();
   if (r == Gtk::RESPONSE_DELETE_EVENT)
     return mforms::ResultCancel;
@@ -257,19 +261,17 @@ static void handle_click(Gtk::CheckButton* btn, bool* state)
   *state = btn->get_active();
 }
 
-int show_message_with_checkbox(const std::string &title, const std::string &text,
+int UtilitiesImpl::show_message_with_checkbox(const std::string &title, const std::string &text,
                                const std::string &ok, const std::string &cancel,
                                const std::string &other,
                                const std::string &checkbox_text, // empty text = default "Don't show this message again" text
                                bool &remember_checked)
 {
-  Gtk::Dialog dlg("<b>"+title+"</b>\n"+text, true, true);
-
-  Gtk::VBox *vbox = dlg.get_vbox();
-  vbox->add(*Gtk::manage(new Gtk::Label(text, true)));
+  Gtk::MessageDialog dlg("<b>"+title+"</b>", true, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE, true);
+  dlg.set_secondary_text(text);
 
   Gtk::CheckButton* btn = Gtk::manage(new Gtk::CheckButton(checkbox_text.empty() ? "Don't show this message again" : checkbox_text));
-  vbox->add(*btn);
+  dlg.get_vbox()->pack_start(*btn, false, true);
   btn->set_active(remember_checked);
   btn->signal_clicked().connect(sigc::bind(sigc::ptr_fun(handle_click), btn, &remember_checked));
 
@@ -280,8 +282,8 @@ int show_message_with_checkbox(const std::string &title, const std::string &text
     dlg.add_action_widget(*Gtk::manage(new Gtk::Button(cancel)), mforms::ResultCancel);
   if (!other.empty())
     dlg.add_action_widget(*Gtk::manage(new Gtk::Button(other)), mforms::ResultOther);
-
-  dlg.set_transient_for(*get_mainwindow());
+  dlg.show_all();
+ // dlg.set_transient_for(*get_mainwindow());
   int r= dlg.run();
   if (r == Gtk::RESPONSE_DELETE_EVENT)
     return mforms::ResultCancel;
@@ -758,7 +760,10 @@ void TransparentMessage::show_message(const std::string& title, const std::strin
   window->set_opacity(0.85);
 #endif
   window->process_updates(true);
+
   show_now();
+
+  window->freeze_updates(); // Added to stop idle window update requests storm in gnome-3
 }
 
 
@@ -878,6 +883,33 @@ void UtilitiesImpl::stop_cancelable_wait_message()
   }
 }
 
+   
+Glib::RefPtr<Gdk::Pixbuf> UtilitiesImpl::get_cached_icon(const std::string &icon)
+{
+  std::map<std::string, Glib::RefPtr<Gdk::Pixbuf> > cache;
+
+  if (cache.find(icon) != cache.end())
+    return cache[icon];
+
+  if (icon == "folder")
+  {
+    Glib::RefPtr<Gdk::Pixbuf> pix = get_mainwindow()->render_icon(Gtk::Stock::DIRECTORY, Gtk::ICON_SIZE_MENU);
+    cache[icon] = pix;
+    return pix;
+  }
+  else
+  {
+    std::string path = mforms::App::get()->get_resource_path(icon);
+    if (!path.empty() && g_file_test(path.c_str(), G_FILE_TEST_IS_REGULAR))
+    {
+      cache[icon] = Gdk::Pixbuf::create_from_file(path);
+      return cache[icon];
+    }
+    else
+      g_warning("Can't find icon %s", icon.c_str());
+  }
+  return Glib::RefPtr<Gdk::Pixbuf>();
+}
 
 
 //------------------------------------------------------------------------------
@@ -889,6 +921,7 @@ void UtilitiesImpl::init()
   f->_utilities_impl.show_message= &UtilitiesImpl::show_message;
   f->_utilities_impl.show_error= &UtilitiesImpl::show_error;
   f->_utilities_impl.show_warning= &UtilitiesImpl::show_warning;
+  f->_utilities_impl.show_message_with_checkbox= &UtilitiesImpl::show_message_with_checkbox;
   f->_utilities_impl.show_wait_message= &UtilitiesImpl::show_wait_message;
   f->_utilities_impl.hide_wait_message= &UtilitiesImpl::hide_wait_message;
   f->_utilities_impl.run_cancelable_wait_message= &UtilitiesImpl::run_cancelable_wait_message;
@@ -913,7 +946,7 @@ void UtilitiesImpl::init()
 
 void MainThreadRequestQueue::from_main_thread()
 {
-  Request *req;
+  boost::shared_ptr<Request> req;
   {
     Glib::Mutex::Lock lock(_mutex);
     if (_queue.empty())
@@ -941,27 +974,38 @@ MainThreadRequestQueue *MainThreadRequestQueue::get()
   return q;
 }
 
-void *MainThreadRequestQueue::perform(const boost::function<void* ()> &slot)
+void *MainThreadRequestQueue::perform(const boost::function<void* ()> &slot, bool wait)
 {
-  MainThreadRequestQueue *self = MainThreadRequestQueue::get();
-
-  Request req;
-  req.slot = slot;
-  req.done = false;
-  req.result = 0;
+  if (Utilities::in_main_thread())
+    return slot();
+  else
   {
-    Glib::Mutex::Lock lock(self->_mutex);
-    self->_queue.push_back(&req);
+    MainThreadRequestQueue *self = MainThreadRequestQueue::get();
+
+    boost::shared_ptr<Request> req(new Request());
+    req->slot = slot;
+    req->done = false;
+    req->result = 0;
+    {
+      Glib::Mutex::Lock lock(self->_mutex);
+      self->_queue.push_back(req);
+    }
+    self->_disp.emit();
+
+    if (wait)
+    {
+      Glib::Mutex::Lock lock(req->mutex);
+      while (!req->done)
+        req->cond.wait(req->mutex);
+
+      return req->result;
+    }
+    return NULL;
   }
-  self->_disp.emit();
-
-  Glib::Mutex::Lock lock(req.mutex);
-  while (!req.done)
-    req.cond.wait(req.mutex);
-
-  return req.result;
 }
 
 
+   
+   
 };
 };
