@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -24,7 +24,7 @@
 #include <mforms/view.h>
 
 #include "cairo/cairo.h"
-#include "geometry.h"
+#include "base/geometry.h"
 
 /**
  * This class implements a popup window class which can be used for context menus or drop down menus.
@@ -48,7 +48,7 @@ namespace mforms
     void (__stdcall *set_needs_repaint)(Popup *);
     void (__stdcall *set_size)(Popup *, int, int);
     int (__stdcall *show)(Popup *, int, int);
-    MySQL::Geometry::Rect (__stdcall *get_content_rect)(Popup *);
+    base::Rect (__stdcall *get_content_rect)(Popup *);
     void (__stdcall *set_modal_result)(Popup *, int result);
   };
 #endif
@@ -62,7 +62,7 @@ namespace mforms
     void set_needs_repaint();
     void set_size(int width, int height);
     int show(int spot_x, int spot_y);
-    MySQL::Geometry::Rect get_content_rect();
+    base::Rect get_content_rect();
     void set_modal_result(int result);
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
