@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2013, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -60,6 +60,7 @@ namespace mforms {
     TreeFlatList         = 1 << 10, //!< no child items expected
     TreeAltRowColors     = 1 << 11, //!< enable alternating row colors
     TreeSizeSmall        = 1 << 12, //!< small text
+    TreeIndexOnTag       = 1 << 13  //!< keep a node index on the tags (use with node_with_tag)
   };
   
 #ifndef SWIG
@@ -169,7 +170,7 @@ namespace mforms {
     virtual void remove_children(); // default impl provided, subclasses may override to provide faster impl
     virtual TreeNodeRef get_child(int index) const = 0;
     virtual TreeNodeRef get_parent() const = 0;
-    virtual TreeNodeRef find_child_with_tag(const std::string &tag);
+    virtual TreeNodeRef find_child_with_tag(const std::string &tag); // this will search the subnodes sequentially
  
     virtual std::vector<mforms::TreeNodeRef> add_node_collection(const TreeNodeCollectionSkeleton &nodes, int position = -1) = 0;
 
@@ -219,6 +220,7 @@ namespace mforms {
     
     int (__stdcall *row_for_node)(TreeNodeView *self, TreeNodeRef node);
     TreeNodeRef (__stdcall *node_at_row)(TreeNodeView *self, int row);
+    TreeNodeRef (__stdcall *node_with_tag)(TreeNodeView *self, const std::string &tag);
   };
 #endif
 #endif
@@ -273,7 +275,10 @@ namespace mforms {
     
     int row_for_node(TreeNodeRef node);
     TreeNodeRef node_at_row(int row);
-    
+
+    /** Requires TreeIndexOnTag */
+    TreeNodeRef node_with_tag(const std::string &tag);
+
     /** Sets the height of a row in pixels */
     void set_row_height(int height);
     
@@ -356,6 +361,7 @@ namespace mforms {
     Menu *_context_menu;
     std::vector<TreeColumnType> _column_types;
     int _update_count;
+    bool _index_on_tag;
   };
 }
 
