@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -24,6 +24,8 @@
 #include <boost/signals2.hpp>
 
 #include "base/geometry.h"
+#include "base/trackable.h"
+#include "base/drawing.h"
 
 namespace mforms {
 
@@ -37,13 +39,31 @@ namespace mforms {
     ResizeBoth
   };
 
-  // Layout definition for background images.
-  enum ImageLayout {
-    LayoutNone,    //!< The image is left-aligned at the top across the control's client rectangle. 
-    LayoutTile,    //!< The image is tiled across the control's client rectangle. 
-    LayoutCenter,  //!< The image is centered within the control's client rectangle. 
-    LayoutStretch, //!< The image is stretched across the control's client rectangle. 
-    LayoutZoom     //!< The image is enlarged within the control's client rectangle. 
+  enum Alignment
+  {
+    BottomLeft,
+    BottomCenter,
+    BottomRight,
+    MiddleLeft,
+    MiddleCenter,
+    MiddleRight,
+    TopLeft,
+    TopCenter,
+    TopRight,
+    
+    //
+    WizardLabelAlignment
+  };
+  
+  struct TextAttributes
+  {
+#ifndef SWIG
+    bool bold;
+    bool italic;
+    base::Color color;
+    TextAttributes() : bold(false), italic(false), color(base::Color::Invalid()) {}
+#endif
+    TextAttributes(const std::string &c, bool b, bool i) : bold(b), italic(i), color(base::Color::parse(c)) {}
   };
 
   // Mouse button indicators for mouse handling routines.
@@ -90,16 +110,19 @@ namespace mforms {
     std::string (__stdcall *get_front_color)(View *self);
     void (__stdcall *set_back_color)(View *self, const std::string&);
     std::string (__stdcall *get_back_color)(View *self);
-    void (__stdcall *set_back_image)(View *self, const std::string&, ImageLayout layout);
+    // for containers only
+    void (__stdcall *set_back_image)(View *self, const std::string&, Alignment alignment);
 
     void (__stdcall *flush_events)(View *self);
+
+    void (__stdcall *focus)(View *self);
   };
 #endif
 #endif
   
   class Form;
 
-  class MFORMS_EXPORT View : public Object
+  class MFORMS_EXPORT View : public Object, public base::trackable
   {
     friend class ControlFactory;
 
@@ -108,21 +131,23 @@ namespace mforms {
   private:
     std::string _name;
     AutoResizeMode _resize_mode;
-    std::list<std::pair<View*, bool> > _subviews;
     bool _layout_dirty;
     
   protected:
     View();
 
     View *_parent;
+    std::list<std::pair<View*, bool> > _subviews;
 
     boost::signals2::signal<void ()> _signal_resized;
 
     void add_subview(View *sv);
-    void remove_subview(View *sv);
+    virtual void remove(View *sv);
     int get_subview_index(View *sv);
     View *get_subview_at_index(int index);
     
+    // This works only for containers so is made public in the Container subclass
+    virtual void set_back_image(const std::string& path, Alignment alignment);
   public:
     virtual ~View();
     
@@ -130,10 +155,12 @@ namespace mforms {
     
     View *find_subview(const std::string &name);
     bool contains_subview(View* subview);
+    void clear_subviews();
     
     AutoResizeMode get_resize_mode();
     void set_resize_mode(AutoResizeMode mode);
 
+    /** Triggered by the platform layers when the size of the view changes. */
     boost::signals2::signal<void ()>* signal_resized() { return &_signal_resized; }
     
     void set_name(const std::string &name);
@@ -160,11 +187,9 @@ namespace mforms {
     bool is_enabled();
     void set_needs_repaint();
 
-    virtual void needs_resize();
     virtual void relayout();
     virtual void set_layout_dirty(bool value);
     virtual bool is_layout_dirty();
-    virtual void on_resize();
     
     void suspend_layout();
     void resume_layout();
@@ -172,7 +197,6 @@ namespace mforms {
     std::string get_front_color();
     void set_back_color(const std::string& color);
     std::string get_back_color();
-    void set_back_image(const std::string& path, ImageLayout layout);
     
     void show_retain_counts(int depth=0);
 
@@ -181,6 +205,8 @@ namespace mforms {
     virtual bool get_bool_value() { return false; }
 
     virtual void flush_events();
+
+    virtual void focus();
   };
 };
 
