@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -16,45 +16,38 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301  USA
  */
+
 #include "stdafx.h"
 
-#include <mforms/mforms.h>
-#include "mforms/scrollpanel.h"
+#include "mforms/mforms.h"
 
 using namespace mforms;
 
-
 ScrollPanel::ScrollPanel(ScrollPanelFlags flags)
-  : View()
+  : Container()
 {
   _spanel_impl= &ControlFactory::get_instance()->_spanel_impl;
 
   _spanel_impl->create(this, flags);
 }
 
-
+ScrollPanel::~ScrollPanel()
+{
+  set_destroying();
+  _spanel_impl->remove(this);
+}
 
 void ScrollPanel::add(View *child)
 {
-  child->retain();
   add_subview(child);
-  child->set_parent(this);
   _spanel_impl->add(this, child);
   child->show();
-  
-  _content = child;
 }
 
-
 void ScrollPanel::remove()
 {
-  if (_content)
-  {
-    remove_subview(_content);
-    _spanel_impl->remove(this);
-    _content->release();
-    _content = 0;
-  }
+  _spanel_impl->remove(this);
+  clear_subviews();
 }
 
 
