@@ -138,7 +138,8 @@ TreeNodeView::TreeNodeView(TreeOptions options)
 : _context_menu(0), _update_count(0)
 {
   _treeview_impl= &ControlFactory::get_instance()->_treenodeview_impl;
-  
+  _index_on_tag = (options & TreeIndexOnTag) ? true : false;
+
   _treeview_impl->create(this, options);
 }
 
@@ -318,3 +319,11 @@ TreeNodeRef TreeNodeView::node_at_row(int row)
   return _treeview_impl->node_at_row(this, row);
 }
 
+
+TreeNodeRef TreeNodeView::node_with_tag(const std::string &tag)
+{
+  if (!_index_on_tag)
+    throw std::logic_error("Tree was not created with TreeIndexOnTag");
+
+  return _treeview_impl->node_with_tag(this, tag);
+}
