@@ -19,6 +19,10 @@
 
 #include "stdafx.h"
 
+#include "mforms/mforms.h"
+#include "wf_view.h"
+#include "wf_popup.h"
+
 using namespace System::Drawing;
 using namespace System::Windows::Forms;
 using namespace System::Threading;
