@@ -19,6 +19,10 @@
 
 #include "stdafx.h"
 
+#include "mforms/mforms.h"
+#include "wf_view.h"
+#include "wf_scrollpanel.h"
+
 /**
  * Implementation of a specialized mforms panel, which has scrollbars.
  * On Windows every container has scrollbars, so we don't need a separate implementation here.
@@ -69,6 +73,38 @@ bool ScrollFillLayout::Layout(Object^ sender, LayoutEventArgs^ arguments)
 
 //----------------- ScrollFillPanel ----------------------------------------------------------------
 
+private ref class WheelMessageFilter : IMessageFilter
+{
+private:
+  ScrollFillPanel^ panel;
+
+public:
+  WheelMessageFilter(ScrollFillPanel^ panel)
+  {
+    this->panel = panel;
+  }
+
+  virtual bool PreFilterMessage(Message% m)
+  {
+    if (panel != nullptr && panel->Visible && m.Msg == WM_MOUSEWHEEL)
+    {
+      // Only handle messages if the mouse without our bounds.
+      POINT cursorPoint;
+      GetCursorPos(&cursorPoint);
+      Point point = panel->PointToClient(Point(cursorPoint.x, cursorPoint.y));
+      if (panel->ClientRectangle.Contains(point))
+      {
+        panel->WndProc(m);
+        return true;
+      }
+    }
+
+    return false;
+  }
+};
+
+//--------------------------------------------------------------------------------------------------
+
 ScrollFillPanel::ScrollFillPanel()
 {
   autoHideScrollbars= true;
@@ -77,6 +113,18 @@ ScrollFillPanel::ScrollFillPanel()
   horizontalOffset= 0;
   verticalOffset= 0;
   updateCount= 0;
+
+  // In addition to the normal scroll wheel handling we add a message filter for scroll wheel
+  // messages to react also to them if the mouse is within our client area but we are not focused.
+  wheelMessageFilter = gcnew WheelMessageFilter(this);
+  Application::AddMessageFilter(wheelMessageFilter);
+}
+
+//--------------------------------------------------------------------------------------------------
+
+ScrollFillPanel::~ScrollFillPanel()
+{
+  Application::RemoveMessageFilter(wheelMessageFilter);
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -201,7 +249,7 @@ void ScrollFillPanel::HandleWheelScrolling(Message% m)
     if (maxSize.Width > ClientSize.Width)
     {
       scrollAmount= (int) (wheelFactor * scrollLines);
-      SetOffset(horizontalOffset, verticalOffset + scrollAmount);
+      SetOffset(horizontalOffset + scrollAmount, verticalOffset);
     }
 
   m.Result= IntPtr::Zero;
