@@ -19,6 +19,11 @@
 
 #include "stdafx.h"
 
+#include "mforms/mforms.h"
+#include "wf_view.h"
+#include "wf_table.h"
+#include "wf_label.h"
+
 using namespace MySQL;
 using namespace MySQL::Forms;
 using namespace MySQL::Utilities;
@@ -218,12 +223,26 @@ System::Drawing::Size Table::ComputeLayout(System::Drawing::Size proposedSize, b
 
     // Check if the width of the entry is larger than what we have already.
     // While we are at it, keep the expand state in the associated cells.
-    int currentWidth= 0;
-    for (int i= entry->leftAttachment; i < entry->rightAttachment; i++)
+    // However, if the current entry is expanding and covers a column which is already set to expand
+    // then don't apply expansion, as we only want to expand those columns.
+    int currentWidth = 0;
+    bool doExpand = entry->horizontalExpand;
+    if (doExpand)
+    {
+      for (int i = entry->leftAttachment; i < entry->rightAttachment; i++)
+      {
+        if (horizontalExpandState[i])
+        {
+          doExpand = false;
+          break;
+        }
+      }
+    }
+    for (int i = entry->leftAttachment; i < entry->rightAttachment; i++)
     {
       currentWidth += widths[i];
-      if (entry->horizontalExpand)
-        horizontalExpandState[i]= true;
+      if (doExpand)
+        horizontalExpandState[i] = true;
     }
 
     bool use_min_width = ViewImpl::use_min_width_for_layout(entry->control);
@@ -331,11 +350,24 @@ System::Drawing::Size Table::ComputeLayout(System::Drawing::Size proposedSize, b
     // On the way apply the expand flag to all cells that are covered by that entry.
 
     // Check if the height of the entry is larger than what we have already.
+    // Same expansion handling here as for horizontal expansion.
     int currentHeight= 0;
+    bool doExpand = entry->verticalExpand;
+    if (doExpand)
+    {
+      for (int i = entry->topAttachment; i < entry->bottomAttachment; i++)
+      {
+        if (verticalExpandState[i])
+        {
+          doExpand = false;
+          break;
+        }
+      }
+    }
     for (int i= entry->topAttachment; i < entry->bottomAttachment; i++)
     {
       currentHeight += heights[i];
-      if (entry->verticalExpand)
+      if (doExpand)
         verticalExpandState[i]= true;
     }
 
