@@ -23,6 +23,13 @@
 
 #include "stdafx.h"
 
+#include "mforms/mforms.h"
+#include "wf_view.h"
+#include "wf_tabview.h"
+#include "wf_panel.h"
+
+#include "ConvUtils.h"
+
 using namespace System::Drawing;
 using namespace System::Windows::Forms;
 
