@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2013, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -29,9 +29,12 @@
 #include "wf_view.h"
 #include "wf_utilities.h"
 
+#include "base/log.h"
 #include "base/string_utilities.h"
 #include "ConvUtils.h"
 
+DEFAULT_LOG_DOMAIN(DOMAIN_MFORMS_WRAPPER)
+
 using namespace MySQL::Forms;
 using namespace MySQL::Utilities;
 
@@ -39,6 +42,8 @@ using namespace MySQL::Utilities;
 
 CustomMessageBox::CustomMessageBox()
 {
+  log_debug("Creating custom message box in old style\n");
+
   _picture= gcnew Windows::Forms::PictureBox();
   _button1= gcnew Windows::Forms::Button();
   _button2= gcnew Windows::Forms::Button();
@@ -121,6 +126,8 @@ mforms::DialogResult CustomMessageBox::ShowVistaStyle(const std::string& title,
   PCWSTR mainIcon, const std::string& buttonOK, const std::string& buttonCancel,
   const std::string& buttonOther, const std::string& checkbox, bool& checked)
 {
+  log_debug("Creating custom message box in vista style\n");
+
   // Load TaskDialogIndirect dynamically so we don't get a problem on XP.
   HMODULE comctl32 = LoadLibraryW(L"comctl32.dll");
   PTaskDialogIndirect _TaskDialogIndirect = (PTaskDialogIndirect) GetProcAddress(comctl32, "TaskDialogIndirect");
@@ -188,7 +195,11 @@ mforms::DialogResult CustomMessageBox::ShowVistaStyle(const std::string& title,
   if (checkbox_text.size() > 0)
     config.pszVerificationText = checkbox_text.c_str();
 
+  log_debug("Running custom message box\n");
+
   HRESULT result = _TaskDialogIndirect(&config, &button, &radioButton, &verificationChecked);
+  FreeLibrary(comctl32);
+
   if (!SUCCEEDED(result))
     return mforms::ResultCancel;
 
@@ -204,8 +215,6 @@ mforms::DialogResult CustomMessageBox::ShowVistaStyle(const std::string& title,
   default:
     return mforms::ResultOther;
   }
-
-  FreeLibrary(comctl32);
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -216,6 +225,8 @@ mforms::DialogResult CustomMessageBox::ShowVistaStyle(const std::string& title,
 mforms::DialogResult CustomMessageBox::ShowTraditionalStyle(String^ title,  String^ text, Image^ image,  String^ button1,
    String^ button2,  String^ button3,  String^ checkbox, bool& checked)
 {
+  log_debug("Showing traditional custom message box\n");
+
   CustomMessageBox^ box= gcnew CustomMessageBox();
   
   box->_picture->Image= image; 
@@ -287,6 +298,8 @@ void AdjustButton(Windows::Forms::Button^ button)
  */
 void CustomMessageBox::ComputeLayout()
 {
+  log_debug2("Layouting custom message box\n");
+
   SuspendLayout();
 
   // Buttons have a minimum width of 75 px. Make them all same size and hide those which don't have
@@ -448,6 +461,8 @@ void CustomMessageBox::ComputeLayout()
 
 void CustomMessageBox::ButtonClick(Object^ sender, EventArgs^ arguments)
 {
+  log_debug2("Button was clicked in custom message box\n");
+
   DialogResult = ((Windows::Forms::Button^)sender)->DialogResult;
 }
 
@@ -457,6 +472,8 @@ mforms::DialogResult CustomMessageBox::Show(const std::string& title, const std:
   PCWSTR mainIcon, const std::string& buttonOK, const std::string& buttonCancel,
   const std::string& buttonOther, const std::string& checkbox, bool& checked)
 {
+  log_debug("About to show a custom message box\n");
+
   // Our message looks different depending on whether we are running on XP or Vista and above.
   if (ControlUtilities::IsVistaOrAbove())
   {
@@ -498,6 +515,8 @@ mforms::DialogResult CustomMessageBox::Show(const std::string& title, const std:
 Windows::Forms::DialogResult CustomMessageBox::Show(MessageType type,  String^ title,  String^ text,  
    String^ buttonOK,  String^ buttonCancel,  String^ buttonOther,  String^ checkbox, [Out] bool% checked)
 {
+  log_debug("About to show a custom message box\n");
+
   mforms::DialogResult result;
 
   // Our message looks different depending on whether we are running on XP or Vista and above.
@@ -581,8 +600,12 @@ delegate InvokationResult^ RunSlotDelegate();
 
 void* DispatchControl::RunOnMainThread(const boost::function<void* ()>& slot, bool wait)
 {
+  log_debug("Running slot on main thread (%s waiting for it)\n", wait ? "" : "not");
+
   if (InvokeRequired)
   {
+    log_debug2("Cross thread invocation required\n");
+
     _slot = new boost::function<void* ()>(slot);
     if (wait)
     {
@@ -615,6 +638,8 @@ DispatchControl::~DispatchControl()
  */
 InvokationResult^ DispatchControl::RunSlot()
 {
+  log_debug2("Running slot on main thread\n");
+
   return gcnew InvokationResult((*_slot)());
 }
 
@@ -629,6 +654,8 @@ UtilitiesImpl::UtilitiesImpl()
 int UtilitiesImpl::show_message(const std::string &title, const std::string &text, const std::string &ok, 
   const std::string &cancel, const std::string &other)
 {
+  log_debug("Showing a message to the user\n");
+
   hide_wait_message();
 
   bool checked;
@@ -640,6 +667,8 @@ int UtilitiesImpl::show_message(const std::string &title, const std::string &tex
 int UtilitiesImpl::show_error(const std::string &title, const std::string &text, const std::string &ok, 
   const std::string &cancel, const std::string &other)
 {
+  log_debug("Showing an error to the user\n");
+
   hide_wait_message();
 
   bool checked;
@@ -651,6 +680,8 @@ int UtilitiesImpl::show_error(const std::string &title, const std::string &text,
 int UtilitiesImpl::show_warning(const std::string &title, const std::string &text, const std::string &ok, 
   const std::string &cancel, const std::string &other)
 {
+  log_debug("Showing a warning to the user\n");
+
   hide_wait_message();
 
   bool checked;
@@ -663,6 +694,8 @@ int UtilitiesImpl::show_message_with_checkbox(const std::string &title, const st
   const std::string &ok, const std::string &cancel, const std::string &other, const std::string &checkbox_text,
   bool &isChecked)
 {
+  log_debug("Showing a message with checkbox to the user\n");
+
   hide_wait_message();
 
   std::string checkboxText = (checkbox_text.size() > 0) ? checkbox_text :
@@ -678,6 +711,8 @@ int UtilitiesImpl::show_message_with_checkbox(const std::string &title, const st
  */
 void UtilitiesImpl::show_wait_message(const std::string &title, const std::string &text)
 {
+  log_debug("Showing wait message\n");
+
   HUDForm::Show(CppStringToNative(title), CppStringToNative(text), true);
 }
 
@@ -688,9 +723,19 @@ void UtilitiesImpl::show_wait_message(const std::string &title, const std::strin
  */
 bool UtilitiesImpl::hide_wait_message()
 {
+  log_debug("Hiding the wait message\n");
+
   bool result= HUDForm::IsVisible;
   if (result)
+  {
+    log_debug2("Wait message was visible, finishing it\n");
+
     HUDForm::Finished();
+  }
+  else
+    log_debug2("Wait message was not visibile, nothing to do\n");
+
+
   return result;
 }
 
@@ -713,6 +758,8 @@ bool UtilitiesImpl::run_cancelable_wait_message(const std::string &title, const
                                                 const boost::function<void ()> &start_task,
                                                 const boost::function<bool ()> &cancel_slot)
 {
+  log_debug("Running a cancelable wait message\n");
+
   CallSlotDelegate ^caller = gcnew CallSlotDelegate(&cancel_slot);
 
   HUDForm::CancelDelegate ^deleg = gcnew HUDForm::CancelDelegate(caller, &CallSlotDelegate::call_slot);
@@ -723,9 +770,15 @@ bool UtilitiesImpl::run_cancelable_wait_message(const std::string &title, const
   // ShowModal. That will cause the modal window will stay up forever.
 
   if (start_task)
-    start_task();
+  {
+    log_debug2("Starting the task\n");
 
+    start_task();
+  }
+
+  log_debug2("Running the HUD window\n");
   Windows::Forms::DialogResult result = HUDForm::ShowModal(CppStringToNative(title), CppStringToNative(text), true, deleg);
+  log_debug2("HUD window returned with code: %i\n", result);
 
   // Abort is used if the window was forcibly closed (e.g. when showing another dialog, like password query).
   return (result == Windows::Forms::DialogResult::OK) || (result == Windows::Forms::DialogResult::Abort);
@@ -739,6 +792,8 @@ bool UtilitiesImpl::run_cancelable_wait_message(const std::string &title, const
  */
 void UtilitiesImpl::stop_cancelable_wait_message()
 {
+  log_debug("Explicit cancelation of the wait message\n");
+
   // Wait until the HUDForm is visible (ie ShowModal is called) before closing it
   // to avoid race condition. This could deadlock only if start_task() is not a 
   // thread, which would be a problem in itself.
@@ -756,6 +811,8 @@ void UtilitiesImpl::stop_cancelable_wait_message()
  */
 void UtilitiesImpl::set_clipboard_text(const std::string &content)
 {
+  log_debug("Setting clipboard text\n");
+
   if (!content.empty())
   {
     String^ text = CppStringToNative(content);
@@ -766,12 +823,16 @@ void UtilitiesImpl::set_clipboard_text(const std::string &content)
       // If the clipboard cannot be opened because another application uses it at this very moment
       // we try a second time with built-in retries. If that still fails we inform the user.
       Clipboard::SetText(text);
+
+      log_debug2("Successful\n");
     }
     catch (ExternalException ^)
     {
       try
       {
+        log_debug2("Got exception, second attempt\n");
         Clipboard::SetDataObject(text, false, 5, 200);
+        log_debug2("Successful\n");
       }
       catch (ExternalException ^e)
       {
@@ -783,6 +844,7 @@ void UtilitiesImpl::set_clipboard_text(const std::string &content)
         GetWindowText(window, window_text, 500);
         String ^converted_text = gcnew String(window_text);
         msg += converted_text;
+        log_debug2("Error while setting the text: %s\n", NativeToCppString(msg).c_str());
 
         CustomMessageBox::Show(MessageType::MessageError, _("Error while copying to clipboard"), msg, "Close");
       }
@@ -800,6 +862,8 @@ void UtilitiesImpl::set_clipboard_text(const std::string &content)
  */
 std::string UtilitiesImpl::get_clipboard_text()
 {
+  log_debug("Reading clipboard text\n");
+
   String^ unicode= (String^) Clipboard::GetData(DataFormats::UnicodeText);
   if (unicode == nullptr)
     return "";
@@ -814,6 +878,8 @@ std::string UtilitiesImpl::get_clipboard_text()
  */
 std::string UtilitiesImpl::get_special_folder(mforms::FolderType type)
 {
+  log_debug("Get special folder\n");
+
   Environment::SpecialFolder special_folder;
   switch (type)
   {
@@ -838,6 +904,8 @@ std::string UtilitiesImpl::get_special_folder(mforms::FolderType type)
   // IntPtr has a size of 8 for 64 bit apps.
   if (IntPtr::Size == 4 && type == mforms::WinProgramFiles)
   {
+    log_debug2("Getting the 64bit program path\n");
+
     WCHAR folder[MAX_PATH];
     ExpandEnvironmentStrings(L"%ProgramW6432%", folder, ARRAYSIZE(folder));
     return base::wstring_to_string(folder);
@@ -851,11 +919,16 @@ void UtilitiesImpl::open_url(const std::string &url)
 {
   try
   {
+    log_debug("Opening the URL: %s\n", url.c_str());
+
     System::Diagnostics::Process::Start(CppStringToNative(url));
   }
   catch (Exception ^e)
   {
-    MessageBox::Show(e->Message->ToString(), "Error Opening Browser", 
+    String ^message = e->Message->ToString();
+    log_debug("Error opening the url: %s\n", NativeToCppString(message).c_str());
+
+    MessageBox::Show(message, "Error Opening Browser", 
       MessageBoxButtons::OK, MessageBoxIcon::Error, MessageBoxDefaultButton::Button1);
   }
 }
@@ -864,6 +937,8 @@ void UtilitiesImpl::open_url(const std::string &url)
 
 bool UtilitiesImpl::move_to_trash(const std::string &file_name)
 {
+  log_debug("Moving file to trash: %s\n", file_name.c_str());
+  
   SHFILEOPSTRUCT shf = {0};
 
   // Filenames must be double 0 terminated.
@@ -896,6 +971,8 @@ typedef std::map<std::string, std::string>::iterator PasswordIterator;
  */
 void UtilitiesImpl::load_passwords()
 {
+  log_debug("Loading password cache\n");
+  
   // Load password cache from disk. Don't throw an error if the cache file doesn't exist yet, though.
   std::string file= get_special_folder(mforms::ApplicationData) + "/MySQL/Workbench/workbench_user_data.dat";
   if (g_file_test(file.c_str(), G_FILE_TEST_EXISTS))
@@ -906,6 +983,7 @@ void UtilitiesImpl::load_passwords()
     bool result= g_file_get_contents(file.c_str(), &content, &length, &error) == TRUE;
     if (!result)
     {
+      log_error("Error loading password data: %s\n", error->message);
       show_error("Password management error", "Error while loading passwords: " + std::string(error->message),
         _("Close"), "", "");
       return;
@@ -916,18 +994,23 @@ void UtilitiesImpl::load_passwords()
 
     data_in.pbData= (BYTE*) content;
     data_in.cbData= length;
-    result= CryptUnprotectData(&data_in, NULL, NULL, NULL, NULL, CRYPTPROTECT_UI_FORBIDDEN, &data_out) == TRUE;
+    
+    log_debug2("Decrypting password data\n");
+    result = CryptUnprotectData(&data_in, NULL, NULL, NULL, NULL, CRYPTPROTECT_UI_FORBIDDEN, &data_out) == TRUE;
     
     g_free(content);
 
     if (!result)
     {
+      log_error("Could not decrypt password data\n");
       show_error("Password management error", "Could not decrypt password cache.",  _("Close"), "", "");
       return;
     }
 
     try
     {
+      log_debug2("Filling password cache\n");
+
       // Split the string into individual items and fill the password cache with them.
       std::stringstream ss((char*) data_out.pbData);
       std::string item;
@@ -954,11 +1037,15 @@ void UtilitiesImpl::load_passwords()
  */
 void UtilitiesImpl::unload_passwords(bool store)
 {
+  log_debug("Unloading password cache\n");
+  
   // Store all passwords in a string for encryption.
   try
   {
     if (store)
     {
+      log_debug("Storing password data\n");
+
       std::string plain_data;
       for (PasswordIterator iterator= password_cache.begin(); iterator != password_cache.end(); iterator++)
         plain_data += iterator->first + PASSWORD_SEPARATOR + iterator->second + "\n";
@@ -971,6 +1058,7 @@ void UtilitiesImpl::unload_passwords(bool store)
       
       if (!CryptProtectData(&data_in, NULL, NULL, NULL, NULL, CRYPTPROTECT_UI_FORBIDDEN, &data_out))
       {
+        log_error("Error encrypting password data\n");
         show_error("Password management error", "Could not encrypt password cache.", _("Close"), "", "");
         return;
       }
@@ -983,8 +1071,11 @@ void UtilitiesImpl::unload_passwords(bool store)
       LocalFree(data_out.pbData);
 
       if (!result)
+      {
+        log_error("Error storing password data: %s\n", error->message);
         show_error("Password management error", "Error while storing passwords: " + std::string(error->message),
-        _("Close"), "", "");
+          _("Close"), "", "");
+      }
     }
   }
   finally
@@ -1026,6 +1117,8 @@ void UtilitiesImpl::store_password(const std::string &service, const std::string
  */
 bool UtilitiesImpl::find_password(const std::string &service, const std::string &account, std::string &password)
 {
+  log_debug("Looking up password for service: %s, account: %s\n", service.c_str(), account.c_str());
+  
   g_static_mutex_lock(&password_mutex);
 
   try
@@ -1090,6 +1183,8 @@ void* UtilitiesImpl::perform_from_main_thread(const boost::function<void* ()>& s
  */
 Windows::Forms::Form^ UtilitiesImpl::get_mainform()
 {
+  log_debug2("Returning main form\n");
+
   return Application::OpenForms["MainForm"];
 }
 
@@ -1100,6 +1195,8 @@ public ref class TimerHandler
 public:
   TimerHandler(float interval, const boost::function<bool ()> &slot)
   {
+    log_debug("Creating new TimerHandler\n");
+
     _timer = gcnew System::Windows::Forms::Timer();
 
     _slot = new boost::function<bool ()>(slot);
@@ -1111,6 +1208,8 @@ public:
 
   ~TimerHandler()
   {
+    log_debug("Destructing TimerHandler instance\n");
+
     _timer->Stop();
     delete _timer;
     delete _slot;
@@ -1122,8 +1221,10 @@ private:
 
   void timer_tick(Object^ sender, System::EventArgs ^e)
   {
-    // emulate behaviour in MacOS X (timers arent fired when in modal loops)
-    // also works around a deadlock of python when a timer is fired while inside a modal loop
+    log_debug3("Timer tick\n");
+
+    // Emulate behavior in MacOS X (timers aren't fired when in modal loops).
+    // Also works around a deadlock of python when a timer is fired while inside a modal loop.
     if (!mforms::Utilities::in_modal_loop())
     {
       _timer->Stop();
@@ -1141,6 +1242,8 @@ private:
 
 void UtilitiesImpl::add_timeout(float interval, const boost::function<bool ()> &slot)
 {
+  log_debug("Adding new timeout\n");
+
   TimerHandler ^handler = gcnew TimerHandler(interval, slot);
 }
 
