@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008, 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2013, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -643,13 +643,18 @@ String^ ViewImpl::get_front_color()
 
 void ViewImpl::set_back_color(String ^color)
 {
-  get_control<Control>()->BackColor= System::Drawing::ColorTranslator::FromHtml(color);
+  if (color == "")
+    get_control<Control>()->BackColor = Color::Transparent;
+  else
+    get_control<Control>()->BackColor = System::Drawing::ColorTranslator::FromHtml(color);
 }
 
 //-------------------------------------------------------------------------------------------------
 
 String^ ViewImpl::get_back_color()
 {
+  if (get_control<Control>()->BackColor == Color::Transparent)
+    return "";
   return System::Drawing::ColorTranslator::ToHtml(get_control<Control>()->BackColor);
 }
 
