@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2013, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -68,6 +68,7 @@ namespace MySQL {
 
       virtual Collections::IEnumerable^ GetChildren(TreePath ^treePath) override;
 
+      void Resort();
     };
 
     private ref class AttributedNodeText : public NodeTextBox
@@ -90,20 +91,22 @@ namespace MySQL {
       bool _flat_list;
       SortOrder _current_sort_order;
       List<ManagedTreeColumnType> _column_types;
-    protected:
-      static bool create(::mforms::TreeNodeView *self, ::mforms::TreeOptions options);
-      static int add_column(::mforms::TreeNodeView *self, ::mforms::TreeColumnType type, const std::string &name, 
-        int initial_width, bool editable);
-      static void end_columns(::mforms::TreeNodeView *self);
-      
-      static void clear(::mforms::TreeNodeView *self);
 
-      static mforms::TreeSelectionMode get_selection_mode(::mforms::TreeNodeView *self);
-      static void set_selection_mode(::mforms::TreeNodeView *self, mforms::TreeSelectionMode mode);
-      static std::list<mforms::TreeNodeRef> get_selection(::mforms::TreeNodeView *self);
-      static mforms::TreeNodeRef get_selected_node(::mforms::TreeNodeView *self);
-      static void clear_selection(::mforms::TreeNodeView *self);
-      static void set_selected(::mforms::TreeNodeView *self, mforms::TreeNodeRef node, bool flag);
+      Dictionary<String^, Node^>^ _tag_map;
+    protected:
+      static bool create(mforms::TreeNodeView *self, mforms::TreeOptions options);
+      static int add_column(mforms::TreeNodeView *self, mforms::TreeColumnType type, const std::string &name, 
+        int initial_width, bool editable);
+      static void end_columns(mforms::TreeNodeView *self);
+      
+      static void clear(mforms::TreeNodeView *self);
+
+      static mforms::TreeSelectionMode get_selection_mode(mforms::TreeNodeView *self);
+      static void set_selection_mode(mforms::TreeNodeView *self, mforms::TreeSelectionMode mode);
+      static std::list<mforms::TreeNodeRef> get_selection(mforms::TreeNodeView *self);
+      static mforms::TreeNodeRef get_selected_node(mforms::TreeNodeView *self);
+      static void clear_selection(mforms::TreeNodeView *self);
+      static void set_selected(mforms::TreeNodeView *self, mforms::TreeNodeRef node, bool flag);
 
       static void set_allow_sorting(mforms::TreeNodeView *self, bool flag);
       static void set_row_height(mforms::TreeNodeView *self, int h);
@@ -114,6 +117,7 @@ namespace MySQL {
 
       static mforms::TreeNodeRef node_at_row(mforms::TreeNodeView *self, int);
       static int row_for_node(mforms::TreeNodeView *self, mforms::TreeNodeRef);
+      static mforms::TreeNodeRef node_with_tag(mforms::TreeNodeView *self, const std::string &tag);
 
       // Event handlers.
       static void TreeValueNeeded(System::Object^ sender, NodeControlValueEventArgs^ e);
@@ -127,12 +131,12 @@ namespace MySQL {
       void Collapsed(System::Object^ sender, TreeViewAdvEventArgs^ e);
       void OnBeforeNodeDrawing(System::Object^ sender, TreeViewAdvDrawRowEventArgs^ e);
     public:
-      TreeNodeViewImpl(::mforms::TreeNodeView *self);
+      TreeNodeViewImpl(mforms::TreeNodeView *self, bool use_tag_index);
       virtual ~TreeNodeViewImpl();
 
       void set_row_height(int h);
 
-      int add_column(::mforms::TreeColumnType type, const std::string &name, int initial_width, bool editable);
+      int add_column(mforms::TreeColumnType type, const std::string &name, int initial_width, bool editable);
       void end_columns();
       
       void clear();
@@ -150,32 +154,35 @@ namespace MySQL {
       void freeze_refresh(bool flag);
 
       mforms::TreeNodeRef root_node();
-
       
       mforms::TreeNodeRef node_at_row(int);
       int row_for_node(mforms::TreeNodeRef);
+      mforms::TreeNodeRef node_with_tag(const std::string &tag);
+
+      void process_mapping(Node^ node, const std::string &tag); // Internal function.
 
       static void init(Manager ^mgr)
       {
-        ::mforms::ControlFactory *f= ::mforms::ControlFactory::get_instance();
+        mforms::ControlFactory *f= mforms::ControlFactory::get_instance();
 
-        DEF_CALLBACK2(bool, ::mforms::TreeNodeView*, ::mforms::TreeOptions, mgr, f->_treenodeview_impl, TreeNodeViewImpl, create);
-        DEF_CALLBACK5(int, ::mforms::TreeNodeView*, ::mforms::TreeColumnType, const std::string&, int, bool, mgr, 
+        DEF_CALLBACK2(bool, mforms::TreeNodeView*, mforms::TreeOptions, mgr, f->_treenodeview_impl, TreeNodeViewImpl, create);
+        DEF_CALLBACK5(int, mforms::TreeNodeView*, mforms::TreeColumnType, const std::string&, int, bool, mgr, 
           f->_treenodeview_impl, TreeNodeViewImpl, add_column);
-        DEF_CALLBACK1(void, ::mforms::TreeNodeView*, mgr, f->_treenodeview_impl, TreeNodeViewImpl, end_columns);
-        DEF_CALLBACK1(void, ::mforms::TreeNodeView*, mgr, f->_treenodeview_impl, TreeNodeViewImpl, clear);
-        DEF_CALLBACK1(void, ::mforms::TreeNodeView*, mgr, f->_treenodeview_impl, TreeNodeViewImpl, clear_selection);
-        DEF_CALLBACK1(std::list<mforms::TreeNodeRef>, ::mforms::TreeNodeView*, mgr, f->_treenodeview_impl, TreeNodeViewImpl, get_selection);
-        DEF_CALLBACK1(mforms::TreeNodeRef, ::mforms::TreeNodeView*, mgr, f->_treenodeview_impl, TreeNodeViewImpl, get_selected_node);
-        DEF_CALLBACK3(void, ::mforms::TreeNodeView*, ::mforms::TreeNodeRef, bool, mgr, f->_treenodeview_impl, TreeNodeViewImpl, set_selected);
-        DEF_CALLBACK2(void, ::mforms::TreeNodeView*, bool, mgr, f->_treenodeview_impl, TreeNodeViewImpl, set_allow_sorting);
-        DEF_CALLBACK2(void, ::mforms::TreeNodeView*, int, mgr, f->_treenodeview_impl, TreeNodeViewImpl, set_row_height);
-        DEF_CALLBACK2(void, ::mforms::TreeNodeView*, bool, mgr, f->_treenodeview_impl, TreeNodeViewImpl, freeze_refresh);
-        DEF_CALLBACK1(mforms::TreeNodeRef, ::mforms::TreeNodeView*, mgr, f->_treenodeview_impl, TreeNodeViewImpl, root_node);
-        DEF_CALLBACK2(int, ::mforms::TreeNodeView*, ::mforms::TreeNodeRef, mgr, f->_treenodeview_impl, TreeNodeViewImpl, row_for_node);
-        DEF_CALLBACK2(::mforms::TreeNodeRef, ::mforms::TreeNodeView*, int, mgr, f->_treenodeview_impl, TreeNodeViewImpl, node_at_row);
-        DEF_CALLBACK2(void, ::mforms::TreeNodeView *, mforms::TreeSelectionMode, mgr, f->_treenodeview_impl, TreeNodeViewImpl, set_selection_mode);
+        DEF_CALLBACK1(void, mforms::TreeNodeView*, mgr, f->_treenodeview_impl, TreeNodeViewImpl, end_columns);
+        DEF_CALLBACK1(void, mforms::TreeNodeView*, mgr, f->_treenodeview_impl, TreeNodeViewImpl, clear);
+        DEF_CALLBACK1(void, mforms::TreeNodeView*, mgr, f->_treenodeview_impl, TreeNodeViewImpl, clear_selection);
+        DEF_CALLBACK1(std::list<mforms::TreeNodeRef>, mforms::TreeNodeView*, mgr, f->_treenodeview_impl, TreeNodeViewImpl, get_selection);
+        DEF_CALLBACK1(mforms::TreeNodeRef, mforms::TreeNodeView*, mgr, f->_treenodeview_impl, TreeNodeViewImpl, get_selected_node);
+        DEF_CALLBACK3(void, mforms::TreeNodeView*, mforms::TreeNodeRef, bool, mgr, f->_treenodeview_impl, TreeNodeViewImpl, set_selected);
+        DEF_CALLBACK2(void, mforms::TreeNodeView*, bool, mgr, f->_treenodeview_impl, TreeNodeViewImpl, set_allow_sorting);
+        DEF_CALLBACK2(void, mforms::TreeNodeView*, int, mgr, f->_treenodeview_impl, TreeNodeViewImpl, set_row_height);
+        DEF_CALLBACK2(void, mforms::TreeNodeView*, bool, mgr, f->_treenodeview_impl, TreeNodeViewImpl, freeze_refresh);
+        DEF_CALLBACK1(mforms::TreeNodeRef, mforms::TreeNodeView*, mgr, f->_treenodeview_impl, TreeNodeViewImpl, root_node);
+        DEF_CALLBACK2(int, mforms::TreeNodeView*, mforms::TreeNodeRef, mgr, f->_treenodeview_impl, TreeNodeViewImpl, row_for_node);
+        DEF_CALLBACK2(mforms::TreeNodeRef, mforms::TreeNodeView*, int, mgr, f->_treenodeview_impl, TreeNodeViewImpl, node_at_row);
+        DEF_CALLBACK2(void, mforms::TreeNodeView *, mforms::TreeSelectionMode, mgr, f->_treenodeview_impl, TreeNodeViewImpl, set_selection_mode);
         DEF_CALLBACK1(mforms::TreeSelectionMode, mforms::TreeNodeView *, mgr, f->_treenodeview_impl, TreeNodeViewImpl, get_selection_mode);
+        DEF_CALLBACK2(mforms::TreeNodeRef, mforms::TreeNodeView *, const std::string&, mgr, f->_treenodeview_impl, TreeNodeViewImpl, node_with_tag);
       }
     };
   }
