@@ -228,7 +228,7 @@ void grt_shell_show_python_help(grt::GRT *grt, const char *command)
       }
     }
     if (!found)
-      grt->send_output("Unknown help topic");
+      grt->send_output("Unknown help topic\n");
   }
 }
 
