@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -25,6 +25,7 @@
 
 #include <iostream>
 #include <time.h>
+#include <boost/bind.hpp>
 
 #ifdef _WIN32
 #undef max
@@ -88,9 +89,7 @@ static std::string member_for_object_list(const ObjectRef &object, const BaseLis
   MetaClass *meta= object.get_metaclass();
   std::string name;
   
-  meta->foreach_member(sigc::bind(sigc::ptr_fun(find_member_for_list), 
-                                  (internal::Object*)object.valueptr(), (internal::List*)list.valueptr(), &name));
-  
+  meta->foreach_member(boost::bind(&find_member_for_list,_1,(internal::Object*)object.valueptr(), (internal::List*)list.valueptr(),&name));
   return name;
 }
 
@@ -115,7 +114,7 @@ static std::string member_for_object_dict(const ObjectRef &object, const DictRef
   MetaClass *meta= object.get_metaclass();
   std::string name;
   
-  meta->foreach_member(sigc::bind(sigc::ptr_fun(find_member_for_dict), object, dict, &name));
+  meta->foreach_member(boost::bind(&find_member_for_dict, _1, object, dict, &name));
   
   return name;
 }
@@ -629,8 +628,9 @@ UndoManager::UndoManager(GRT *grt)
 
 UndoManager::~UndoManager()
 {
-  g_static_rec_mutex_free(&_mutex);
+  _changed_signal.disconnect_all_slots(); // prevent emission in reset()
   reset();
+  g_static_rec_mutex_free(&_mutex);
 }
 
 
@@ -793,7 +793,7 @@ void UndoManager::reset()
   _redo_stack.clear();
 
   unlock();
-  _changed_signal.emit();
+  _changed_signal();
 }
 
 
@@ -903,7 +903,7 @@ void UndoManager::cancel_undo_group()
   else
     stack= &_undo_stack;
 
-  UndoGroup *group;
+  UndoGroup *group= 0;
   UndoGroup *parent= 0;
   UndoGroup *subgroup= 0;
   
@@ -959,7 +959,7 @@ void UndoManager::set_action_description(const std::string &descr)
       _undo_stack.back()->set_description(descr);
   }
   unlock();
-  _changed_signal.emit();
+  _changed_signal();
 }
 
 
@@ -1007,7 +1007,7 @@ void UndoManager::undo()
     _undo_stack.pop_back();
     unlock();
 
-    _undo_signal.emit(cmd);
+    _undo_signal(cmd);
 
     delete cmd;
   }
@@ -1036,7 +1036,7 @@ void UndoManager::redo()
     _redo_stack.pop_back();
     unlock();
 
-    _redo_signal.emit(cmd);
+    _redo_signal(cmd);
 
     delete cmd;
   }
@@ -1099,11 +1099,11 @@ void UndoManager::add_undo(UndoAction *cmd)
   }
   unlock();
 
-  _changed_signal.emit();
+  _changed_signal();
 }
 
 
-void UndoManager::add_simple_undo(const sigc::slot<void> &slot)
+void UndoManager::add_simple_undo(const boost::function<void ()> &slot)
 {
   add_undo(new SimpleUndoAction(slot));
 }
