@@ -914,6 +914,22 @@ void grt::merge_contents(ObjectRef target, ObjectRef source)
   while (metac != 0);
 }
 
+
+std::string grt::join_string_list(const StringListRef &list, const std::string &separator)
+{
+  std::string result;
+  for (StringListRef::const_iterator i = list.begin(); i != list.end(); ++i)
+  {
+    if (i != list.begin())
+      result.append(separator);
+    result.append(*i);
+  }
+  return result;
+}
+
+
+
+
 ObjectRef CopyContext::copy(const ObjectRef &object, std::set<std::string> skip_members)
 {
   ObjectRef copy= duplicate_object(object, skip_members, false);
