@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -271,25 +271,6 @@ static int object_compare(PyGRTObjectObject *self, PyGRTObjectObject *other)
 }
 
 
-static bool add_member_to_list(const grt::MetaClass::Member *member, PyObject *list)
-{
-  PyObject *tmp = PyString_FromString(member->name.c_str());
-  PyList_Append(list, tmp);
-  Py_DECREF(tmp);
-  
-  return true;
-}
-
-static bool add_method_to_list(const grt::MetaClass::Method *method, PyObject *list)
-{
-  PyObject *tmp = PyString_FromString(method->name.c_str());
-  PyList_Append(list, tmp);
-  Py_DECREF(tmp);
-  
-  return true;
-}
-
-
 static PyObject *object_getattro(PyGRTObjectObject *self, PyObject *attr_name)
 {  
   if (PyString_Check(attr_name)) 
@@ -298,33 +279,13 @@ static PyObject *object_getattro(PyGRTObjectObject *self, PyObject *attr_name)
     
     PyObject *object;
     if ((object= PyObject_GenericGetAttr((PyObject*)self, attr_name)))
-    {
-      if (strcmp(attrname, "__members__") == 0)
-      {
-        PyObject *tmp = PyString_FromString("__grtclassname__");
-        PyList_Append(object, tmp);
-        Py_DECREF(tmp);
-        self->object->get_metaclass()->foreach_member(boost::bind(&add_member_to_list, _1, object));
-      }
-      
       return object;
-    }
     PyErr_Clear();
     
-    if (strcmp(attrname, "__members__") == 0)
-    {
-      PyObject *members= Py_BuildValue("[ss]", "__grtclassname__", "__doc__");
-      self->object->get_metaclass()->foreach_member(boost::bind(&add_member_to_list, _1, members));
-      return members;
-    }
-    else if (strcmp(attrname, "__methods__") == 0)
-    {
-      PyObject *methods= Py_BuildValue("[s]", "__callmethod__");
-      self->object->get_metaclass()->foreach_method(boost::bind(&add_method_to_list, _1, methods));
-      return methods;
-    }
-    else if (strcmp(attrname, "__grtclassname__") == 0)
+    if (strcmp(attrname, "__grtclassname__") == 0)
       return Py_BuildValue("s", self->object->class_name().c_str());    
+    else if (strcmp(attrname, "__id__") == 0)
+      return Py_BuildValue("s", self->object->id().c_str());    
     else
     {
       if (self->object->has_member(attrname))
@@ -426,6 +387,14 @@ object_callmethod(PyGRTObjectObject *self, PyObject *args)
 }
 
 
+static PyObject *object_reset_references(PyGRTObjectObject *self, void *nothing)
+{
+  (*self->object)->reset_references();
+
+  Py_RETURN_NONE;
+}
+
+
 static PyObject *object_get_doc(PyGRTObjectObject *self, void *closure)
 {
   return Py_BuildValue("s", self->object->get_metaclass()->get_attribute("description").c_str());
@@ -433,6 +402,39 @@ static PyObject *object_get_doc(PyGRTObjectObject *self, void *closure)
 
 
 
+static bool add_member_to_list(const grt::MetaClass::Member *member, PyObject *list)
+{
+  PyObject *tmp = PyString_FromString(member->name.c_str());
+  PyList_Append(list, tmp);
+  Py_DECREF(tmp);
+  
+  return true;
+}
+
+static bool add_method_to_list(const grt::MetaClass::Method *method, PyObject *list)
+{
+  PyObject *tmp = PyString_FromString(method->name.c_str());
+  PyList_Append(list, tmp);
+  Py_DECREF(tmp);
+  
+  return true;
+}
+
+static PyObject *object_get_members(PyGRTObjectObject *self, void *closure)
+{
+  PyObject *members= PyList_New(0);
+  self->object->get_metaclass()->foreach_member(boost::bind(&add_member_to_list, _1, members));
+  return members;
+}
+
+static PyObject *object_get_methods(PyGRTObjectObject *self, void *closure)
+{
+  PyObject *methods= PyList_New(0);
+  self->object->get_metaclass()->foreach_method(boost::bind(&add_method_to_list, _1, methods));
+  return methods;
+}
+
+
 PyDoc_STRVAR(PyGRTObjectDoc,
 "Object(grtclass) -> GRT Object\n\
 \n\
@@ -445,6 +447,7 @@ PyDoc_STRVAR(call_doc,
 
 static PyMethodDef PyGRTObjectMethods[] = {
 {"__callmethod__",  (PyCFunction)object_callmethod,  METH_VARARGS, call_doc},
+{"reset_references",  (PyCFunction)object_reset_references,  METH_NOARGS, NULL},
 {NULL, NULL, 0, NULL}
 };
 
@@ -452,6 +455,8 @@ static PyMethodDef PyGRTObjectMethods[] = {
 
 static PyGetSetDef PyGRTObjectGetSetters[] = {
 {(char*)"__doc__", (getter)object_get_doc, NULL, (char*)"Documentation of the GRT class.", NULL},
+{(char*)"__grtmembers__", (getter)object_get_members, NULL, (char*)"GRT object members", NULL},
+{(char*)"__grtmethods__", (getter)object_get_methods, NULL, (char*)"GRT object methods", NULL},
 {NULL, NULL, NULL, NULL, NULL},
 };
 
