@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,13 +21,12 @@
 
 #ifdef ENABLE_PYTHON_MODULES
 
+#include "base/string_utilities.h"
 #include "python_context.h"
 #include "grtpp_util.h"
-#include "base/string_utilities.h"
 
 #include "python_module.h"
 
-
 using namespace grt;
 using namespace base;
 
@@ -102,11 +101,28 @@ static PyObject* function_call(PyGRTFunctionObject *self, PyObject *args, PyObje
 
     return pyresult;
   }
+  catch (grt::user_cancelled &exc)
+  {
+    PythonContext::set_user_interrupted(exc);
+  }
+  catch (grt::db_access_denied &exc)
+  {
+    PythonContext::set_db_access_denied(exc);
+  }
+  catch (grt::db_login_error &exc)
+  {
+    PythonContext::set_db_login_error(exc);
+  }
+  catch (grt::module_error &exc)
+  {
+    if (exc.inner.empty())
+      PythonContext::set_python_error(exc, strfmt("%s.%s()", self->module->name().c_str(), self->function->name.c_str()));
+    else
+      PythonContext::set_python_error(exc, exc.inner);
+  }
   catch (std::exception &exc)
   {
     PythonContext::set_python_error(exc, strfmt("%s.%s()", self->module->name().c_str(), self->function->name.c_str()));
-
-    return NULL;
   }
 
   return NULL;  
@@ -231,7 +247,7 @@ static void module_dealloc(PyGRTModuleObject *self)
 
 
 static PyObject *module_getattro(PyGRTModuleObject *self, PyObject *attr_name)
-{  
+{ 
   if (PyString_Check(attr_name)) 
   {
     const char *attrname= PyString_AsString(attr_name);
@@ -243,7 +259,7 @@ static PyObject *module_getattro(PyGRTModuleObject *self, PyObject *attr_name)
     
     if (strcmp(attrname, "__members__") == 0)
     {
-      return Py_BuildValue("[s]", "__doc__");
+      return Py_BuildValue("[ss]", "__doc__", "__bundlepath__", "__author__", "__name__", "__iconpath__", "__description__", "__version__");
     }
     else if (strcmp(attrname, "__methods__") == 0)
     {
@@ -255,6 +271,16 @@ static PyObject *module_getattro(PyGRTModuleObject *self, PyObject *attr_name)
       }
       return methods;
     }
+    else if (strcmp(attrname, "__author__") == 0)
+      return Py_BuildValue("s", self->module->author().c_str());
+    else if (strcmp(attrname, "__name__") == 0)
+      return Py_BuildValue("s", self->module->name().c_str());
+    else if (strcmp(attrname, "__iconpath__") == 0)
+      return Py_BuildValue("s", self->module->default_icon_path().c_str());
+    else if (strcmp(attrname, "__description__") == 0)
+      return Py_BuildValue("s", self->module->description().c_str());
+    else if (strcmp(attrname, "__version__") == 0)
+      return Py_BuildValue("s", self->module->version().c_str());
     else if (strcmp(attrname, "__bundlepath__") == 0)
     {
       if (self->module->is_bundle())
