@@ -23,8 +23,10 @@
 #include "unserializer.h"
 #include "grtpp_util.h"
 
-#include <glib.h>
 #include "base/string_utilities.h"
+#include "base/log.h"
+
+DEFAULT_LOG_DOMAIN(DOMAIN_GRT)
 
 using namespace grt;
 using namespace grt::internal;
@@ -219,7 +221,7 @@ ValueRef internal::Unserializer::traverse_xml_recreating_tree(xmlNodePtr node)
       std::string node_type= get_prop(node, "type");
       if (node_type.empty() || node_type != "object")
       {
-        g_warning("%s: link of type '%s' could not be resolved during unserialized", _source_name.c_str(), node_type.c_str());
+        log_warning("%s: link of type '%s' could not be resolved during unserialized", _source_name.c_str(), node_type.c_str());
         return ValueRef();
       }
       
@@ -237,7 +239,7 @@ ValueRef internal::Unserializer::traverse_xml_recreating_tree(xmlNodePtr node)
       }
 
       if (!value.is_valid() && get_prop(node, "key") != "owner")
-        g_warning("%s:%i: link '%s' <%s %s> key=%s could not be resolved", 
+        log_warning("%s:%i: link '%s' <%s %s> key=%s could not be resolved", 
                   _source_name.c_str(), node->line, link_id.c_str(),                 
                   get_prop(node, "type").c_str(), 
                   get_prop(node, "struct-name").c_str(),
@@ -380,7 +382,7 @@ ValueRef internal::Unserializer::traverse_xml_recreating_tree(xmlNodePtr node)
         {
           if (!list->null_allowed())
           {
-            g_warning("%s: Attempt o add null value to %s list", _source_name.c_str(),
+            log_warning("%s: Attempt o add null value to %s list", _source_name.c_str(),
                       cclass_name.c_str());
           }
           list.ginsert(ValueRef());
@@ -397,14 +399,14 @@ ValueRef internal::Unserializer::traverse_xml_recreating_tree(xmlNodePtr node)
             }
             catch (const std::exception &exc)
             {
-              g_warning("%s: Error inserting %s to list: %s", _source_name.c_str(), sub_value.repr().c_str(), exc.what());
+              log_warning("%s: Error inserting %s to list: %s", _source_name.c_str(), sub_value.repr().c_str(), exc.what());
               throw;
             }
           }
           else
           {
             //error!
-            g_warning("%s: skipping element '%s' in unserialized document, line %i", _source_name.c_str(), child->name, child->line);
+            log_warning("%s: skipping element '%s' in unserialized document, line %i", _source_name.c_str(), child->name, child->line);
             value.clear();
             break;
           }
@@ -444,10 +446,10 @@ ObjectRef internal::Unserializer::unserialize_object_step1(xmlNodePtr node)
   gstruct= _grt->get_metaclass(prop);
   if (!gstruct)
   {
-    g_warning("%s:%i: error unserializing object: struct '%s' unknown",
+    log_warning("%s:%i: error unserializing object: struct '%s' unknown",
               _source_name.c_str(), node->line,
               prop.c_str());
-    throw std::runtime_error("error unserializing object (invalid struct)");
+    throw std::runtime_error(base::strfmt("error unserializing object (struct '%s' unknown)", prop.c_str()));
   }
 
   id= get_prop(node, "id");
@@ -460,7 +462,7 @@ ObjectRef internal::Unserializer::unserialize_object_step1(xmlNodePtr node)
     unsigned int checksum= (unsigned int)strtol(prop.c_str(), NULL, 0);
     if (_check_serialized_crc && checksum != gstruct->crc32())
     {
-      g_warning("current checksum of struct of serialized object %s (%s) differs from the one when it was saved",
+      log_warning("current checksum of struct of serialized object %s (%s) differs from the one when it was saved",
                 id.c_str(), gstruct->name().c_str());
     }
   }
@@ -481,7 +483,7 @@ ObjectRef internal::Unserializer::unserialize_object_step2(xmlNodePtr node)
   
   ObjectRef value= ObjectRef::cast_from(find_cached(id));
   if (!value.is_valid())
-    g_warning("%s: Unknown object-id '%s' in unserialized file", _source_name.c_str(), id.c_str());
+    log_warning("%s: Unknown object-id '%s' in unserialized file", _source_name.c_str(), id.c_str());
   unserialize_object_contents(value, node);
   
   return value;
@@ -508,7 +510,7 @@ void internal::Unserializer::unserialize_object_contents(const ObjectRef &object
       {
         if (!object->has_member(key))
         {
-          g_warning("in %s: %s", object.id().c_str(),
+          log_warning("in %s: %s", object.id().c_str(),
                     std::string("unserialized XML contains invalid member "+object.class_name()+"::"+key).c_str());
           //throw std::runtime_error("unserialized XML contains invalid member "+object.class_name()+"::"+key);
         }
@@ -531,7 +533,7 @@ void internal::Unserializer::unserialize_object_contents(const ObjectRef &object
           }
           catch (grt::null_value &exc)
           {
-            g_warning("%s in %s:%s %s", exc.what(), object->class_name().c_str(), key.c_str(), object->id().c_str());
+            log_warning("%s in %s:%s %s", exc.what(), object->class_name().c_str(), key.c_str(), object->id().c_str());
             throw;
           }
           if (sub_value.is_valid())
@@ -542,7 +544,7 @@ void internal::Unserializer::unserialize_object_contents(const ObjectRef &object
             }
             catch (const std::exception &exc) 
             {
-              g_warning("exception setting %s<%s>:%s to %s %s", object.id().c_str(), object.class_name().c_str(), key.c_str(), 
+              log_warning("exception setting %s<%s>:%s to %s %s", object.id().c_str(), object.class_name().c_str(), key.c_str(), 
                         sub_value.repr().c_str(), exc.what());
               throw;
             }
