@@ -1,4 +1,23 @@
-#include "stdafx.h"
+/* 
+ * Copyright (c) 2011, Oracle and/or its affiliates. All rights reserved.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; version 2 of the
+ * License.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301  USA
+ */
+
+#include "tut_stdafx.h"
 
 #include "grt_test_utility.h"
 #include "testgrt.h"
@@ -61,7 +80,7 @@ void apply_change(BaseListRef source, const grt::MultiChange* change)
   const grt::ChangeSet *change_list= change->subchanges();
   for(grt::ChangeSet::const_iterator e2= change_list->end(), jt= change_list->begin(); jt != e2; jt++)
   {
-    const grt::DiffChange *subchange= *jt;
+    const grt::DiffChange *subchange= jt->get();
 //    print_array(source);
     switch(subchange->get_change_type())
     {
@@ -126,8 +145,8 @@ void apply_change_to_object(ValueRef source, DiffChange* change)
   if (BaseListRef::can_wrap(source))
     resolve_change_type(BaseListRef::cast_from(source),change);
 }
-std::vector<std::vector<int>> test_src;
-std::vector<std::vector<int>> test_dst;
+std::vector<std::vector<int> > test_src;
+std::vector<std::vector<int> > test_dst;
 
 template<typename TTestData>
 void test_diff(TTestData src, TTestData dest, GRT& test_grt)
@@ -137,8 +156,12 @@ void test_diff(TTestData src, TTestData dest, GRT& test_grt)
   IntegerListRef target(&test_grt);
   list_from_container(src->begin(), src->end(), source);
   list_from_container(dest->begin(), dest->end(), target);
-  DiffChange* change= diff_make(source, target, NULL,  grt::NormalizedComparer(&test_grt));
-  apply_change_to_object(source,change);
+
+  default_omf omf;
+  grt::NormalizedComparer normalizer(&test_grt);
+  normalizer.init_omf(&omf);
+  boost::shared_ptr<DiffChange> change= diff_make(source, target, &omf);
+  apply_change_to_object(source,change.get());
   assure_grt_values_equal(source, target);
 }
 
@@ -215,8 +238,8 @@ TEST_FUNCTION(1)
 #endif
 
   size_t cntr = 0;
-  std::vector<std::vector<int>>::const_iterator It2 = test_dst.begin();
-  for(std::vector<std::vector<int>>::const_iterator It1 = test_src.begin();
+  std::vector<std::vector<int> >::const_iterator It2 = test_dst.begin();
+  for(std::vector<std::vector<int> >::const_iterator It1 = test_src.begin();
     It1 != test_src.end(),It2 != test_dst.end(); ++It1,++It2)
   {
     test_diff(It1,It2,test_grt);
@@ -236,8 +259,11 @@ TEST_FUNCTION(2)
   list_from_container(s, s + UPPER_BOUND(s), source);
   list_from_container(t, t + UPPER_BOUND(t), target);
 
-  DiffChange* change= diff_make(source, target, NULL,  grt::NormalizedComparer(&test_grt));
-  apply_change_to_object(source,change);
+  default_omf omf;
+  grt::NormalizedComparer normalizer(&test_grt);
+  normalizer.init_omf(&omf);
+  boost::shared_ptr<DiffChange> change= diff_make(source, target, &omf);
+  apply_change_to_object(source,change.get());
 
   assure_grt_values_equal(source, target);
 }
