@@ -26,7 +26,12 @@ extern "C" void on_parse_error(struct ANTLR3_BASE_RECOGNIZER_struct * recognizer
   IBOutlet NSTextView *stepsList;
   
   IBOutlet NSView *topView;
-  
+
+  // For query to token conversion.
+  IBOutlet NSTextView *queryList;
+  IBOutlet NSTextView *tokenList;
+  IBOutlet NSTextField *conversionErrorText;
+
 @private
   NSWindow *window;
   
@@ -41,4 +46,6 @@ extern "C" void on_parse_error(struct ANTLR3_BASE_RECOGNIZER_struct * recognizer
 - (IBAction)selectFile: (id)sender;
 - (IBAction)startTests: (id)sender;
 
+- (IBAction)startConversion: (id)sender;
+
 @end
