@@ -211,7 +211,9 @@ class MSSQLMigration(GenericMigration):
             # string data types:
             target_datatype = ''
             if source_datatype in ['VARCHAR', 'NVARCHAR']:
-                if 0 < source_column.length < 256:
+                if source_column.length == -1:  # VARCHAR(MAX) or NVARCHAR(MAX)
+                    target_datatype = 'LONGTEXT'  #TODO: Give the user the choice for this target datatype
+                elif 0 < source_column.length < 256:
                     target_datatype = 'VARCHAR'
                 else:  # MySQL versions > 5.0 can hold up to 65535 chars in a VARCHAR column
                     target_datatype = 'TEXT' if targetCatalog.version.majorNumber < 5 else 'VARCHAR'
@@ -260,7 +262,9 @@ class MSSQLMigration(GenericMigration):
                 target_column.scale = source_column.simpleType.numericScale
             # binary datatypes:
             elif source_datatype in ['IMAGE', 'BINARY', 'VARBINARY']:
-                if 0 <= source_column.length < 256:
+                if source_column.length == -1:  # VARBINARY(MAX)
+                   target_datatype = 'LONGBLOB'  #TODO: Give the user the choice for this target datatype
+                elif 0 <= source_column.length < 256:
                     if source_datatype == 'IMAGE':
                         target_datatype = 'TINYBLOB'
                     else:
@@ -272,13 +276,16 @@ class MSSQLMigration(GenericMigration):
             # datetime datatypes:
             elif source_datatype in ['DATETIME', 'SMALLDATETIME', 'DATETIME2', 'DATETIMEOFFSET']:
                 target_datatype = 'DATETIME'
+                target_column.precision = -1
             # timestamp datatypes
             elif source_datatype in ['TIMESTAMP', 'ROWVERSION']:
                 target_datatype = 'TIMESTAMP'
             elif source_datatype == 'DATE':
                 target_datatype = 'DATE'
+                target_column.precision = -1
             elif source_datatype == 'TIME':
                 target_datatype = 'TIME'
+                target_column.precision = -1
             elif source_datatype == 'BIT':
                 target_datatype = 'TINYINT'
                 target_column.length = 1
