@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -20,7 +20,7 @@
 
 #include "stdafx.h"
 
-#include <glib/gunicode.h>
+#include <glib.h>
 #include "grt/common.h"
 #include "grt/grt_manager.h"
 #include "grtdb/charset_utils.h"
@@ -305,7 +305,7 @@ void Mysql_sql_parser_fe::SqlMode::parse(const std::string &text_value)
   std::string mode;
   while (std::getline(iss, mode, ','))
   {
-    if (mode == "ANSI" || mode == "DB2" || mode == "MAXDB" || mode == "MSSQL" || mode == "ORACLE" || mode == "POSTGRESQL")
+    if (mode == "ANSI" || mode == "DB2" || mode == "MSSQL" || mode == "ORACLE" || mode == "POSTGRESQL")
     {
       MODE_ANSI_QUOTES= true;
       MODE_PIPES_AS_CONCAT= true;
@@ -372,19 +372,19 @@ void Mysql_sql_parser_fe::parse_sql_mode(const std::string &sql_mode_string)
 }
 
 
-int Mysql_sql_parser_fe::parse_sql_script(const std::string &sql, fe_process_sql_statement_callback cb, void *user_data)
+int Mysql_sql_parser_fe::parse_sql_script(const char* sql, fe_process_sql_statement_callback cb, void *user_data)
 {
-  bec::GStaticMutexLock parser_fe_critical_section(_parser_fe_critical_section);
+  base::GStaticMutexLock parser_fe_critical_section(_parser_fe_critical_section);
   reset();
   Context context= {this, cb, user_data, 0, ignore_dml, is_ast_generation_enabled, max_insert_statement_size, processing_create_statements, processing_alter_statements, processing_drop_statements, sql_mode};
-  myx_process_sql_statements(sql.c_str(), Lex_helper::charset(), &process_sql_statement_cb, &context, MYX_SPM_NORMAL_MODE);
+  myx_process_sql_statements(sql, Lex_helper::charset(), &process_sql_statement_cb, &context, MYX_SPM_NORMAL_MODE);
   return context.err_count;
 }
 
 
 int Mysql_sql_parser_fe::parse_sql_script_file(const std::string &filename, fe_process_sql_statement_callback cb, void *user_data)
 {
-  bec::GStaticMutexLock parser_fe_critical_section(_parser_fe_critical_section);
+  base::GStaticMutexLock parser_fe_critical_section(_parser_fe_critical_section);
   reset();
   Context context= {this, cb, user_data, 0, ignore_dml, is_ast_generation_enabled, max_insert_statement_size, processing_create_statements, processing_alter_statements, processing_drop_statements, sql_mode};
   myx_process_sql_statements_from_file(filename.c_str(), Lex_helper::charset(), &process_sql_statement_cb, &context, MYX_SPM_NORMAL_MODE/*MYX_SPM_DELIMS_REQUIRED*/);
@@ -413,7 +413,7 @@ int Mysql_sql_parser_fe::process_sql_statement_cb(const MyxStatementParser *spli
   // possible values for result:
   // -1 - statement was ignored
   // 0 - statement was successfully processed
-  // 1 - error occured during statement processing
+  // 1 - error occurred during statement processing
   int result= 0;
 
   if (::parser_is_stopped)
@@ -479,6 +479,7 @@ int Mysql_sql_parser_fe::process_sql_statement_cb(const MyxStatementParser *spli
     }
     else if ("syntax error" == err_msg)
     {
+      // Simple style error messages.
       if (const SqlAstNode *item= _lex_helper.lex()->last_item)
       {
         static const size_t MAX_SQL_CONTEXT_SIZE= 80;
@@ -495,6 +496,12 @@ int Mysql_sql_parser_fe::process_sql_statement_cb(const MyxStatementParser *spli
         determine_token_position(item, splitter, statement, err_tok_lineno, err_tok_line_pos, err_tok_len);
       }
     }
+    else
+    {
+      // General error message style.
+      if (const SqlAstNode *item= _lex_helper.lex()->last_item)
+        determine_token_position(item, splitter, statement, err_tok_lineno, err_tok_line_pos, err_tok_len);
+    }
   }
 
   int stmt_begin_lineno= -1;
@@ -634,7 +641,7 @@ void Mysql_sql_parser_fe::determine_token_position(const SqlAstNode *item, const
 
 std::string Mysql_sql_parser_fe::get_first_sql_token(const std::string &sql, const std::string &versioning_comment_subst_token)
 {
-  bec::GStaticMutexLock parser_fe_critical_section(_parser_fe_critical_section);
+  base::GStaticMutexLock parser_fe_critical_section(_parser_fe_critical_section);
   reset();
   static Mysql_sql_parser_fe::SqlMode sql_mode;
 
