@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2007, 2010, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2012, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -44,8 +44,8 @@ Mysql_sql_schema_rename::Null_state_keeper::~Null_state_keeper()
 Mysql_sql_schema_rename::Mysql_sql_schema_rename(grt::GRT *grt)
 :
 Sql_parser_base(grt),
-Mysql_sql_parser_base(grt),
-Sql_schema_rename(grt)
+Sql_schema_rename(grt),
+Mysql_sql_parser_base(grt)
 {
   NULL_STATE_KEEPER // reset all members to null-values
 }
@@ -66,7 +66,7 @@ int Mysql_sql_schema_rename::rename_schema_references(
 
   _messages_enabled= false;
 
-  _process_sql_statement= sigc::mem_fun(this, &Mysql_sql_schema_rename::process_sql_statement);
+  _process_sql_statement= boost::bind(&Mysql_sql_schema_rename::process_sql_statement, this, _1);
   Mysql_sql_parser_fe sql_parser_fe(_grtm->get_grt());
   sql_parser_fe.ignore_dml= false;
 
@@ -97,7 +97,7 @@ int Mysql_sql_schema_rename::rename_schema_references(
     add_log_message(msg, 0);
   }
 
-  _process_sql_statement= sigc::mem_fun(this, &Mysql_sql_schema_rename::process_sql_statement);
+  _process_sql_statement= boost::bind(&Mysql_sql_schema_rename::process_sql_statement, this, _1);
   Mysql_sql_parser_fe sql_parser_fe(_grtm->get_grt());
   sql_parser_fe.ignore_dml= false;
 
@@ -134,7 +134,7 @@ int Mysql_sql_schema_rename::rename_schema_references(
           tables.get(n)->triggers(),
           &db_mysql_Trigger::sqlDefinition,
           &db_mysql_Trigger::sqlDefinition,
-          0,
+          1,
           sql_parser_fe);
       }
     }
@@ -294,13 +294,11 @@ bool Mysql_sql_schema_rename::rename_schema_references(std::string &sql_text, My
 
   (void) parse_sql_script(sql_parser_fe, sql_text.c_str());
 
-  if (rename_schema_references(sql_text))
+  rename_schema_references(sql_text);
+  if (delim_wrapping)
   {
-    if (delim_wrapping)
-    {
       sql_text.erase(sql_text.size() - end_delim.size(), end_delim.size());
       sql_text.erase(0, begin_delim.size());
-    }
   }
 
   return true;
