@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2012, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2013, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -286,6 +286,8 @@ class ActionGenerateSQL : public DiffSQLGeneratorBEActionInterface
   int _maxTableCommentLength;
   int _maxIndexCommentLength;
   int _maxColumnCommentLength;
+  std::string _algorithm_type;
+  std::string _lock_type;
 
   std::string sql;
   std::string comma;
@@ -453,6 +455,9 @@ ActionGenerateSQL::ActionGenerateSQL(grt::ValueRef target, grt::ListRef<GrtNamed
   _maxTableCommentLength = options.get_int("maxTableCommentLength");
   _maxIndexCommentLength = options.get_int("maxIndexCommentLength");
   _maxColumnCommentLength = options.get_int("maxColumnCommentLength");
+  _algorithm_type = options.get_string("AlterAlgorithm");
+  _lock_type = options.get_string("AlterLock");
+
   _use_oids_as_dict_key = options.get_int("UseOIDAsResultDictKey", use_oids_as_key) != 0;
   
   SqlFacade::Ref sql_facade = SqlFacade::instance_for_rdbms_name(grt, "Mysql");
@@ -685,7 +690,8 @@ std::string ActionGenerateSQL::generate_create(db_mysql_IndexRef index, std::str
     if(!pk)
       index_sql.append((ind_column->descend() == 0 ? " ASC" : " DESC"));
   }
-  
+  index_sql.append(") ");
+
   if (index->keyBlockSize())
     index_sql.append(" KEY_BLOCK_SIZE=").append(itoa(index->keyBlockSize(), itoa_buf, 10));
 
@@ -694,10 +700,7 @@ std::string ActionGenerateSQL::generate_create(db_mysql_IndexRef index, std::str
 
   std::string comment = generate_comment(index->comment(), _maxIndexCommentLength);
   if (!comment.empty())
-    sql.append("COMMENT '").append(comment).append("' ");
-
-
-  index_sql.append(") ");
+    index_sql.append(" COMMENT '").append(comment).append("' ");
 
   return index_sql;
 }
@@ -1125,6 +1128,16 @@ void ActionGenerateSQL::alter_table_partition_definitions(db_mysql_TableRef tabl
 
 void ActionGenerateSQL::alter_table_props_end(db_mysql_TableRef table)
 {
+  if(sql.length() > empty_length)
+  {
+      if (!_algorithm_type.empty())
+          sql.append(", ALGORITHM = ").append(_algorithm_type);
+
+      if (!_lock_type.empty())
+          sql.append(", LOCK = ").append(_lock_type);      
+  }
+
+
   if(!partitions_to_drop.empty())
   {
     sql.append(generate_drop_partitions(partitions_to_drop));
