@@ -2,7 +2,7 @@
 #include "mysql_table_editor_fe.h"
 #include "grtdb/db_object_helpers.h"
 #include "mysql_table_editor_trigger_page.h"
-
+#include "mforms/../gtk/lf_view.h"
 
 //------------------------------------------------------------------------------
 DbMySQLTableEditorTriggerPage::DbMySQLTableEditorTriggerPage(DbMySQLTableEditor *owner
@@ -29,16 +29,17 @@ void DbMySQLTableEditorTriggerPage::switch_be(MySQLTableEditorBE* be)
   Gtk::VBox* trigger_code_win;
   _xml->get_widget("trigger_code_holder", trigger_code_win);
 
+//  trigger_code_win->remove_all();
+
   _be = be;
-  _owner->embed_code_editor(_be ? _be->get_sql_editor()->get_editor_control() : NULL, trigger_code_win);
-  if (_be)
-    _be->load_trigger_sql();
+  trigger_code_win->pack_start(*mforms::widget_for_view(be->get_trigger_panel()), true, true);
+  trigger_code_win->show_all();
 }
 
 //------------------------------------------------------------------------------
 void DbMySQLTableEditorTriggerPage::refresh()
 {
-  if (_be)
-    _be->load_trigger_sql();
+ // if (_be)
+ //   _be->load_trigger_sql();
 }
 
