@@ -21,6 +21,7 @@
 
 #include "MySQLTableEditorBE.h"
 #include "grtdb/db_object_helpers.h"
+#include "mforms/view.h"
 
 namespace MySQL {
 namespace Grt {
@@ -59,9 +60,11 @@ MySQLTablePartitionTreeBE^ MySQLTableEditorBE::get_partitions()
 
 //--------------------------------------------------------------------------------------------------
 
-void MySQLTableEditorBE::load_trigger_sql()
+Control ^MySQLTableEditorBE::get_trigger_panel()
 {
-  get_unmanaged_object()->load_trigger_sql();
+  mforms::View* panel = get_unmanaged_object()->get_trigger_panel();
+  MySQL::Forms::ViewImpl^ managed_view= (MySQL::Forms::ViewImpl^) MySQL::Forms::ViewImpl::FromUnmanaged(panel);
+  return managed_view->get_control();
 }
 
 //--------------------------------------------------------------------------------------------------
