@@ -125,19 +125,39 @@ protected:
                                                const std::string& schema_name);
   void apply_sql_to_model(const std::string& sql);
   all_objects_mwb get_model_objects();
-  TEST_DATA_CONSTRUCTOR(db_mysql_plugin_test)
-  {
+
+TEST_DATA_CONSTRUCTOR(db_mysql_plugin_test)
+{
   // init datatypes
   populate_grt(tester.grt, NULL, tester);
 
   omf.dontdiff_mask = 3;
 
   // init database connection
-  connection= tester.create_connection_for_import();
+  connection = tester.create_connection_for_import();
+  
+  /*
+  std::auto_ptr<sql::Statement> stmt(connection->createStatement());
+
+  sql::ResultSet *res = stmt->executeQuery("SELECT VERSION() as VERSION");
+  if (res && res->next())
+  {
+    std::string version = res->getString("VERSION");
+    tester.get_rdbms()->version(CatalogHelper::parse_version(tester.grt, version));
+  }
+  delete res;
+  */
+
+  // Modeling uses a default server version, which is not related to any server it might have
+  // reverse engineered content from, nor where it was sync'ed to. So we have to mimic this here.
+  std::string target_version = tester.wb->get_grt_manager()->get_app_option_string("DefaultTargetMySQLVersion");
+  if (target_version.empty())
+    target_version = "5.5";
+  tester.get_rdbms()->version(CatalogHelper::parse_version(tester.grt, target_version));
 
   sql_parser= SqlFacade::instance_for_rdbms_name(tester.grt, "Mysql");
   ensure("failed to get sqlparser module", (NULL != sql_parser));
-  }
+}
 
 END_TEST_DATA_CLASS
 
@@ -216,7 +236,12 @@ boost::shared_ptr<DiffChange> tut::Test_object_base<db_mysql_plugin_test>::compa
   grt::NormalizedComparer comparer(tester.grt,grt::DictRef(tester.grt));
   comparer.init_omf(&omf);
 
-  return diff_make(cat, org_cat, &omf);
+  boost::shared_ptr<DiffChange> result = diff_make(cat, org_cat, &omf);
+
+  tester.wb->close_document();
+  tester.wb->close_document_finish();
+
+  return result;
 }
 
 void tut::Test_object_base<db_mysql_plugin_test>::apply_sql_to_model(const std::string& sql)
@@ -252,8 +277,7 @@ void tut::Test_object_base<db_mysql_plugin_test>::apply_sql_to_model(const std::
 
 }
 
-
-TEST_FUNCTION(2)
+TEST_FUNCTION(5)
 {
   // Bug #32327
   static const char *sql1= 
@@ -262,10 +286,10 @@ TEST_FUNCTION(2)
     "CREATE  TABLE IF NOT EXISTS `db_mysql_plugin_test`.`table1`"
     " (`idtable1` INT(11) NOT NULL , PRIMARY KEY (`idtable1`) ) ENGINE=InnoDB DEFAULT CHARSET=latin1 DEFAULT COLLATE = latin1_swedish_ci;";
 
-  db_mysql_CatalogRef mod_cat= create_catalog_from_script(sql1);
-  db_mysql_CatalogRef org_cat= create_catalog_from_script(sql1);
+  db_mysql_CatalogRef mod_cat = create_catalog_from_script(sql1);
+  db_mysql_CatalogRef org_cat= grt::copy_object(mod_cat);
 
-  db_mysql_IndexRef pk= mod_cat->schemata().get(0)->tables().get(0)->indices().get(0);
+  db_mysql_IndexRef pk = mod_cat->schemata().get(0)->tables().get(0)->indices().get(0);
   ensure("bug_32327 - invalid test input", pk->isPrimary() != 0);
 
   // rename PK
@@ -288,7 +312,7 @@ TEST_FUNCTION(2)
   ensure("Unexpected changes", empty_change == NULL);
 }
 
-TEST_FUNCTION(3)
+TEST_FUNCTION(10)
 {
   // Bug #32330
   static const char *sql1 = 
@@ -298,7 +322,7 @@ TEST_FUNCTION(3)
       " ENGINE=InnoDB DEFAULT CHARSET=latin1 DEFAULT COLLATE = latin1_swedish_ci;";
 
   db_mysql_CatalogRef mod_cat= create_catalog_from_script(sql1);
-  db_mysql_CatalogRef org_cat= create_catalog_from_script(sql1);
+  db_mysql_CatalogRef org_cat= grt::copy_object(mod_cat);
 
   ensure("bug_32330 - invalid test input", mod_cat->schemata().get(0)->tables().count() == 1);
   
@@ -321,7 +345,7 @@ TEST_FUNCTION(3)
   ensure("Unexpected changes", empty_change == NULL);
 }
 
-TEST_FUNCTION(4)
+TEST_FUNCTION(15)
 {
   // Bug #32334
   static const char *sql1 = 
@@ -335,7 +359,7 @@ TEST_FUNCTION(4)
       "ENGINE = MyISAM CHARSET = latin1 DEFAULT COLLATE = latin1_swedish_ci;";
 
   db_mysql_CatalogRef mod_cat= create_catalog_from_script(sql1);
-  db_mysql_CatalogRef org_cat= create_catalog_from_script(sql1);
+  db_mysql_CatalogRef org_cat= grt::copy_object(mod_cat);
 
   ensure("bug_32334 - invalid test input", mod_cat->schemata().get(0)->tables().count() == 3);
   
@@ -369,7 +393,7 @@ TEST_FUNCTION(4)
   //ensure("bug_32334 - test failed", empty_change == NULL);
 }
 
-TEST_FUNCTION(5)
+TEST_FUNCTION(20)
 {
   // Bug #32336
   static const char *sql1 = 
@@ -379,7 +403,7 @@ TEST_FUNCTION(5)
       " ENGINE=InnoDB DEFAULT CHARSET=latin1 DEFAULT COLLATE = latin1_swedish_ci;";
 
   db_mysql_CatalogRef mod_cat= create_catalog_from_script(sql1);
-  db_mysql_CatalogRef org_cat= create_catalog_from_script(sql1);
+  db_mysql_CatalogRef org_cat= grt::copy_object(mod_cat);
 
   ensure("bug_32336 - invalid test input", mod_cat->schemata().get(0)->tables().count() == 1);
   
@@ -408,7 +432,7 @@ TEST_FUNCTION(5)
   }
 }
 
-TEST_FUNCTION(6)
+TEST_FUNCTION(25)
 {
   // Bug #32358
   static const char *sql1 = 
@@ -446,13 +470,13 @@ TEST_FUNCTION(6)
 
   std::auto_ptr<sql::Statement> stmt(connection->createStatement());
   execute_script(stmt.get(), sql2, tester.wb->get_grt_manager());
-  //Self referencing keys are no longer supported, but as testcase itself checks for
+  //Self referencing keys are no longer supported, but as test case itself checks for
   //crash it is better to this test case since there shouldn't be any crashes even
-  //in case of invalid sqll being produced
+  //in case of invalid sql being produced
 //  execute_script(stmt.get(), script, tester.wb->get_grt_manager());
 }
 
-TEST_FUNCTION(7)
+TEST_FUNCTION(30)
 {
   // Bug #32367
   static const char *sql1 = 
@@ -476,8 +500,10 @@ TEST_FUNCTION(7)
 
   std::list<std::string> schemata_list;
   schemata_list.push_back("db_mysql_plugin_test");
-  db_mysql_CatalogRef mod_cat= tester.db_rev_eng_schema(schemata_list);
-  db_mysql_CatalogRef org_cat= tester.db_rev_eng_schema(schemata_list);
+  db_mysql_CatalogRef mod_cat = grt::copy_object(tester.db_rev_eng_schema(schemata_list));
+  db_mysql_CatalogRef org_cat = grt::copy_object(mod_cat);
+  tester.wb->close_document();
+  tester.wb->close_document_finish();
 
   ensure("bug_32367 - invalid test input wrong table count",  (mod_cat->schemata().get(0)->tables().count() == 3));
   ensure("bug_32367 - invalid test input wrong trigger count",  (mod_cat->schemata().get(0)->tables().get(0)->triggers().count() == 1));
@@ -499,9 +525,12 @@ TEST_FUNCTION(7)
   ensure_equals("Table count mismatch", new_cat->schemata().get(0)->tables().count(), 2);
   ensure_equals("Trigger count mismatch", new_cat->schemata().get(0)->tables().get(0)->triggers().count(), 0);
   ensure_equals("Routines count mismatch", new_cat->schemata().get(0)->routines().count(), 0);
+
+  tester.wb->close_document();
+  tester.wb->close_document_finish();
 }
 
-TEST_FUNCTION(8)
+TEST_FUNCTION(35)
 {
   // Bug #32371
   static const char *sql1 = 
@@ -529,8 +558,11 @@ TEST_FUNCTION(8)
 
   std::list<std::string> schemata_list;
   schemata_list.push_back("db_mysql_plugin_test");
-  db_mysql_CatalogRef mod_cat= tester.db_rev_eng_schema(schemata_list);
-  db_mysql_CatalogRef org_cat= tester.db_rev_eng_schema(schemata_list);
+  db_mysql_CatalogRef mod_cat= grt::copy_object(tester.db_rev_eng_schema(schemata_list));
+  db_mysql_CatalogRef org_cat= grt::copy_object(mod_cat);
+
+  tester.wb->close_document();
+  tester.wb->close_document_finish();
 
   ensure("bug_32371 - invalid test input", 
     (mod_cat->schemata().get(0)->tables().count() == 1) &&
@@ -543,8 +575,7 @@ TEST_FUNCTION(8)
 
   ensure("bug_32371 - test failed", empty_change == NULL);
 
-  // part2 - check that delimiters for rouintes are generated
-
+  // Part2 - check that delimiters for routines are generated.
   static const char *def1= 
     "CREATE PROCEDURE proc1(OUT param1 INT) "
     "BEGIN "
@@ -569,7 +600,7 @@ TEST_FUNCTION(8)
   execute_script(stmt.get(), script, tester.wb->get_grt_manager());
 }
 
-TEST_FUNCTION(9)
+TEST_FUNCTION(40)
 {
   // Bug #32329
   static const char *sql1 = 
@@ -579,7 +610,7 @@ TEST_FUNCTION(9)
     "(`idtable1` INT NOT NULL , `col1` VARCHAR(45) NULL , PRIMARY KEY (`idtable1`) , INDEX idx1 (`idtable1` ASC, `col1` ASC) ) engine = MyISAM;";
 
   db_mysql_CatalogRef mod_cat= create_catalog_from_script(sql1);
-  db_mysql_CatalogRef org_cat= create_catalog_from_script(sql1);
+  db_mysql_CatalogRef org_cat= grt::copy_object(mod_cat);
 
   ensure("bug_32329 - invalid test input", 
     mod_cat->schemata().get(0)->tables().get(0)->indices().get(1)->columns().count() == 2);
@@ -604,7 +635,7 @@ TEST_FUNCTION(9)
   ensure("Unexpected changes", empty_change == NULL);
 }
 
-TEST_FUNCTION(10)
+TEST_FUNCTION(45)
 {
   // Bug #32324
   static const char *sql1 = 
@@ -614,7 +645,7 @@ TEST_FUNCTION(10)
     "(`idtable1` INT NOT NULL , `col1` VARCHAR(45) NULL , `col2` VARCHAR(45) NULL , PRIMARY KEY (`idtable1`) ) engine = MyISAM;";
 
   db_mysql_CatalogRef mod_cat= create_catalog_from_script(sql1);
-  db_mysql_CatalogRef org_cat= create_catalog_from_script(sql1);
+  db_mysql_CatalogRef org_cat= grt::copy_object(mod_cat);
 
   ensure("bug_32324 - invalid test input", 
     mod_cat->schemata().get(0)->tables().get(0)->columns().count() == 3);
@@ -642,7 +673,7 @@ TEST_FUNCTION(10)
   ensure("Unexpected changes", empty_change == NULL);
 }
 
-TEST_FUNCTION(11)
+TEST_FUNCTION(50)
 {
   // Bug #32331
   static const char *sql1 = 
@@ -689,7 +720,7 @@ TEST_FUNCTION(11)
 // http://bugs.mysql.com/bug.php?id=37634
 // update model figures (and FKs) when a table is replaced 
 // during the db/script to model synchronization
-TEST_FUNCTION(12)
+TEST_FUNCTION(55)
 {
   static const char *sql1=
     "CREATE SCHEMA IF NOT EXISTS `mydb` DEFAULT CHARACTER SET latin1 COLLATE latin1_swedish_ci;\n"
@@ -764,10 +795,13 @@ TEST_FUNCTION(12)
 
   ensure("before update table is referenced from figure 1", 
     tester.grt->get("/wb/doc/physicalModels/0/diagrams/1/figures/0/table")
-    == t2);  
+    == t2);
+
+  tester.wb->close_document();
+  tester.wb->close_document_finish();
 }
 
-TEST_FUNCTION(13)
+TEST_FUNCTION(60)
 {
   static const char *sql1=
     "CREATE SCHEMA IF NOT EXISTS `mydb` DEFAULT CHARACTER SET latin1 COLLATE latin1_swedish_ci;\n"
@@ -780,19 +814,24 @@ TEST_FUNCTION(13)
   tester.wb->open_document("data/workbench/diff_table_replace_test.mwb");
   apply_sql_to_model(sql1);
 
-
   db_TableRef t2= tester.get_catalog()->schemata().get(0)->tables().get(0);
   db_ColumnRef col = t2->columns().get(0);
   db_SimpleDatatypeRef dtype = col->simpleType();
   ensure("Column type not changed", dtype->name() == "TINYINT");
 
+  tester.wb->close_document();
+  tester.wb->close_document_finish();
 }
 
-TEST_FUNCTION(14)
+TEST_FUNCTION(65)
 {
   static const char *sql1= "CREATE SCHEMA IF NOT EXISTS `mydb` DEFAULT CHARACTER SET latin1 COLLATE latin1_swedish_ci;";
   tester.wb->open_document("data/workbench/diff_table_replace_test.mwb");
   apply_sql_to_model(sql1);
   ensure ("drop table in model",tester.get_catalog()->schemata().get(0)->tables().count() == 0);
+
+  tester.wb->close_document();
+  tester.wb->close_document_finish();
 }
+
 END_TESTS
