@@ -27,7 +27,7 @@ from workbench.utils import server_version_str2tuple
 from wb_admin_ssh import SSHDownException
 from workbench.db_utils import MySQLConnection, MySQLError, QueryError
 
-from wb_common import OperationCancelledError
+from wb_common import OperationCancelledError, Users
 
 from wb_server_control import PasswordHandler, ServerControlShell, ServerControlWMI
 from wb_server_management import ServerManagementHelper, SSH
@@ -41,7 +41,7 @@ from grt import log_info, log_error, log_warning, log_debug, log_debug2, log_deb
 _this_file = os.path.basename(__file__)
 
 MYSQL_ERR_ACCESS_DENIED = 1045
-
+MYSQL_ERR_PASSWORD_EXPIRED = 1820
 
 #===============================================================================
 #
@@ -440,6 +440,10 @@ uses_ssh: %i uses_wmi: %i\n""" % (self.server_profile.uses_ssh, self.server_prof
                     else:
                         # continue without a db connection
                         self.sql_enabled = False
+                elif err.code == MYSQL_ERR_PASSWORD_EXPIRED:
+                    import grt
+                    if not grt.modules.WbAdmin.handleExpiredPassword(self.server_profile.db_connection_params):
+                        raise OperationCancelledError("Connection cancelled")
                 else:
                     self.sql_enabled = False
                     if not self.server_profile.admin_enabled:  # We have neither sql connection nor management method
@@ -597,8 +601,8 @@ uses_ssh: %i uses_wmi: %i\n""" % (self.server_profile.uses_ssh, self.server_prof
                         password = self.server_control.get_password()
                         command = 'type %s' if self.server_profile.target_is_windows else 'cat %s'
                         self.cfg_data = self.execute_filtered_command(command % self.server_profile.config_file_path,
-                                                                      as_admin = True,
-                                                                      admin_password = password)[0]
+                                                                      as_user = Users.ADMIN,
+                                                                      user_password = password)[0]
                         cfg_file = StringIO.StringIO(self.cfg_data)
                     else:
                         return {}
@@ -657,21 +661,32 @@ uses_ssh: %i uses_wmi: %i\n""" % (self.server_profile.uses_ssh, self.server_prof
             opts = get_config_options()
             config_section = self.server_profile.config_file_section or 'mysqld'
 
-            result = self.exec_query("SHOW VARIABLES LIKE 'hostname'")
-            hostname = result.stringByName('Value') if result and result.nextRow() else ''
+            request_save_profile = False
+            try:
+                hostname = self.get_server_variable('hostname')
 
-            result = self.exec_query("SHOW VARIABLES LIKE 'datadir'")
-            datadir = result.stringByName('Value') if result and result.nextRow() else ''
 
-            result = self.exec_query("SHOW VARIABLES LIKE 'general_log'")
-            if result and result.nextRow():
-                value = result.stringByName('Value')
-                self.server_profile.general_log_enabled = (value == 'ON' or value == '1')
+                datadir = self.get_server_variable('datadir')
+                if self.server_profile.datadir != datadir:
+                    self.server_profile.datadir = datadir
+                    request_save_profile = True
 
-            result = self.exec_query("SHOW VARIABLES LIKE 'log_slow_queries'")
-            if result and result.nextRow():
-                value = result.stringByName('Value')
-                self.server_profile.slow_log_enabled = (value == 'ON' or value == '1')
+                basedir = self.get_server_variable('basedir')
+                if self.server_profile.basedir != basedir:
+                    self.server_profile.basedir = basedir
+                    request_save_profile = True
+
+                general_log_enabled = self.get_server_variable('general_log') in ('ON', '1')
+                if self.server_profile.general_log_enabled != general_log_enabled:
+                    self.server_profile.general_log_enabled = general_log_enabled
+                    request_save_profile = True
+
+                slow_log_enabled = self.get_server_variable('log_slow_queries') in ('ON', '1')
+                if self.server_profile.slow_log_enabled != slow_log_enabled:
+                    self.server_profile.slow_log_enabled = slow_log_enabled
+                    request_save_profile = True
+            except ValueError:
+                pass
 
             if self.server_version < (5, 1, 29):
                 general_log_file_path = opts[config_section].get('log', '').strip(' "') if opts.has_key(config_section) else ''
@@ -684,24 +699,32 @@ uses_ssh: %i uses_wmi: %i\n""" % (self.server_profile.uses_ssh, self.server_prof
                 self.server_profile.error_log_file_path = error_log_file_path or os.path.join(datadir, hostname + '.err')
 
             else:
-                result = self.exec_query("SHOW VARIABLES LIKE 'general_log_file'")
-                if result and result.nextRow():
-                    path = result.stringByName('Value')
-                    self.server_profile.general_log_file_path = path if path and path != '0' else ''
+                path = self.get_server_variable('general_log_file')
+                general_log_file_path = path if path and path != '0' else ''
+                if self.server_profile.general_log_file_path != general_log_file_path:
+                    self.server_profile.general_log_file_path = general_log_file_path
+                    request_save_profile = True
 
-                result = self.exec_query("SHOW VARIABLES LIKE 'slow_query_log_file'")
-                if result and result.nextRow():
-                    path = result.stringByName('Value')
-                    self.server_profile.slow_log_file_path = path if path and path != '0' else ''
+                path = self.get_server_variable('slow_query_log_file')
+                slow_query_log_file_path = path if path and path != '0' else ''
+                if self.server_profile.slow_log_file_path != slow_query_log_file_path:
+                    self.server_profile.slow_log_file_path = slow_query_log_file_path
+                    request_save_profile = True
 
-                result = self.exec_query("SHOW VARIABLES LIKE 'log_error'")
-                if result and result.nextRow():
-                    path = result.stringByName('Value')
-                    self.server_profile.error_log_file_path = path if path and path != '0' else ''
+                path = self.get_server_variable('log_error')
+                log_error_path = path if path and path != '0' else ''
+                if self.server_profile.error_log_file_path != log_error_path:
+                    self.server_profile.error_log_file_path = log_error_path
+                    request_save_profile = True
 
             log_info(_this_file, "Created SQL connection to MySQL server. Server version is " + repr(self.server_version) +
                      ", conn status = " + repr(self.is_sql_connected()) +
                      ", active plugins = " + str(self.server_active_plugins) + '\n')
+
+            # Save the server profile if at least one of its values has changed:
+            if request_save_profile:
+                from grt.modules import Workbench
+                Workbench.saveInstances()
         else:
             print "Failed to connect to MySQL server"
 
@@ -785,25 +808,26 @@ uses_ssh: %i uses_wmi: %i\n""" % (self.server_profile.uses_ssh, self.server_prof
         return False
 
     #---------------------------------------------------------------------------
-    def get_server_variable(self, variable):
+    def get_server_variable(self, variable, default = None):
         result = self.exec_query("SHOW VARIABLES LIKE '%s'" % variable)
         if result and result.nextRow():
             var = result.stringByName('Value')
         else:  # No result available
-            raise ValueError()
+            if default is not None:
+                var = default
+            else:
+                raise ValueError('Could not successfully retrieve the value for the '
+                                 'server variable "%s"' % variable)
         return var
 
     #---------------------------------------------------------------------------
     def get_server_version(self):
-        if type(self.server_version) is str:
-            self.server_version = self.server_version.lower()
+        if isinstance(self.server_version, (str, unicode)):
+            self.server_version = server_version_str2tuple(self.server_version)
 
-        if self.server_version is not None and type(self.server_version) is not tuple and self.server_version != "unknown":
-            converted = server_version_str2tuple(self.server_version)
-            if converted:
-                self.server_version = converted
-        elif type(self.server_version) is not tuple:
-            self.server_version = (5,1)
+        if not self.server_version or not isinstance(self.server_version, tuple):
+            log_warning(_this_file, 'Could not parse the server version tuple. Server version set to (5, 1)')
+            self.server_version = (5, 1)
 
         return self.server_version
 
@@ -818,13 +842,13 @@ uses_ssh: %i uses_wmi: %i\n""" % (self.server_profile.uses_ssh, self.server_prof
         return self.ssh is not None
 
     #---------------------------------------------------------------------------
-    def execute_filtered_command(self, script, as_admin = False, admin_password = False, verbose = None):
+    def execute_filtered_command(self, script, as_user = Users.CURRENT, user_password = False, verbose = None):
         (script, filters) = build_filters(script)
 
         output_text = []
         def gather_output(line, l=output_text):
             l.append(line)
-        retcode = self.server_helper.execute_command(script, as_admin=as_admin, admin_password=admin_password, output_handler=gather_output)
+        retcode = self.server_helper.execute_command(script, as_user=as_user, user_password=user_password, output_handler=gather_output)
         output_text = "".join(output_text)
 
         if verbose:
