@@ -496,6 +496,8 @@ class WbAdminSSH(object):
         log_debug3(_this_file, "cmd = %s\n" % cmd)
         out = ""
         ret = None
+        password_sent = False
+        
         # For some reason we have bool in pwd
         if type(user_password) is unicode:
             user_password = user_password.encode("utf8")
@@ -511,7 +513,10 @@ class WbAdminSSH(object):
                 chan = transport.open_session() # There should be timeout someday. The patch was sent.
                 if chan:
                     chan.setblocking(True)
-                    chan.settimeout(10)
+                    
+                    # Updating the timeout to an hour
+                    chan.settimeout(216000)
+                    
                     if as_user != Users.CURRENT:
                         chan.get_pty()
 
@@ -533,6 +538,7 @@ class WbAdminSSH(object):
                         try:
                             stdin.write(user_password+"\n")
                             stdin.flush()
+                            password_sent = True
                         except socket.error, e:
                             es = str(e)
                             if not('ocket' in es and 'closed' in es):
@@ -584,8 +590,11 @@ class WbAdminSSH(object):
             if chan is not None:
                 chan.close()
 
-        if out is not None and user_password is not None:
-            out = out.replace(user_password, "")
+        # If the password was sent removes the first occurrence of it from the output
+        # This is to prevent the sent password to be included but to not affect the
+        # rest of the output
+        if out is not None and user_password is not None and password_sent:
+            out = out.replace(user_password, "", 1)
 
         log_debug3(_this_file, "%s.exec_cmd(cmd=%s, output=%s. Retcode = %s)\n" % (self.__class__.__name__.encode('utf8'), cmd.encode('utf8'), out.decode('utf8'), ret) )
         return (out, ret)
