@@ -25,7 +25,7 @@ import grt
 import mforms
 
 from wb_server_management import wbaOS
-from wb_common import OperationCancelledError, InvalidPasswordError
+from wb_common import OperationCancelledError, InvalidPasswordError, Users
 
 import re
 import socket
@@ -241,6 +241,16 @@ Please edit your connection settings and try again."""
                 ret = 'none'
         return ret
 
+    @property
+    def host_name(self):
+        host_name = None
+        if self.db_connection_params:
+            if self.db_connection_params.driver.name == "MysqlNativeSocket":
+                host_name = "localhost"
+            else:
+                host_name = self.db_connection_params.parameterValues["hostName"]
+        return host_name
+
 
     @property
     def uses_ssh(self):
@@ -412,6 +422,24 @@ Please edit your connection settings and try again."""
 
     error_log_file_path = property(error_log_file_path, set_error_log_file_path)
 
+    #-------------------------------------------------------
+    def datadir(self):
+        return self._str_server_info('datadir')
+
+    def set_datadir(self, path):
+        self.__settings.serverInfo['datadir'] = path
+
+    datadir = property(datadir, set_datadir)
+
+    #-------------------------------------------------------
+    def basedir(self):
+        return self._str_server_info('basedir')
+
+    def set_basedir(self, path):
+        self.__settings.serverInfo['basedir'] = path
+
+    basedir = property(basedir, set_basedir)
+
 
 class PasswordHandler(object):
     def __init__(self, server_profile):
@@ -540,7 +568,7 @@ class PasswordHandler(object):
         if accepted:
             if not password:
                 password = ""
-            self.pwd_store[service_type] = password
+            self.pwd_store[service_type] = password.encode("utf8")
             return password
         else:
             raise OperationCancelledError("Password input cancelled")
@@ -643,9 +671,10 @@ class ServerControlShell(ServerControlBase):
         """ Can also throw InvalidPasswordError"""
         self.info("Starting server...") # TODO: This does not come to info output
         try:
+            as_user = Users.ADMIN if self.profile.use_sudo else Users.CURRENT
             r = self.helper.execute_command(self.profile.start_server_cmd,
-                                    as_admin=self.profile.use_sudo,
-                                    admin_password=password,
+                                    as_user=as_user,
+                                    user_password=password,
                                     output_handler=lambda s:self.info("Start server: %s"%(s if ((type(s) is str) or (type(s) is unicode)) else "").replace(password, "")))
         except InvalidPasswordError, exc:
             # forget password, so that next time it will be requested
@@ -669,9 +698,10 @@ class ServerControlShell(ServerControlBase):
                     output = ""
                 self.info("Stop server: %s"%str(output))
 
+            as_user = Users.ADMIN if self.profile.use_sudo else Users.CURRENT
             r = self.helper.execute_command(self.profile.stop_server_cmd,
-                                    as_admin=self.profile.use_sudo,
-                                    admin_password=password,
+                                    as_user=as_user,
+                                    user_password=password,
                                     output_handler=strip_pwd)
         except InvalidPasswordError, exc:
             # forget password, so that next time it will be requested
@@ -715,9 +745,10 @@ class ServerControlShell(ServerControlBase):
             if dump:
                 dump(line)
         try:
+            as_user = Users.ADMIN if self.profile.use_sudo_for_status else Users.CURRENT
             result = self.helper.execute_command(raw_script,
-                                    as_admin=self.profile.use_sudo_for_status,
-                                    admin_password=password,
+                                    as_user=as_user,
+                                    user_password=password,
                                     output_handler=collect_output)
         except InvalidPasswordError, exc:
             self.info("Invalid password")
@@ -764,7 +795,7 @@ class ServerControlWMI(ServerControlBase):
             password = ""
             self.check_and_fix_profile_for_local_windows(profile)
             self.shell = ServerControlShell(profile, helper, password_delegate)
-            # Forse usage of as_admin for local windows
+            # Force usage of Users.ADMIN for local windows
             self.info("Workbench will use cmd shell commands to start/stop this instance")
         else:
             user = self.profile.wmi_username
