@@ -31,7 +31,7 @@ class Frequency(object):
     monthly  = 3
 
 
-class WBBackupServerInterface:
+class WBBackupServerInterface(object):
     def __init__(self, context):
         self._context = context
         self._needs_admin = None
@@ -46,7 +46,7 @@ class WBBackupServerInterface:
         pass
 
     def execute_backup(self, profile, type, filename, output_handler=None):
-        command = self.create_backup_command_call(profile, type, filename=filename)
+        command = self.create_backup_command_call(profile, type, to_schedule=False, filename=filename)
         result = self._context.ctrl_be.server_helper.execute_command(command, as_user=self._context.mysql_user, user_password=self._context.ctrl_be.password_handler.get_password_for("file"), output_handler=output_handler)
         return result
 
@@ -70,7 +70,7 @@ class WBBackupServerInterface:
             command = self.get_schedule_command(profile, 'incremental')
             ret = self.perform_as_user(self._context.mysql_user, lambda as_user, user_password: self._context.ctrl_be.server_helper.execute_command(command, as_user=as_user, user_password=user_password))
 
-    def create_backup_command_call(self, profile, type, filename=None):
+    def create_backup_command_call(self, profile, type, to_schedule, filename=None):
         cmd_data = []
         if ' ' in self._context.config.backup_command:
             cmd_data.append('"%s"' % self._context.config.backup_command)
@@ -267,8 +267,9 @@ class WBBackupWindowsInterface(WBBackupServerInterface):
         return " ".join(unschedule)
 
     def get_schedule_command(self, profile, type):
+        command = self.create_backup_command_call(profile, type, to_schedule=True)
+
 
-        command = self.create_backup_command_call(profile, type)
         schedule_data = profile.full_backups if type == 'full' else profile.inc_backups
 
         weekdays=['SUN', 'MON','TUE','WED','THU','FRI','SAT']
@@ -307,7 +308,12 @@ class WBBackupWindowsInterface(WBBackupServerInterface):
         self.perform_as_user(self._context.mysql_user, lambda as_user, user_password: self._context.ctrl_be.server_helper.create_directory(path, as_user, user_password))
 
 
-    def create_backup_command_call(self, profile, type, filename=None):
+    def create_backup_command_call(self, profile, type, to_schedule, filename=None):
+        # If the command is not to be scheduled it will return the direct call to
+        # the mysqlbackup command
+        if not to_schedule:
+            return super(WBBackupWindowsInterface, self).create_backup_command_call(profile, type, to_schedule, filename)
+
         cmd_data = []
 
         script_name = joinpath(parentdir(self._context.server_profile.config_file_path), "mysqlwbbackup.vbs")
@@ -376,7 +382,7 @@ class WBBackupUnixInterface(WBBackupServerInterface):
         log_path = joinpath(log_path, "\$BACKUP_NAME.log 2>&1")
             
         # Creates the mysqlbackup command call
-        command = self.create_backup_command_call(profile, type, filename=filename)
+        command = self.create_backup_command_call(profile, type, to_schedule=True, filename=filename)
         
         # Chooses the proper scheduling data and creates the schedule command
         schedule_data = profile.full_backups if type == 'full' else profile.inc_backups
