@@ -188,8 +188,11 @@ class TableTreeNode(TreeNode):
         if self.flags_box:
             self.flags_box.set_fill_color(r, g, b, 0.7)
 
-    def stroke_line_to_parent(self, c, node):
-        p1, p2 = TreeNode.stroke_line_to_parent(self, c, node)
+    def stroke_line_to_parent(self, c, node, vertical):
+        if vertical:
+            p1, p2 = TreeNode.stroke_line_to_parent_v(self, c, node)
+        else:
+            p1, p2 = TreeNode.stroke_line_to_parent_h(self, c, node)
         filtered = self.data.get("filtered", None)
         rows = self.data.get("rows", None)
         if filtered is not None and rows is not None:
@@ -428,16 +431,22 @@ class MaterializedTableTreeNode(TableTreeNode):
 # Layouter
 
 class TreeLayouter:
-    def __init__(self, root):
+    def __init__(self, root, options):
         self.root = root
-        self.yspacing = 60
-        self.xspacing = 30
-
+        self.yspacing = options.get("yspacing", 60)
+        self.xspacing = options.get("xspacing", 30)
+        self.vertical = options.get("vertical", True)
 
+    
     def layout(self, ctx, node, x = 0, y = 0):
         t, l, b, r = node.padding
+        
+        if self.vertical:
+            spacing = self.xspacing
+        else:
+            spacing = self.yspacing
 
-        spacings = [self.xspacing] * (len(node.children)-1)
+        spacings = [spacing] * (len(node.children)-1)
         spacings.append(0) # no space after last item
 
         if node.children:
@@ -455,46 +464,88 @@ class TreeLayouter:
                     next = node.children[i+1]
                     rspace = ch.minimal_space_required_space_for_ref_to(ctx, next)
                     spacings[i] = max(spacings[i], int(rspace))
-          
+
         #
         width, height = node.size
-        total_width = 0
-        max_height = 0
-        xx = x
-        for i, ch in enumerate(node.children):
-            w, h = self.layout(ctx, ch, xx, y + self.yspacing + height + t)
-            xx  += w + spacings[i]
-            total_width += w
-            max_height = max(max_height, h)
-        twidth = max(width, total_width + sum(spacings))
-        if max_height > 0:
-            theight = height + self.yspacing + max_height
+    
+        if self.vertical:
+            total_width = 0
+            max_height = 0
+            xx = x
+            for i, ch in enumerate(node.children):
+                w, h = self.layout(ctx, ch, xx, y + self.yspacing + height + t)
+                xx  += w + spacings[i]
+                total_width += w
+                max_height = max(max_height, h)
+            twidth = max(width, total_width + sum(spacings))
+            if max_height > 0:
+                theight = height + self.yspacing + max_height
+            else:
+                theight = height
+
+            twidth += l + r
+            theight += t + b + node.extra_bottom_space
+
+            node.pos = x+(twidth)/2-node.size[0]/2, y
+            node.gsize = twidth, theight
+            if node.expand_to_fill:
+                node.pos = x, y
+                node.size = twidth, height
+
+            node.layout_internal()
+            # if child nodes are narrower than parent nodes, then offset them
+            if total_width <= width:
+                self.adjust_child_layout_v(node, l+(width-total_width)/2)
+            else:
+                self.adjust_child_layout_v(node, l)
         else:
-            theight = height
-
-        twidth += l + r
-        theight += t + b + node.extra_bottom_space
-
-        node.pos = x+(twidth)/2-node.size[0]/2, y
-        node.gsize = twidth, theight
-        if node.expand_to_fill:
-            node.pos = x, y
-            node.size = twidth, height
-
-        node.layout_internal()
-        # if child nodes are narrower than parent nodes, then offset them
-        if total_width <= width:
-            self.adjust_child_layout(node, l+(width-total_width)/2)
-        else:
-            self.adjust_child_layout(node, l)
+            total_height = 0
+            max_width = 0
+            yy = y
+            for i, ch in enumerate(node.children):
+                w, h = self.layout(ctx, ch, x + self.xspacing + width + t, yy)
+                yy  += h + spacings[i]
+                total_height += h
+                max_width = max(max_width, w)
+            theight = max(height, total_height + sum(spacings))
+            if max_width > 0:
+                twidth = width + self.xspacing + max_width
+            else:
+                twidth = width
             
+            theight += l + r
+            twidth += t + b + node.extra_bottom_space
+
+            node.pos = x, y+(theight)/2-node.size[1]/2
+            node.gsize = twidth, theight
+            if node.expand_to_fill:
+                node.pos = x, y
+                node.size = twidth, height
+            
+            node.layout_internal()
+            # if child nodes are narrower than parent nodes, then offset them
+            if total_height <= height:
+                self.adjust_child_layout_h(node, l+(height-total_height)/2)
+            else:
+                self.adjust_child_layout_h(node, l)
+        
+
         return twidth, theight
 
-    def adjust_child_layout(self, node, offset):
+
+    def adjust_child_layout_v(self, node, offset):
         for ch in node.children:
             cx, cy = ch.pos
             ch.pos = int(cx + offset), int(cy)
-            self.adjust_child_layout(ch, offset)                                       
+            self.adjust_child_layout_v(ch, offset)
+
+
+    def adjust_child_layout_h(self, node, offset):
+        for ch in node.children:
+            cx, cy = ch.pos
+            ch.pos = int(cx), int(cy + offset)
+            self.adjust_child_layout_h(ch, offset)
+
 
     def get_total_size(self, ctx):
         def calc_all(c, node):
@@ -518,7 +569,7 @@ class TreeLayouter:
 
     def do_render_lines(self, c, node):
         for ch in node.children:
-            ch.stroke_line_to_parent(c, node)
+            ch.stroke_line_to_parent(c, node, self.vertical)
 
         for ch in node.children:
             self.do_render_lines(c, ch)
@@ -549,10 +600,10 @@ def process_table(parent, table):
     ("system",          None,                   TableTreeNode),
     ("const",           None,                   TableTreeNode),
     ("eq_ref",          (0.25, 0.5, 0.75, 1),   IndexedTableTreeNode),
-    ("ref",             (1, 0.5, 0, 1),         IndexedTableTreeNode),
+    ("index",           (1, 0.5, 0, 1),         IndexedTableTreeNode),
     ("ALL",             (0.75, 0.25, 0.25, 1),  TableTreeNode),
     ("range",           (0.0, 0.5, 0.25, 1),    IndexedTableTreeNode),
-    ("index",           (0.0, 0.5, 0.25, 1),    IndexedTableTreeNode),
+    ("ref",             (0.0, 0.5, 0.25, 1),      IndexedTableTreeNode),
     ("fulltext",        (1, 0.5, 0, 1),         TableTreeNode),
     ("ref_or_null",     None,                   TableTreeNode),
     ("unique_subquery", None,                   TableTreeNode),
@@ -643,13 +694,34 @@ def tree_from_json(parent, name, json):
     return node
 
 
-def render_json_data(ctx, json_text, background_image):
+def strip_useless_nodes(tree):
+    def is_useless(node):
+        if node.name in ["query_specification", "nested_loop_item", "query_block"]:
+            return True
+        return False
+
+    if is_useless(tree) and len(tree.children) == 1:
+        tree = tree.children[0]
+        tree.parent = None
+
+    for i, ch in enumerate(tree.children):
+        if is_useless(ch) and len(ch.children) == 1:
+            tree.children[i] = ch.children[0]
+            ch.children[0].parent = tree
+
+        strip_useless_nodes(ch)
+
+    return tree
+
+
+def render_json_data(ctx, json_text, background_image, options):
     padding = 50
 
     json = decode_json(json_text)
     tree = tree_from_json(None, "query_block", json["query_block"])
     tree.process()
-    layout = TreeLayouter(tree)
+    tree = strip_useless_nodes(tree)
+    layout = TreeLayouter(tree, options)
     w, h = layout.get_total_size(ctx)
     ctx.set_font_size(12)
     if background_image:
@@ -671,13 +743,14 @@ def render_json_data(ctx, json_text, background_image):
     return w+padding*2, h+padding*2
 
 
-def render_json_data_to_file(json_text, background_image, png_file):
+def render_json_data_to_file(json_text, background_image, png_file, options):
     padding = 50
 
     json = decode_json(json_text)
     tree = tree_from_json(None, "query_block", json["query_block"])
     tree.process()
-    layout = TreeLayouter(tree)
+    tree = strip_useless_nodes(tree)
+    layout = TreeLayouter(tree, options)
     img = ImageSurface(cairo.CAIRO_FORMAT_ARGB32, 10, 100)
     ctx = Context(img)
     w, h = layout.get_total_size(ctx)
